@@ -32,9 +32,9 @@ import itertools
 from sets import Set
 
 import osv
-import sql_db
-
 import tools
+import pooler
+
 
 import netsvc
 from osv import fields
@@ -124,16 +124,16 @@ class Node(Singleton):
 			s += '%s`-> %s' % ('   ' * depth, c._pprint(depth+1))
 		return s
 
-def create_graph():
+def create_graph(module_list, force=[]):
 	graph = Graph()
 	packages = []
 
-	for i in os.listdir(ad):
-		terp_file = opj(ad, i, '__terp__.py')
+	for module in module_list:
+		terp_file = opj(ad, module, '__terp__.py')
 		if os.path.isfile(terp_file):
 			info = eval(file(terp_file).read())
-			if info.get('active', True):
-				packages.append((i, info.get('depends', []), info))
+			if info.get('installable', True):
+				packages.append((module, info.get('depends', []), info))
 
 	current,later = Set([p for p, dep, data in packages]), Set()
 	while packages and current > later:
@@ -147,7 +147,7 @@ def create_graph():
 			node = Node(package, graph)
 			node.datas = datas
 			for kind in ('init', 'demo', 'update'):
-				if package in tools.config[kind] or 'all' in tools.config[kind]:
+				if package in tools.config[kind] or 'all' in tools.config[kind] or kind in force:
 					setattr(node, kind, True)
 		else:
 			later.add(package)
@@ -159,40 +159,91 @@ def create_graph():
 	
 	return graph
 
-def load_modules(graph):
+def init_module_objects(cr, module_name, obj_list):
+	pool = pooler.get_pool(cr.dbname)
+	logger.notifyChannel('init', netsvc.LOG_INFO, 'addon:%s:creating or updating database tables' % module_name)
+	for obj in obj_list:
+		#CHECKME: is this test useful? all objects are supposed to have an _auto_init method, right?
+		#if hasattr(obj, '_auto_init'):
+		if hasattr(obj, 'init'):
+			obj.init(cr)
+		obj._auto_init(cr)
+		cr.commit()
+
+def load_module_graph(cr, graph, status={}):
 	package_todo = []
+	statusi = 0
 	for package in graph:
+		status['progress'] = (float(statusi)+0.1)/len(graph)
 		m = package.name
 		logger.notifyChannel('init', netsvc.LOG_INFO, 'addon:%s' % m)
 		sys.stdout.flush()
-		imp.load_module(m, *imp.find_module(m))
+		pool = pooler.get_pool(cr.dbname)
+		modules = pool.instanciate(m)
+		cr.execute('select state, demo from ir_module_module where name=%s', (m,))
+		(package_state, package_demo) = (cr.rowcount and cr.fetchone()) or ('uninstalled', False)
 		idref = {}
-		if hasattr(package, 'init') or hasattr(package, 'update'):
+		status['progress'] = (float(statusi)+0.4)/len(graph)
+		if hasattr(package, 'init') or hasattr(package, 'update') or package_state in ('to install', 'to upgrade'):
+			init_module_objects(cr, m, modules)
 			for kind in ('init', 'update'):
-				for xml in package.datas.get('%s_xml' % kind, []):
+				for filename in package.datas.get('%s_xml' % kind, []):
 					mode = 'update'
-					if hasattr(package, 'init'):
+					if hasattr(package, 'init') or package_state=='to install':
 						mode = 'init'
-					logger.notifyChannel('init', netsvc.LOG_INFO, 'addon:%s:loading %s' % (m, xml))
-					if xml[-4:].lower() == '.csv':
-						tools.convert_csv_import(xml, tools.file_open(opj(m, xml)).read(), idref, mode=mode)
+					logger.notifyChannel('init', netsvc.LOG_INFO, 'addon:%s:loading %s' % (m, filename))
+					name, ext = os.path.splitext(filename)
+					if ext == '.csv':
+						tools.convert_csv_import(cr, m, filename, tools.file_open(opj(m, filename)).read(), idref, mode=mode)
+					elif ext == '.sql':
+						queries = tools.file_open(opj(m, filename)).read().split(';')
+						for query in queries:
+							new_query = ' '.join(query.split())
+							if new_query:
+								cr.execute(new_query)
+						cr.commit()
 					else:
-						tools.convert_xml_import(m, tools.file_open(opj(m, xml)).read(), idref, mode=mode)
-			if hasattr(package, 'demo'):
+						tools.convert_xml_import(cr, m, tools.file_open(opj(m, filename)).read(), idref, mode=mode)
+			if hasattr(package, 'demo') or (package_demo and package_state != 'installed'):
+				status['progress'] = (float(statusi)+0.75)/len(graph)
 				for xml in package.datas.get('demo_xml', []):
+					name, ext = os.path.splitext(xml)
 					logger.notifyChannel('init', netsvc.LOG_INFO, 'addon:%s:loading %s' % (m, xml))
-					tools.convert_xml_import(m, tools.file_open(opj(m, xml)).read(), idref)
+					if ext == '.csv':
+						tools.convert_csv_import(cr, m, os.path.basename(xml), tools.file_open(opj(m, xml)).read(), idref)
+					else:
+						tools.convert_xml_import(cr, m, tools.file_open(opj(m, xml)).read(), idref)
 			package_todo.append(package.name)
+			cr.execute("update ir_module_module set state='installed', demo=%s where state in ('to upgrade', 'to install') and name=%s", (str(hasattr(package, 'demo')) or package_demo, package.name))
+			cr.commit()
+		statusi+=1
+	cr.commit()
 
-	pool=osv.osv.osv_pools
-	cr=sql_db.db.cursor()
-	pool.get('ir.model.data')._process_end(cr, 1, package_todo)
+#	pool = osv.osv.FakePool('base')
+#	pool = pooler.get_pool(cr.dbname)
+#	pool.get('ir.model.data')._process_end(cr, 1, package_todo)
+#	cr.commit()
 
+def register_classes():
+	module_list = os.listdir(ad)
+	for package in create_graph(module_list):
+		m = package.name
+		logger.notifyChannel('init', netsvc.LOG_INFO, 'addon:%s:registering classes' % m)
+		sys.stdout.flush()
+		imp.load_module(m, *imp.find_module(m))
+
+def load_modules(db, force_demo=False, status={}, update_module=False):
+	force = []
+	if force_demo:
+		force.append('demo')
+	cr = db.cursor()
+	if update_module:
+		cr.execute("select name from ir_module_module where state in ('installed', 'to install', 'to upgrade')")
+	else:
+		cr.execute("select name from ir_module_module where state = 'installed'")
+	module_list = [name for (name,) in cr.fetchall()]
+	graph = create_graph(module_list, force)
+	load_module_graph(cr, graph, status)
 	cr.commit()
 	cr.close()
 
-def main():
-	g = create_graph()
-	load_modules(g)
-
-main()
