@@ -1,8 +1,15 @@
 {
 	"name" : "Accounting and financial management",
 	"version" : "1.0",
-	"depends" : ["base"],
+	"depends" : ["product"],
 	"author" : "Tiny",
+	"description": """Financial and accounting module that covers:
+	General accounting
+	Cost / Analytic accounting
+	Third party accounting
+	Taxes management
+	Budgets
+	""",
 	"website" : "http://tinyerp.com/module_account.html",
 	"category" : "Generic Modules/Accounting",
 	"init_xml" : [
@@ -10,6 +17,7 @@
 	"demo_xml" : [
 		"account_demo.xml",
 		"project/project_demo.xml",
+		"project/account.analytic.account.csv"
 	],
 	"update_xml" : [
 		"account_wizard.xml",
@@ -25,9 +33,12 @@
 		"account_invoice_workflow.xml",
 		"project/project_view.xml",
 		"project/project_report.xml",
+		"product_data.xml",
+		"product_view.xml",
 	],
 #	"translations" : {
 #		"fr": "i18n/french_fr.csv"
 #	},
-	"active": True
+	"active": False,
+	"installable": True
 }
