@@ -36,7 +36,7 @@ import ir
 class account_invoice(osv.osv):
 	def _amount_untaxed(self, cr, uid, ids, prop, unknow_none,unknow_dict):
 		id_set=",".join(map(str,ids))
-		cr.execute("SELECT s.id,COALESCE(SUM(l.price_unit*l.quantity),0)::decimal(16,2) AS amount FROM account_invoice s LEFT OUTER JOIN account_invoice_line l ON (s.id=l.invoice_id) WHERE s.id IN ("+id_set+") GROUP BY s.id ")
+		cr.execute("SELECT s.id,COALESCE(SUM(l.price_unit*l.quantity*(100-l.discount))/100.0,0)::decimal(16,2) AS amount FROM account_invoice s LEFT OUTER JOIN account_invoice_line l ON (s.id=l.invoice_id) WHERE s.id IN ("+id_set+") GROUP BY s.id ")
 		res=dict(cr.fetchall())
 		return res
 
@@ -78,14 +78,14 @@ class account_invoice(osv.osv):
 	_description = 'Invoice'
 	_order = "number"
 	_columns = {
-		'name': fields.char('Invoice Description', size=64, required=True),
+		'name': fields.char('Invoice Description', size=64, required=True, select=True),
 		'origin': fields.char('Origin', size=64),
 		'type': fields.selection([
 			('out_invoice','Customer Invoice'),
 			('in_invoice','Supplier Invoice'),
 			('out_refund','Customer Refund'),
 			('in_refund','Supplier Refund'),
-		],'Type', readonly=True, states={'draft':[('readonly',False)]}),
+		],'Type', readonly=True, states={'draft':[('readonly',False)]}, select=True),
 
 		'number': fields.char('Invoice Number', size=32, readonly=True),
 		'reference': fields.char('Invoice Reference', size=64),
@@ -98,7 +98,7 @@ class account_invoice(osv.osv):
 			('open','Open'),
 			('paid','Paid'),
 			('cancel','Canceled')
-		],'State', readonly=True),
+		],'State', readonly=True, select=True),
 
 		'date_invoice': fields.date('Date Invoiced', required=True, states={'open':[('readonly',True)],'close':[('readonly',True)]}),
 		'date_due': fields.date('Due Date', states={'open':[('readonly',True)],'close':[('readonly',True)]}),
@@ -112,16 +112,18 @@ class account_invoice(osv.osv):
 
 		'payment_term': fields.many2one('account.payment.term', 'Payment Term'),
 
+		'period_id': fields.many2one('account.period', 'Force Period', help="Keep empty to use the period of the validation date."),
+
 		'account_id': fields.many2one('account.account', 'Dest Account', required=True, readonly=True, states={'draft':[('readonly',False)]}),
 		'invoice_line': fields.one2many('account.invoice.line', 'invoice_id', 'Invoice Lines', readonly=True, states={'draft':[('readonly',False)]}),
 		'tax_line': fields.one2many('account.invoice.tax', 'invoice_id', 'Tax Lines', readonly=True, states={'draft':[('readonly',False)]}),
 
 		'move_id': fields.many2one('account.move', 'Invoice Movement', readonly=True),
-		'amount_untaxed': fields.function(_amount_untaxed, method=True, string='Untaxed Amount'),
-		'amount_tax': fields.function(_amount_tax, method=True, string='Tax Amount'),
-		'amount_total': fields.function(_amount_total, method=True, string='Total Amount'),
+		'amount_untaxed': fields.function(_amount_untaxed, method=True, digits=(16,2),string='Untaxed Amount'),
+		'amount_tax': fields.function(_amount_tax, method=True, string='Tax'),
+		'amount_total': fields.function(_amount_total, method=True, string='Total'),
 		'currency_id': fields.many2one('res.currency', 'Currency', required=True),
-		'journal_id': fields.many2one('account.journal', 'Journal', required=True),
+		'journal_id': fields.many2one('account.journal', 'Journal', required=True, relate=True),
 	}
 	_defaults = {
 		'type': lambda *a: 'out_invoice',
@@ -224,21 +226,22 @@ class account_invoice(osv.osv):
 				sign = 1
 			else:
 				sign = -1
+			# one move line per invoice line
+			iml = self.pool.get('account.invoice.line').move_line_get(cr, uid, inv['id'])
 			if inv['project_id']:
-				for il in ils:
-					self.pool.get('account.analytic.line').create(cr, uid, {
-						'name': 'Inv.'+ str(inv['number'])+': '+il['name'],
+				for il in iml:
+					il['analytic_lines'] = [(0,0, {
+						'name': il['name'],
 						'date': time.strftime('%Y-%m-%d'),
 						'account_id': inv['project_id'],
 						'unit_amount': il['quantity'],
-						'amount': il['price_subtotal'] * sign,
-						'general_account_id': il['account_id'][0],
+						'amount': il['price'] * sign,
+						#'product_id': il['product_id']  and il['product_id'][0],
+						#'product_uom_id': il['uos_id']  and il['uos_id'][0],
+						'general_account_id': il['account_id'],
 						'journal_id': self._get_journal_analytic(cr, uid, inv['type'])
-					})
+					})]
 
-			# one move line per invoice line
-			iml = self.pool.get('account.invoice.line').move_line_get(cr, uid, inv['id'])
-			
 			# one move line per tax line
 			iml += self.pool.get('account.invoice.tax').move_line_get(cr, uid, inv['id'])
 			
@@ -249,7 +252,7 @@ class account_invoice(osv.osv):
 				if inv['currency_id'] != company_currency:
 					i['currency_id'] = inv['currency_id']
 					i['amount_currency'] = i['price']
-					i['price'] = self.pool.get('res.currency').compute(cr, uid, inv['currency_id'], company_currency, i['price'])
+					i['price'] = round(self.pool.get('res.currency').compute(cr, uid, inv['currency_id'], company_currency, i['price']),2)
 				else:
 					i['amount_currency'] = False
 					i['currency_id'] = False
@@ -257,7 +260,7 @@ class account_invoice(osv.osv):
 				if inv['type'] in ('out_invoice','in_refund'):
 					total += i['price']
 					total_currency += i['amount_currency'] or i['price']
-					i['price'] = -i['price']
+					i['price'] = - i['price']
 				else:
 					total -= i['price']
 					total_currency -= i['amount_currency'] or i['price']
@@ -273,7 +276,20 @@ class account_invoice(osv.osv):
 
 			date = inv['date_invoice']
 			part = inv['partner_id']
-			line = map(lambda x:(0,0,{ 'date':date, 'date_maturity': x.get('date_maturity', False), 'partner_id':part, 'name':x['name'], 'debit':x['price']>0 and x['price'], 'credit':x['price']<0 and -x['price'], 'account_id':x['account_id'], 'amount_currency':x.get('amount_currency', False), 'currency_id':x.get('currency_id', False), 'ref':x.get('ref',False) }) ,iml)
+			line = map(lambda x:(0,0,{
+				'date':date,
+				'date_maturity': x.get('date_maturity', False),
+				'partner_id':part,
+				'name':x['name'],
+				'debit':x['price']>0 and x['price'],
+				'credit':x['price']<0 and -x['price'],
+				'account_id':x['account_id'],
+				'analytic_lines':x.get('analytic_lines', []),
+				'amount_currency':x.get('amount_currency', False),
+				'currency_id':x.get('currency_id', False),
+				'tax_code_id': x.get('tax_code_id', False),
+				'tax_amount': x.get('tax_amount', False),
+				'ref':x.get('ref',False) }) ,iml)
 
 			journal_id = inv['journal_id'] #self._get_journal(cr, uid, {'type': inv['type']})
 			journal = self.pool.get('account.journal').browse(cr, uid, journal_id)
@@ -281,6 +297,10 @@ class account_invoice(osv.osv):
 				name = self.pool.get('ir.sequence').get_id(cr, uid, journal.sequence_id.id)
 
 			move = {'name': name, 'line_id': line, 'journal_id': journal_id}
+			if inv['period_id']:
+				move['period_id'] = inv['period_id']
+				for i in line:
+					i[2]['period_id'] = inv['period_id']
 			move_id = self.pool.get('account.move').create(cr, uid, move)
 
 			# make the invoice point to that move
@@ -322,12 +342,12 @@ class account_invoice(osv.osv):
 		return taxes.values()
 
 	def _log_event(self, cr, uid, ids, factor=1.0, name='Open Invoice'):
-		invs = self.read(cr, uid, ids, ['type','partner_id'])
+		invs = self.read(cr, uid, ids, ['type','partner_id','amount_untaxed'])
 		for inv in invs:
 			part=inv['partner_id'] and inv['partner_id'][0]
 			pc = pr = 0.0
 			cr.execute('select sum(quantity*price_unit) from account_invoice_line where invoice_id=%d', (inv['id'],))
-			total = cr.fetchone()[0] or 0
+			total = inv['amount_untaxed']
 			if inv['type'] in ('in_invoice','in_refund'):
 				partnertype='supplier'
 				eventtype = 'purchase'
@@ -367,6 +387,8 @@ class account_invoice(osv.osv):
 					del line['id']
 					del line['invoice_id']
 					line['account_id'] = line['account_id'] and line['account_id'][0]
+					line['product_id'] = line['product_id'] and line['product_id'][0]
+					line['uos_id'] = line['uos_id'] and line['uos_id'][0]
 					line['invoice_line_tax_id'] = [(6,0, line.get('invoice_line_tax_id', [])) ]
 				return map(lambda x: (0,0,x), lines)
 				
@@ -388,13 +410,13 @@ class account_invoice(osv.osv):
 		
 			# take the id part of the tuple returned for many2one fields
 			for field in ('address_contact_id', 'address_invoice_id', 'partner_id', 
-					'project_id', 'account_id', 'currency_id'):
+					'project_id', 'account_id', 'currency_id', 'payment_term'):
 				invoice[field] = invoice[field] and invoice[field][0]
 
 			# create the new invoice
 			new_ids.append(self.create(cr, uid, invoice))
 		return new_ids
-		
+
 	def pay_and_reconcile(self, cr, uid, ids, pay_amount, pay_account_id, pay_journal_id, writeoff_acc_id, writeoff_period_id, writeoff_journal_id, context={}):
 		assert len(ids)==1, "Can only pay one invoice at a time"
 		invoice = self.browse(cr, uid, ids[0])
@@ -440,82 +462,203 @@ class account_invoice_line(osv.osv):
 	def _amount_line(self, cr, uid, ids, prop, unknow_none,unknow_dict):
 		res = {}
 		for line in self.browse(cr, uid, ids):
-			res[line.id] = line.price_unit * line.quantity
+			res[line.id] = round(line.price_unit * line.quantity * (1-(line.discount or 0.0)/100.0),2)
 		return res
 	_name = "account.invoice.line"
 	_description = "Invoice line"
 	_columns = {
 		'name': fields.char('Description', size=256, required=True),
-		'invoice_id': fields.many2one('account.invoice', 'Invoice Ref', ondelete='cascade'),
-		'uos_id': fields.many2one('account.uos', 'Unit', ondelete='set null'),
+		'invoice_id': fields.many2one('account.invoice', 'Invoice Ref', ondelete='cascade', select=True),
+		'uos_id': fields.many2one('product.uom', 'Unit', ondelete='set null'),
+		'product_id': fields.many2one('product.product', 'Product', ondelete='set null'),
 		'account_id': fields.many2one('account.account', 'Source Account', required=True, domain=[('type','<>','view')]),
 		'price_unit': fields.float('Unit Price', required=True),
 		'price_subtotal': fields.function(_amount_line, method=True, string='Subtotal'),
 		'quantity': fields.float('Quantity', required=True),
+		'discount': fields.float('Discount (%)', digits=(16,2)),
 		'invoice_line_tax_id': fields.many2many('account.tax', 'account_invoice_line_tax', 'invoice_line_id', 'tax_id', 'Taxes', domain=[('parent_id','=',False)]),
 		'note': fields.text('Notes'),
 	}
 	_defaults = {
-		'quantity': lambda *a: 1
+		'quantity': lambda *a: 1,
+		'discount': lambda *a: 0.0
 	}
-	def move_line_get(self, cr, uid, invoice_id):
-		invoice = self.pool.get('account.invoice').browse(cr, uid, invoice_id)
+	def product_id_change(self, cr, uid, ids, product, uom, qty=0, name='', type='out_invoice'):
+		if not product:
+			return {'value': {'price_unit': 0.0}, 'domain':{'product_uom':[]}}
+		res = self.pool.get('product.product').browse(cr, uid, product)
+		result = {'price_unit': res.list_price, 'invoice_line_tax_id':map(lambda x: x.id, res.taxes_id)}
+		if not name:
+			result['name'] = res.name
+
+		if type in ('out_invoice','out_refund'):
+			a =  res.product_tmpl_id.property_account_income
+			if not a:
+				a = res.categ_id.property_account_income_categ
+			result['account_id'] = a[0]
+		else:
+			a =  res.product_tmpl_id.property_account_expense
+			if not a:
+				a = res.categ_id.property_account_expense_categ
+			result['account_id'] = a[0]
+
+		domain = {}
+		if not uom:
+			result['product_uom'] = res.uom_id.id or False
+			if result['product_uom']:
+				res2 = self.pool.get('product.uom').read(cr, uid, [result['product_uom']], ['category_id'])
+				if res2 and res2[0]['category_id']:
+					domain = {'product_uom':[('category_id','=',res2[0]['category_id'][0])]}
+		return {'value':result, 'domain':domain}
+
+	def move_line_get(self, cr, uid, invoice_id, context={}):
 		res = []
 		tax_grouped = {}
 		tax_obj = self.pool.get('account.tax')
 #TODO: rewrite using browse instead of the manual SQL queries
-		cr.execute('SELECT * FROM account_invoice_line WHERE invoice_id=%d', (invoice_id,))
-		for line in cr.dictfetchall():
-			res.append({'type':'src', 'name':line['name'], 'price_unit':line['price_unit'], 'quantity':line['quantity'], 'price':round(line['quantity']*line['price_unit'],2), 'account_id':line['account_id'], })
-			cr.execute('SELECT tax_id FROM account_invoice_line_tax WHERE invoice_line_id=%d', (line['id'],))
-			for (tax_id,) in cr.fetchall():
-				# even though we pass only one tax id at a time to compute, it can return several results
-				# in case a tax has a parent tax
-				sequence = tax_obj.read(cr, uid, [tax_id], ['sequence'])[0]['sequence']
-				for tax in tax_obj.compute(cr, uid, [tax_id], line['price_unit'], line['quantity'], invoice.address_invoice_id.id):
-					tax['sequence'] = sequence
-					if invoice.type in ('out_invoice','in_refund'):
-						tax['account_id'] = tax['account_collected_id']
+#		cr.execute('SELECT id FROM account_invoice_line WHERE invoice_id=%d', (invoice_id,))
+		inv = self.pool.get('account.invoice').browse(cr, uid, invoice_id)
+
+		for line in inv.invoice_line:
+			res.append( {
+				'type':'src', 
+				'name':line.name, 
+				'price_unit':line.price_unit, 
+				'quantity':line.quantity, 
+				'price':round(line.quantity*line.price_unit * (1.0- (line.discount or 0.0)/100.0),2),
+				'account_id':line.account_id.id
+			})
+			for tax2 in line.invoice_line_tax_id:
+				for tax in tax_obj.compute(cr, uid, [tax2.id], line.price_unit, line.quantity, inv.address_invoice_id.id):
+					tax['amount'] = tax['amount']*(1.0- (line['discount'] or 0.0)/100.0)
+					tax['sequence'] = tax2.sequence
+
+					#
+					# Setting the tax account and amount for the line
+					#
+					if inv.type in ('out_invoice','out_refund'):
+						res[-1]['tax_code_id'] = tax2.base_code_id.id
+						res[-1]['tax_amount'] = line['price_unit'] * line['quantity'] * (1.0- (line['discount'] or 0.0)/100.0) * tax2.base_sign
 					else:
-						tax['account_id'] = tax['account_paid_id']
-					key = tax['account_id']
+						res[-1]['tax_code_id'] = tax2.ref_base_code_id.id
+						res[-1]['tax_amount'] = line['price_unit'] * line['quantity'] * (1.0- (line['discount'] or 0.0)/100.0) * tax2.ref_base_sign
+					if inv.type in ('out_refund','in_refund'):
+						res[-1]['tax_amount'] = -res[-1]['tax_amount']
+
+					if inv.type in ('out_invoice','out_refund'):
+						tax['account_id'] = tax['account_collected_id'] or line.account_id.id
+					else:
+						tax['account_id'] = tax['account_paid_id'] or line.account_id.id
+					#
+					# Revoir la cl: tax.id ?
+					#
+					key = (res[-1]['tax_code_id'], tax['account_id'])
 					if not key in tax_grouped:
 						tax_grouped[key] = tax
-						tax_grouped[key]['base'] = line['price_unit'] * line['quantity']
+						tax_grouped[key]['base'] = line['price_unit'] * line['quantity'] * (1.0- (line['discount'] or 0.0)/100.0)
 					else:
 						tax_grouped[key]['amount'] += tax['amount']
-						tax_grouped[key]['base'] += line['price_unit'] * line['quantity']
+						tax_grouped[key]['base'] += line['price_unit'] * line['quantity'] * (1.0- (line['discount'] or 0.0)/100.0)
 		# delete automatic tax lines for this invoice
 		cr.execute("DELETE FROM account_invoice_tax WHERE NOT manual AND invoice_id=%d", (invoice_id,))
+		self.move_line_tax_create(cr, uid, inv, tax_grouped, context)
+		return res
+
+	def move_line_tax_create(self, cr, uid, inv,  tax_grouped, context={}):
 		
 		# (re)create them
 		ait = self.pool.get('account.invoice.tax')
 		for t in tax_grouped.values():
-			ait.create(cr, uid, {'invoice_id':invoice_id, 'name':t['name'], 'account_id':t['account_id'], 'amount':t['amount'], 'manual':False, 'sequence':t['sequence'], 'base': t['base']})
-		return res
+			tax = self.pool.get('account.tax').browse(cr, uid, t['id'])
+			val = {
+				'invoice_id':inv.id,
+				'name':t['name'],
+				'account_id':t['account_id'],
+				'amount':t['amount'],
+				'manual':False,
+				'sequence':t['sequence'],
+				'base': t['base'],
+			}
+			if inv.type in ('out_invoice','out_refund'):
+				val.update({
+					'base_code_id': tax.base_code_id.id or False,
+					'tax_code_id': tax.tax_code_id.id or False,
+					'base_amount': tax.base_sign * t['base'],
+					'tax_amount': tax.tax_sign * t['amount']
+				})
+			elif inv.type in ('in_invoice','in_refund'):
+				val.update({
+					'base_code_id': tax.ref_base_code_id.id or False,
+					'tax_code_id': tax.ref_tax_code_id.id or False,
+					'base_amount': tax.ref_base_sign * t['base'],
+					'tax_amount': tax.ref_tax_sign * t['amount']
+				})
+			if inv.type in ('out_refund','in_refund'):
+				val.update({
+					'base_amount': -val['base_amount'],
+					'tax_amount': -val['tax_amount']
+				})
+
+			ait.create(cr, uid, val)
+			#ait.create(cr, uid, {'invoice_id':invoice_id, 'name':t['name'], 'account_id':t['account_id'], 'amount':t['amount'], 'manual':False, 'sequence':t['sequence'], 'base':t['base']})
+		return True
+
+	#
+	# Set the tax field according to the account and the partner
+	# 
+	def onchange_account_id(self, cr, uid, ids, partner_id,account_id):
+		if not (partner_id and account_id):
+			return {}
+		taxes = self.pool.get('account.account').browse(cr, uid, account_id).tax_ids
+		taxep = self.pool.get('res.partner').browse(cr, uid, partner_id).property_account_tax
+		if not taxep:
+			return {'value': {'invoice_line_tax_id': map(lambda x: x.id, taxes or []) }}
+		res = [taxep[0]]
+		tp = self.pool.get('account.tax').browse(cr, uid, taxep[0])
+		for t in taxes:
+			if not t.tax_group==tp.tax_group:
+				res.append(t.id)
+		r = {'value':{'invoice_line_tax_id': res}}
+		return r
 account_invoice_line()
 
 class account_invoice_tax(osv.osv):
 	_name = "account.invoice.tax"
 	_description = "Invoice Tax"
 	_columns = {
-		'invoice_id': fields.many2one('account.invoice', 'Invoice Line', ondelete='cascade'),
+		'invoice_id': fields.many2one('account.invoice', 'Invoice Line', ondelete='cascade', select=True),
 		'name': fields.char('Tax Description', size=64, required=True),
 		'account_id': fields.many2one('account.account', 'Tax Account', required=True, domain=[('type','<>','view'),('type','<>','income')]),
+		'base': fields.float('Base', digits=(16,2)),
 		'amount': fields.float('Amount', digits=(16,2)),
-		'base': fields.float('Base', digits=(16,4)),
 		'manual': fields.boolean('Manual'),
-		'sequence': fields.integer('Sequence')
+		'sequence': fields.integer('Sequence'),
+
+		'base_code_id': fields.many2one('account.tax.code', 'Base Code'),
+		'base_amount': fields.float('Base Code Amount', digits=(16,2)),
+		'tax_code_id': fields.many2one('account.tax.code', 'Tax Code'),
+		'tax_amount': fields.float('Tax Code Amount', digits=(16,2)),
 	}
 	_order = 'sequence'
 	_defaults = {
 		'manual': lambda *a: 1,
+		'base_amount': lambda *a: 0.0,
+		'tax_amount': lambda *a: 0.0,
 	}
 	def move_line_get(self, cr, uid, invoice_id):
 		res = []
 		cr.execute('SELECT * FROM account_invoice_tax WHERE invoice_id=%d', (invoice_id,))
 		for t in cr.dictfetchall():
-			res.append({'type':'tax','name':t['name'],'price_unit': t['amount'],'quantity': 1,'price': t['amount'] or 0.0,'account_id': t['account_id'], })
+			res.append({
+				'type':'tax',
+				'name':t['name'],
+				'price_unit': t['amount'],
+				'quantity': 1,
+				'price': t['amount'] or 0.0,
+				'account_id': t['account_id'],
+				'tax_code_id': t['tax_code_id'],
+				'tax_amount': t['tax_amount']
+			})
 		return res
 account_invoice_tax()
 
