@@ -104,6 +104,15 @@ class res_partner(osv.osv):
 		  view_load=True,
 		  group_name="Accounting Properties",
 		  help="This account will be used, instead of the default one, as the receivable account for the current partner"),
+		'property_account_tax': fields.property(
+		  'account.tax',
+		  type='many2one', 
+		  relation='account.tax', 
+		  string="Default Tax", 
+		  method=True,
+		  view_load=True,
+		  group_name="Accounting Properties",
+		  help="This tax will be used, instead of the default one."),
 		'property_payment_term': fields.property(
 		  'account.payment.term',
 		  type='many2one', 
