@@ -26,13 +26,13 @@
 #
 ##############################################################################
 
-import sql_db
+import pooler
 import time
 from report import report_sxw
 
 class account_analytic_balance(report_sxw.rml_parse):
-	def __init__(self, name, table, rml):
-		super(account_analytic_balance, self).__init__(name, table, rml)
+	def __init__(self, cr, uid, name, context):
+		super(account_analytic_balance, self).__init__(cr, uid, name, context)
 		self.localcontext.update( {
 			'time': time,
 			'lines_g': self._lines_g,
