@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: rappel.py 3702 2006-08-08 06:54:24Z pinky $
+# $Id: rappel.py 4310 2006-10-25 20:53:06Z pinky $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -32,10 +32,11 @@ import time
 import ir
 from osv import osv
 from report import report_sxw
+import pooler
 
 class report_rappel(report_sxw.rml_parse):
-	def __init__(self, name, table, rml):
-		super(report_rappel, self).__init__(name, table, rml)
+	def __init__(self, cr, uid, name, context):
+		super(report_rappel, self).__init__(cr, uid, name, context)
 		self.localcontext.update( {
 			'time' : time,
 			'adr_get' : self._adr_get,
@@ -43,16 +44,16 @@ class report_rappel(report_sxw.rml_parse):
 		})
 
 	def _adr_get(self, partner, type):
-		res_partner = osv.osv_pools.get('res.partner')
-		res_partner_address = osv.osv_pools.get('res.partner.address')
+		res_partner = pooler.get_pool(self.cr.dbname).get('res.partner')
+		res_partner_address = pooler.get_pool(self.cr.dbname).get('res.partner.address')
 		addresses = res_partner.address_get(self.cr, self.uid, [partner.id], [type])
 		adr_id = addresses and addresses[type] or False
 		return adr_id and res_partner_address.read(self.cr, self.uid, [adr_id])[0] or False
 
 	def _lines_get(self, partner):
-		part = osv.osv_pools.get('res.partner')
+		part = pooler.get_pool(self.cr.dbname).get('res.partner')
 		acc = partner.property_account_receivable[0]
-		moveline_obj = osv.osv_pools.get('account.move.line')
+		moveline_obj = pooler.get_pool(self.cr.dbname).get('account.move.line')
 		movelines = moveline_obj.search(self.cr, self.uid, [('partner_id','=',partner.id), ('account_id','=',acc), ('state','=','valid')])
 		movelines = moveline_obj.read(self.cr, self.uid, movelines)
 		return movelines
