@@ -28,7 +28,7 @@
 
 import wizard
 import netsvc
-from osv.osv import osv_pools
+import pooler
 import time
 
 #TODO:
@@ -53,10 +53,10 @@ import time
 _reconcile_form = '''<?xml version="1.0"?>
 <form string="Reconciliation">
 	<separator string="Options" colspan="4"/>
-	<field name="account_id"/>
-	<field name="power"/>
+	<field name="account_ids" colspan="3" domain="[('reconcile','=',1)]"/>
 	<field name="date1"/>
 	<field name="date2"/>
+	<field name="power"/>
 	<separator string="Write-Off Move" colspan="4"/>
 	<field name="max_amount"/>
 	<field name="writeoff_acc_id"/>
@@ -65,10 +65,11 @@ _reconcile_form = '''<?xml version="1.0"?>
 </form>'''
 
 _reconcile_fields = {
-	'account_id': {
+	'account_ids': {
 		'string': 'Account to reconcile',
-		'type': 'many2one',
+		'type': 'many2many',
 		'relation': 'account.account',
+		'domain': [('reconcile','=',1)],
 		'required': True
 	},
 	'writeoff_acc_id': {
@@ -203,7 +204,7 @@ def do_reconcile(cr, uid, credits, debits, max_amount, power, writeoff_acc_id, p
 
 	ok = True
 	reconciled = 0
-	move_line_obj = osv_pools.get('account.move.line')
+	move_line_obj = pooler.get_pool(cr.dbname).get('account.move.line')
 	while credits and debits and ok:
 		res = check5(credits, debits, power)
 		if res:
@@ -217,92 +218,94 @@ def do_reconcile(cr, uid, credits, debits, max_amount, power, writeoff_acc_id, p
 				
 def _reconcile(self, cr, uid, data, context):
 	service = netsvc.LocalService("object_proxy")
-	move_line_obj = osv_pools.get('account.move.line')
+	move_line_obj = pooler.get_pool(cr.dbname).get('account.move.line')
 	form = data['form']
-	account_id = form['account_id']
 	max_amount = form.get('max_amount', 0.0)
 	power = form['power']
 	reconciled = unreconciled = 0
+	if not form['account_ids']:
+		return {'reconciled':0, 'unreconciled':[0]}
+	for account_id in form['account_ids'][0][2]:
 	
-	# reconcile automatically all transactions from partners whose balance is 0
-	cr.execute(
-		"SELECT partner_id " \
-		"FROM account_move_line " \
-		"WHERE account_id=%d " \
-		"AND reconcile_id IS NULL " \
-		"AND state <> 'draft' " \
-		"GROUP BY partner_id " \
-		"HAVING ABS(SUM(debit-credit)) < %f AND count(*)>0",
-		(account_id, max_amount))
-	partner_ids = [id for (id,) in cr.fetchall()]
-
-	for partner_id in partner_ids:
+		# reconcile automatically all transactions from partners whose balance is 0
 		cr.execute(
-			"SELECT id " \
+			"SELECT partner_id " \
 			"FROM account_move_line " \
 			"WHERE account_id=%d " \
-			"AND partner_id=%d " \
-			"AND state <> 'draft' " \
-			"AND reconcile_id IS NULL",
-			(account_id, partner_id))
-		line_ids = [id for (id,) in cr.fetchall()]
-		
-		if len(line_ids):
-			move_line_obj.reconcile(cr, uid, line_ids, 'auto', form['writeoff_acc_id'], form['period_id'], form['journal_id'], context)
-			reconciled += len(line_ids)
-	
-	# get the list of partners who have more than one unreconciled transaction
-	cr.execute(
-		"SELECT partner_id " \
-		"FROM account_move_line " \
-		"WHERE account_id=%d " \
-		"AND reconcile_id IS NULL " \
-		"AND state <> 'draft' " \
-		"GROUP BY partner_id " \
-		"HAVING count(*)>1",
-		(account_id,))
-	partner_ids = [id for (id,) in cr.fetchall()]
-	#filter?
-	for partner_id in partner_ids:
-		# get the list of unreconciled 'debit transactions' for this partner
-		cr.execute(
-			"SELECT id, debit " \
-			"FROM account_move_line " \
-			"WHERE account_id=%d " \
-			"AND partner_id=%d " \
 			"AND reconcile_id IS NULL " \
 			"AND state <> 'draft' " \
-			"AND debit > 0",
-			(account_id, partner_id))
-		debits = cr.fetchall()
+			"GROUP BY partner_id " \
+			"HAVING ABS(SUM(debit-credit)) < %f AND count(*)>0",
+			(account_id, max_amount))
+		partner_ids = [id for (id,) in cr.fetchall()]
+
+		for partner_id in partner_ids:
+			cr.execute(
+				"SELECT id " \
+				"FROM account_move_line " \
+				"WHERE account_id=%d " \
+				"AND partner_id=%d " \
+				"AND state <> 'draft' " \
+				"AND reconcile_id IS NULL",
+				(account_id, partner_id))
+			line_ids = [id for (id,) in cr.fetchall()]
 			
-		# get the list of unreconciled 'credit transactions' for this partner
+			if len(line_ids):
+				move_line_obj.reconcile(cr, uid, line_ids, 'auto', form['writeoff_acc_id'], form['period_id'], form['journal_id'], context)
+				reconciled += len(line_ids)
+		
+		# get the list of partners who have more than one unreconciled transaction
 		cr.execute(
-			"SELECT id, credit " \
+			"SELECT partner_id " \
 			"FROM account_move_line " \
 			"WHERE account_id=%d " \
-			"AND partner_id=%d " \
 			"AND reconcile_id IS NULL " \
 			"AND state <> 'draft' " \
-			"AND credit > 0",
-			(account_id, partner_id))
-		credits = cr.fetchall()
-		
-		(rec, unrec) = do_reconcile(cr, uid, credits, debits, max_amount, power, form['writeoff_acc_id'], form['period_id'], form['journal_id'], context)
-		reconciled += rec
-		unreconciled += unrec
+			"GROUP BY partner_id " \
+			"HAVING count(*)>1",
+			(account_id,))
+		partner_ids = [id for (id,) in cr.fetchall()]
+		#filter?
+		for partner_id in partner_ids:
+			# get the list of unreconciled 'debit transactions' for this partner
+			cr.execute(
+				"SELECT id, debit " \
+				"FROM account_move_line " \
+				"WHERE account_id=%d " \
+				"AND partner_id=%d " \
+				"AND reconcile_id IS NULL " \
+				"AND state <> 'draft' " \
+				"AND debit > 0",
+				(account_id, partner_id))
+			debits = cr.fetchall()
+				
+			# get the list of unreconciled 'credit transactions' for this partner
+			cr.execute(
+				"SELECT id, credit " \
+				"FROM account_move_line " \
+				"WHERE account_id=%d " \
+				"AND partner_id=%d " \
+				"AND reconcile_id IS NULL " \
+				"AND state <> 'draft' " \
+				"AND credit > 0",
+				(account_id, partner_id))
+			credits = cr.fetchall()
+			
+			(rec, unrec) = do_reconcile(cr, uid, credits, debits, max_amount, power, form['writeoff_acc_id'], form['period_id'], form['journal_id'], context)
+			reconciled += rec
+			unreconciled += unrec
 
-	# add the number of transactions for partners who have only one 
-	# unreconciled transactions to the unreconciled count
-	partner_filter = partner_ids and 'AND partner_id not in (%s)' % ','.join(map(str, partner_ids)) or ''
-	cr.execute(
-		"SELECT count(*) " \
-		"FROM account_move_line " \
-		"WHERE account_id=%d " \
-		"AND reconcile_id IS NULL " \
-		"AND state <> 'draft' " + partner_filter,
-		(account_id,))
-	additional_unrec = cr.fetchone()[0]
+		# add the number of transactions for partners who have only one 
+		# unreconciled transactions to the unreconciled count
+		partner_filter = partner_ids and 'AND partner_id not in (%s)' % ','.join(map(str, filter(None, partner_ids))) or ''
+		cr.execute(
+			"SELECT count(*) " \
+			"FROM account_move_line " \
+			"WHERE account_id=%d " \
+			"AND reconcile_id IS NULL " \
+			"AND state <> 'draft' " + partner_filter,
+			(account_id,))
+		additional_unrec = cr.fetchone()[0]
 	return {'reconciled':reconciled, 'unreconciled':unreconciled+additional_unrec}
 
 class wiz_reconcile(wizard.interface):
