@@ -28,6 +28,7 @@
 
 import wizard
 from osv import osv
+import pooler
 
 _journal_form = '''<?xml version="1.0"?>
 <form string="%s">
@@ -45,11 +46,11 @@ def _action_open_window(self, cr, uid, data, context):
 	form = data['form']
 	cr.execute('select id,name from ir_ui_view where model=%s and type=%s', ('account.move.line', 'form'))
 	view_res = cr.fetchone()
-	jp = osv.osv_pools.get('account.journal.period')
+	jp = pooler.get_pool(cr.dbname).get('account.journal.period')
 	ids = jp.search(cr, uid, [('journal_id','=',form['journal_id']), ('period_id','=',form['period_id'])])
 	if not len(ids):
-		name = osv.osv_pools.get('account.journal').read(cr, uid, [form['journal_id']])[0]['name']
-		state = osv.osv_pools.get('account.period').read(cr, uid, [form['period_id']])[0]['state']
+		name = pooler.get_pool(cr.dbname).get('account.journal').read(cr, uid, [form['journal_id']])[0]['name']
+		state = pooler.get_pool(cr.dbname).get('account.period').read(cr, uid, [form['period_id']])[0]['state']
 		if state == 'done':
 			raise wizard.except_wizard('UserError', 'This period is already closed !')
 		jp.create(cr, uid, {'name':name, 'period_id': form['period_id'], 'journal_id':form['journal_id']})
