@@ -27,7 +27,7 @@
 
 import wizard
 import datetime
-from osv.osv import osv_pools
+import pooler
 
 class followup_all_print(wizard.interface):
 #	_followup_wizard_all_form = """<?xml version="1.0"?>
@@ -63,7 +63,7 @@ class followup_all_print(wizard.interface):
 
 		old = None
 		fups = {}
-		fup_ids = osv_pools.get('account_followup.followup').search(cr, uid, [])
+		fup_ids = pooler.get_pool(cr.dbname).get('account_followup.followup').search(cr, uid, [])
 		if not fup_ids:
 			raise wizard.except_wizard('No Follow up Defined', 
 				'You must define at least one follow up for your company !')
@@ -100,7 +100,7 @@ class followup_all_print(wizard.interface):
 
 		partner_list = []
 		for partner_id, followup_line_id, date, id in move_lines: 
-			if partner_id in partner_list:
+			if (partner_id in partner_list) or (not partner_id):
 				continue
 				
 			# if the move line has already a followup line but it is invalid,
