@@ -4,6 +4,7 @@
 	"author" : "Tiny",
 	"website" : "http://tinyerp.com",
 	"category" : "Generic Modules/Base",
+	"description": "The kernel of Tiny ERP, needed for all installation.",
 	"depends" : [],
 	"init_xml" : [
 		"base_data.xml",
@@ -31,4 +32,5 @@
 		"res/partner/partner_data.xml",
 		"res/ir_property_view.xml",
 	],
+	"installable": True
 }
