@@ -62,6 +62,7 @@ CREATE TABLE ir_model_fields (
   primary key(id)
 );
 
+
 -------------------------------------------------------------------------
 -- Actions
 -------------------------------------------------------------------------
@@ -157,6 +158,7 @@ CREATE TABLE res_users (
     id serial NOT NULL,
     perm_id int references perm on delete set null,
     name varchar(64) not null,
+    active boolean default True,
     login varchar(64) NOT NULL UNIQUE,
     password varchar(32) default null,
     perm_default int references perm on delete set null,
@@ -166,7 +168,7 @@ CREATE TABLE res_users (
 );
 alter table res_users add constraint res_users_login_uniq unique (login);
 
-insert into res_users (id,login,password,name,action_id,perm_id) values (1,'root',NULL,'Administrator',NULL,1);
+insert into res_users (id,login,password,name,action_id,perm_id,active) values (1,'root',NULL,'Administrator',NULL,1,False);
 select setval('res_users_id_seq', 2);
 
 CREATE TABLE res_groups (
@@ -280,3 +282,54 @@ create table wkf_logs
     info varchar(128) default NULL,
     primary key(id)
 );
+
+---------------------------------
+-- Modules
+---------------------------------
+
+CREATE TABLE ir_module_category (
+    id serial NOT NULL,
+    perm_id integer,
+    create_uid integer references res_users on delete set null,
+    create_date timestamp without time zone,
+    write_date timestamp without time zone,
+    write_uid integer references res_users on delete set null,
+    parent_id integer REFERENCES ir_module_category ON DELETE SET NULL,
+    name character varying(128) NOT NULL,
+    primary key(id)
+);
+
+
+CREATE TABLE ir_module_module (
+    id serial NOT NULL,
+    perm_id integer,
+    create_uid integer references res_users on delete set null,
+    create_date timestamp without time zone,
+    write_date timestamp without time zone,
+    write_uid integer references res_users on delete set null,
+    website character varying(256),
+    name character varying(128) NOT NULL,
+    author character varying(128),
+    url character varying(128),
+    state character varying(16),
+    latest_version character varying(64),
+    shortdesc character varying(256),
+    category_id integer REFERENCES ir_module_category ON DELETE SET NULL,
+    description text,
+    demo boolean default False,
+    primary key(id)
+);
+
+CREATE TABLE ir_module_module_dependency (
+    id serial NOT NULL,
+    perm_id integer,
+    create_uid integer references res_users on delete set null,
+    create_date timestamp without time zone,
+    write_date timestamp without time zone,
+    write_uid integer references res_users on delete set null,
+    name character varying(128),
+    version_pattern character varying(128) default NULL,
+    module_id integer REFERENCES ir_module_module ON DELETE cascade,
+    primary key(id)
+);
+
