@@ -108,8 +108,8 @@ class act_window(osv.osv):
 		'name': fields.char('Action Name', size=64, required=True, translate=True),
 		'type': fields.char('Action Type', size=32, required=True),
 		'view_id': fields.many2one('ir.ui.view', 'View Ref.', ondelete='cascade'),
-		'domain': fields.char('Domain Value', size=127),
-		'context': fields.char('Context Value', size=127),
+		'domain': fields.char('Domain Value', size=250),
+		'context': fields.char('Context Value', size=250),
 		'res_model': fields.char('Model', size=64),
 		'view_type': fields.selection((('tree','Tree'),('form','Form')),string='Type of view'),
 		'view_mode': fields.selection((('form,list','Form - List'),('list,form','List - Form')), string='Mode of view'),
@@ -131,9 +131,11 @@ class act_wizard(osv.osv):
 		'name': fields.char('Wizard info', size=64, required=True, translate=True),
 		'type': fields.char('Action type', size=32, required=True),
 		'wiz_name': fields.char('Wizard name', size=64, required=True),
+		'multi': fields.boolean('Action on multiple doc.', help="If set to true, the wizard will not be displayed on the right toolbar of a form views.")
 	}
 	_defaults = {
 		'type': lambda *a: 'ir.actions.wizard',
+		'multi': lambda *a: False,
 	}
 act_wizard()
 
