@@ -40,7 +40,7 @@ from mx import DateTime
 import time
 import netsvc
 import tools
-import sql_db
+import pooler
 from osv import fields,osv
 
 next_wait = 60
@@ -95,9 +95,15 @@ class ir_cron(osv.osv, netsvc.Agent):
 		f = getattr(self.pool.get(model), func)
 		f(cr, uid, *args)
 
-	def _poolJobs(self, check=False):
+	def _poolJobs(self, db_name, check=False):
 		now = DateTime.now()
-		cr = sql_db.db.cursor()
+		#FIXME: multidb. Solution: a l'instanciation d'une nouvelle connection bd (ds pooler) fo que j'instancie
+		# un nouveau pooljob avec comme parametre la bd
+		try:
+			cr = pooler.get_db(db_name).cursor()
+		except:
+			return False
+
 		try:
 			cr.execute('select * from ir_cron where numbercall<>0 and active and nextcall<=now() order by priority')
 			for job in cr.dictfetchall():
@@ -126,11 +132,8 @@ class ir_cron(osv.osv, netsvc.Agent):
 		# But is this an improvement ?
 		# 
 		if not check:
-			self.setAlarm(self._poolJobs, int(time.time())+next_wait)
+			self.setAlarm(self._poolJobs, int(time.time())+next_wait, [db_name])
 
-	def check(self):
-		self._poolJobs(True)
-
-	def __init__(self):
-		super(ir_cron, self).__init__()
+#	def __init__(self):
+#		super(ir_cron, self).__init__()
 ir_cron()
