@@ -31,14 +31,14 @@ import netsvc
 
 import time
 import tools
-import sql_db
+import pooler
 
 class ir_model(osv.osv):
 	_name = 'ir.model'
 	_rec_name = 'model'
 	_columns = {
-		'name': fields.char('Name', size=64, translate=True),
-		'model': fields.char('Model', size=64, required=True),
+		'name': fields.char('Model name', size=64, translate=True),
+		'model': fields.char('Object name', size=64, required=True),
 		'info': fields.text('Information'),
 		'field_id': fields.one2many('ir.model.fields', 'model_id', 'Fields', required=True),
 	}
@@ -51,14 +51,12 @@ class ir_model_fields(osv.osv):
 	_name = 'ir.model.fields'
 	_columns = {
 		'name': fields.char('Name', size=64),
-#TODO: this field (model) should go away !!!! it's the same as model_id.name
-# note that it is at least used in osv/orm.py
 		'model': fields.char('Model Name', size=64, required=True),
 # on pourrait egalement changer ca en many2one, mais le prob c'est qu'alors faut
 # faire une jointure a chaque fois qu'on recherche vu que le client ne connait que le nom
 # de l'objet et pas son id
 		'relation': fields.char('Model Relation', size=64),
-		'model_id': fields.many2one('ir.model', 'Model id', required=True),
+		'model_id': fields.many2one('ir.model', 'Model id', required=True, select=True),
 # in fact, this is the field label
 		'field_description': fields.char('Field Description', size=256),
 		'ttype': fields.char('Field Type', size=64),
@@ -144,10 +142,10 @@ class ir_model_data(osv.osv):
 		'noupdate': lambda *a: False
 	}
 
-	def __init__(self):
-		osv.osv.__init__(self)
+	def __init__(self, pool):
+		osv.osv.__init__(self, pool)
 		self.loads = {}
-		self.init = True
+		self.doinit = True
 		self.unlink_mark = {}
 
 	def _get_id(self,cr, uid, module, xml_id):
@@ -165,16 +163,15 @@ class ir_model_data(osv.osv):
 			id = False
 		return id
 
-	def _update(self,cr, uid, model, module, values, xml_id=False, store=True, noupdate=False, mode='init'):
+	def _update(self,cr, uid, model, module, values, xml_id=False, store=True, noupdate=False, mode='init', res_id=False):
 		warning = True
 		if xml_id and ('.' in xml_id):
 			assert len(xml_id.split('.'))==2, '"%s" contains too many dots. XML ids should not contain dots ! These are used to refer to other modules data, as in module.reference_id' % (xml_id)
 			warning = False
 			module, xml_id = xml_id.split('.')
-		if (not xml_id) and (not self.init):
+		if (not xml_id) and (not self.doinit):
 			return False
 		action_id = False
-		res_id = False
 		if xml_id:
 			cr.execute('select id,res_id from ir_model_data where module=%s and name=%s', (module,xml_id))
 			results = cr.fetchall()
@@ -186,9 +183,13 @@ class ir_model_data(osv.osv):
 				else:
 					res_id,action_id = res_id2,action_id2
 
-		if action_id:
+		if action_id and res_id:
 			self.pool.get(model).write(cr, uid, [res_id], values)
 			self.write(cr, uid, [action_id], {'date_update': time.strftime('%Y-%m-%d %H:%M:%S')})
+		elif res_id:
+			self.pool.get(model).write(cr, uid, [res_id], values)
+			if xml_id:
+				self.create(cr, uid, {'name':xml_id, 'model':model, 'module':module, 'res_id':res_id, 'noupdate':noupdate})
 		else:
 			if mode=='init' or (mode=='update' and xml_id):
 				res_id = self.pool.get(model).create(cr, uid, values)
@@ -215,6 +216,7 @@ class ir_model_data(osv.osv):
 		else:
 			res_id=None
 			model = models[0]
+
 		if res_id:
 			where = ' and res_id=%d' % (res_id,)
 		else:
@@ -253,13 +255,12 @@ class ir_model_data(osv.osv):
 		cr.commit()
 		for (model,id) in self.unlink_mark.keys():
 			if self.pool.get(model):
-				cr2 = sql_db.db.cursor()
 				print 'Deleting %s@%s' % (id, model),
 				try:
-					self.pool.get(model).unlink(cr2, uid, [id])
+					self.pool.get(model).unlink(cr, uid, [id])
 					if self.unlink_mark[(model,id)]:
-						self.unlink(cr2, uid, [self.unlink_mark[(model,id)]])
-					cr2.commit()
+						self.unlink(cr, uid, [self.unlink_mark[(model,id)]])
+					cr.commit()
 					print '... ok'
 				except:
 					print '... ko'
@@ -267,7 +268,6 @@ class ir_model_data(osv.osv):
 					print 'WARNING: Could not delete id', id, 'of model', model
 					print '\tThere should be some relation that points to this resource'
 					print '\tYou should manually fix this and restart --update=module'
-				cr2.close()
 		return True
 ir_model_data()
 
