@@ -29,7 +29,7 @@
 import time, os
 
 import netsvc
-import report,sql_db,tools
+import report,pooler,tools
 
 
 def graph_get(cr, graph, wkf_id, nested=False, workitem={}):
@@ -112,7 +112,7 @@ def graph_instance_get(cr, graph, inst_id, nested=False):
 #
 
 class report_graph_instance(object):
-	def __init__(self, uid, ids, data):
+	def __init__(self, cr, uid, ids, data):
 		try:
 			import pydot
 		except Exception,e:
@@ -122,7 +122,6 @@ class report_graph_instance(object):
 		self.done = False
 
 		try:
-			cr = sql_db.db.cursor()
 			cr.execute('select * from wkf where osv=%s limit 1', (data['model'],))
 			wkfinfo = cr.dictfetchone()
 			cr.execute('select id from wkf_instance where res_id=%d and wkf_id=%d order by state limit 1', (data['id'],wkfinfo['id']))
@@ -144,7 +143,6 @@ showpage'''
 		input.close()
 		self.result = output.read()
 		output.close()
-		cr.close()
 		self.done = True
 
 	def is_done(self):
@@ -167,8 +165,8 @@ class report_graph(report.interface.report_int):
 		else:
 			return (False, False, False)
 
-	def create(self, uid, ids, data, context={}):
-		self.obj = report_graph_instance(uid, ids, data)
+	def create(self, cr, uid, ids, data, context={}):
+		self.obj = report_graph_instance(cr, uid, ids, data)
 		return (self.obj.get(), 'pdf')
 
 report_graph('report.workflow.instance.graph', 'ir.workflow')
