@@ -50,7 +50,7 @@ class wkf_activity(osv.osv):
 	_log_access = False
 	_columns = {
 		'name': fields.char('Name', size=64, required=True),
-		'wkf_id': fields.many2one('workflow', 'Workflow', required=True),
+		'wkf_id': fields.many2one('workflow', 'Workflow', required=True, select=True),
 		'split_mode': fields.selection([('XOR', 'Xor'), ('OR','Or'), ('AND','And')], 'Split Mode', size=3, required=True),
 		'join_mode': fields.selection([('XOR', 'Xor'), ('AND', 'And')], 'Join Mode', size=3, required=True),
 		'kind': fields.selection([('dummy', 'Dummy'), ('function', 'Function'), ('subflow', 'Subflow'), ('stopall', 'Stop All')], 'Kind', size=64, required=True),
@@ -80,8 +80,8 @@ class wkf_transition(osv.osv):
 		'signal': fields.char('Signal (button Name)', size=64),
 		'role_id': fields.many2one('res.roles', 'Role Required'),
 		'condition': fields.char('Condition', required=True, size=128),
-		'act_from': fields.many2one('workflow.activity', 'Source Activity', required=True),
-		'act_to': fields.many2one('workflow.activity', 'Destination Activity', required=True),
+		'act_from': fields.many2one('workflow.activity', 'Source Activity', required=True, select=True),
+		'act_to': fields.many2one('workflow.activity', 'Destination Activity', required=True, select=True),
 	}
 	_defaults = {
 		'condition': lambda *a: 'True',
