@@ -56,15 +56,17 @@ class module_category(osv.osv):
 	_description = "Module Category"
 	
 	def _module_nbr(self,cr,uid, ids, prop, unknow_none,context):
-		cr.execute('select category_id,count(*) from ir_module_module where category_id in ('+','.join(map(str,ids))+') group by category_id')
+		cr.execute('select category_id,count(*) from ir_module_module where category_id in ('+','.join(map(str,ids))+') or category_id in (select id from ir_module_category where parent_id in ('+','.join(map(str,ids))+')) group by category_id')
 		result = dict(cr.fetchall())
 		for id in ids:
-			result.setdefault(id, 0)
+			cr.execute('select id from ir_module_category where parent_id=%d', (id,))
+			childs = [c for c, in cr.fetchall()]
+			result[id] = reduce(lambda x,y:x+y, [result.get(c, 0) for c in childs], result.get(id, 0))
 		return result
 		
 	_columns = {
 		'name': fields.char("Name", size=128, required=True),
-		'parent_id': fields.many2one('ir.module.category', 'Parent Category'),
+		'parent_id': fields.many2one('ir.module.category', 'Parent Category', select=True),
 		'child_ids': fields.one2many('ir.module.category', 'parent_id', 'Parent Category'),
 		'module_nr': fields.function(_module_nbr, method=True, string='# of Modules', type='integer')
 	}
@@ -92,23 +94,59 @@ class module(osv.osv):
 		'latest_version': fields.char('Latest version', size=64, readonly=True),
 		'url': fields.char('URL', size=128, readonly=True),
 		'dependencies_id': fields.one2many('ir.module.module.dependency', 'module_id', 'Dependencies'),
-		'state': fields.selection([('uninstalled','Uninstalled'),('installed','Installed'),('to upgrade','to upgrade'),('to remove','to remove'),('to install','to install')], string='State', readonly=True),
+		'state': fields.selection([
+			('uninstallable','Uninstallable'),
+			('uninstalled','Not Installed'),
+			('installed','Installed'),
+			('to upgrade','To be upgraded'),
+			('to remove','To be removed'),
+			('to install','To be installed')
+		], string='State', readonly=True),
+		'demo': fields.boolean('Demo data'),
 	}
 	
 	_defaults = {
-		'state': lambda *a: 'uninstalled'
+		'state': lambda *a: 'uninstalled',
+		'demo': lambda *a: False,
 	}
 	_order = 'name'
-	
-	def button_install(self, cr, uid, ids, context={}):
-		self.write(cr, uid, ids, {'state': 'to install'})
+
+	def state_change(self, cr, uid, ids, newstate, context={}, level=50):
+		if level<1:
+			raise 'Recursion error in modules dependencies !'
+		ids_dest = []
+		for module in self.browse(cr, uid, ids):
+			for dep in module.dependencies_id:
+				ids2 = self.search(cr, uid, [('name','=',dep.name)])
+				for id in ids2:
+					if (id not in ids_dest):
+						ids_dest.append(id)
+			if module.state=='uninstalled':
+				self.write(cr, uid, [module.id], {'state': newstate})
+		if ids_dest:
+			self.state_change(cr, uid, ids_dest, newstate, context, level-1)
+
+		for module in self.browse(cr, uid, ids):
+			if module.state!='installed':
+				demo=True
+				for dep in module.dependencies_id:
+					ids2 = self.search(cr, uid, [('name', '=', dep.name)])
+					for module2 in self.browse(cr, uid, ids2):
+						demo = demo and module2.demo
+				self.write(cr, uid, [module.id], {'demo':demo})
 		return True
+
+	def button_install(self, cr, uid, ids, context={}):
+		return self.state_change(cr, uid, ids, 'to install', context)
+
 	def button_install_cancel(self, cr, uid, ids, context={}):
 		self.write(cr, uid, ids, {'state': 'uninstalled'})
 		return True
+
 	def button_uninstall(self, cr, uid, ids, context={}):
 		self.write(cr, uid, ids, {'state': 'to remove'})
 		return True
+
 	def button_remove_cancel(self, cr, uid, ids, context={}):
 		self.write(cr, uid, ids, {'state': 'installed'})
 		return True
@@ -215,9 +253,9 @@ class module_dependency(osv.osv):
 	_description = "Module dependency"
 	_columns = {
 		'name': fields.char('Name',  size=128),
-		'module_id': fields.many2one('ir.module.module', 'Module'),
-		'module_dest_id': fields.many2one('ir.module.module', 'Module'),
-		'version_pattern': fields.char('Version pattern', size=128),
+		'module_id': fields.many2one('ir.module.module', 'Module', select=True),
+		#'module_dest_id': fields.many2one('ir.module.module', 'Module'),
+		'version_pattern': fields.char('Required Version', size=128),
 	}
 	# returns the ids of module version records which match all dependencies
 	# [version_id, ...]
