@@ -45,12 +45,12 @@ additional_changes_fields = {
 class wizard_install_module(wizard.interface):
 	def _get_value(self, cr, uid, data, context):
 		service = netsvc.LocalService("object_proxy")
-		extra = service.execute(uid, 'ir.module.module', 'get_extra_modules', data['ids'])
+		extra = service.execute(cr.dbname, uid, 'ir.module.module', 'get_extra_modules', data['ids'])
 		return {'additional': extra}
 
 	def _install_module(self, cr, uid, data, context):
 		service = netsvc.LocalService("object_proxy")
-		res = service.execute(uid, 'ir.module.module', 'install', data['ids'])
+		res = service.execute(cr.dbname, uid, 'ir.module.module', 'install', data['ids'])
 		return {}
 
 	states = {
