@@ -33,7 +33,7 @@ import netsvc
 class wizard_update_module(wizard.interface):
 	def _update_module(self, cr, uid, data, context):
 		service = netsvc.LocalService("object_proxy")
-		service.execute(uid, 'ir.module.module', 'update_list')
+		service.execute(cr.dbname, uid, 'ir.module.module', 'update_list')
 		return {}
 
 	def _action_module_open(self, cr, uid, data, context):
