@@ -49,7 +49,7 @@ sms_send_fields = {
 
 def _sms_send(self, cr, uid, data, context):
 	service = netsvc.LocalService("object_proxy")
-	res = service.execute(uid, 'res.partner', 'read', data['ids'], ['gsm'])
+	res = service.execute(cr.dbname, uid, 'res.partner', 'read', data['ids'], ['gsm'])
 
 	nbr = 0
 	for r in res:
