@@ -4,9 +4,11 @@
 	"author" : "Tiny",
 	"category" : "Generic Modules/Human Resources",
 	"website" : "http://tinyerp.com/module_hr.html",
-	"depends" : ["base","account"],
+	"description": "Module for human ressource management",
+	"depends" : ["base"],
 	"init_xml" : [],
 	"demo_xml" : ["hr_demo.xml", "hr_bel_holidays_2005.xml"],
-	"update_xml" : ["hr_workflow.xml", "hr_view.xml", "hr_report.xml", "hr_wizard.xml"],
-	"active": True
+	"update_xml" : ["hr_view.xml", "hr_report.xml", "hr_wizard.xml"],
+	"active": False,
+	"installable": True
 }
