@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2005-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: sign_in_out.py 2871 2006-04-25 14:08:22Z ged $
+# $Id: sign_in_out.py 4291 2006-10-24 09:29:19Z ged $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -64,9 +64,9 @@ so_fields = {
 
 def _get_empid(self, cr, uid, data, context):
 	service = netsvc.LocalService('object_proxy')
-	emp_id = service.execute(uid, 'hr.employee', 'search', [('user_id', '=', uid)])
+	emp_id = service.execute(cr.dbname, uid, 'hr.employee', 'search', [('user_id', '=', uid)])
 	if emp_id:
-		employee = service.execute(uid, 'hr.employee', 'read', emp_id)[0]
+		employee = service.execute(cr.dbname, uid, 'hr.employee', 'read', emp_id)[0]
 		return {'name': employee['name'], 'state': employee['state'], 'emp_id': emp_id[0]}
 	return {}
 
@@ -74,13 +74,13 @@ def _sign_in(self, cr, uid, data, context):
 	service = netsvc.LocalService('object_proxy')
 	emp_id = data['form']['emp_id']
 	if 'last_time' in data['form']:
-		service.execute(uid, 'hr.attendance', 'create', {
+		service.execute(cr.dbname, uid, 'hr.attendance', 'create', {
 			'name': data['form']['last_time'], 
 			'action': 'sign_out',
 			'employee_id': emp_id
 		})
 	try:
-		success = service.execute(uid, 'hr.employee', 'sign_in', [emp_id])
+		success = service.execute(cr.dbname, uid, 'hr.employee', 'sign_in', [emp_id])
 	except:
 		raise wizard.except_wizard('UserError', 'A sign-in must be right after a sign-out !')
 	return {'success': success}
@@ -89,9 +89,9 @@ def _sign_out(self, cr, uid, data, context):
 	service = netsvc.LocalService('object_proxy')
 	emp_id = data['form']['emp_id']
 	if 'last_time' in data['form']:
-		service.execute(uid, 'hr.attendance', 'create', {'name':data['form']['last_time'], 'action':'sign_in',  'employee_id':emp_id})
+		service.execute(cr.dbname, uid, 'hr.attendance', 'create', {'name':data['form']['last_time'], 'action':'sign_in',  'employee_id':emp_id})
 	try:
-		success = service.execute(uid, 'hr.employee', 'sign_out', [emp_id])
+		success = service.execute(cr.dbname, uid, 'hr.employee', 'sign_out', [emp_id])
 	except:
 		raise wizard.except_wizard('UserError', 'A sign-out must be right after a sign-in !')
 
@@ -113,8 +113,8 @@ def _si_check(self, cr, uid, data, context):
 	states = {True : 'si', False: 'si_ask_so'}
 	service = netsvc.LocalService('object_proxy')
 	emp_id = data['form']['emp_id']
-	att_id = service.execute(uid, 'hr.attendance', 'search', [('employee_id', '=', emp_id)], limit=1, order='name desc')
-	last_att = service.execute(uid, 'hr.attendance', 'read', att_id)
+	att_id = service.execute(cr.dbname, uid, 'hr.attendance', 'search', [('employee_id', '=', emp_id)], limit=1, order='name desc')
+	last_att = service.execute(cr.dbname, uid, 'hr.attendance', 'read', att_id)
 	if last_att:
 		last_att = last_att[0]
 	cond = not last_att or last_att['action'] == 'sign_out'
@@ -136,8 +136,8 @@ def _so_check(self, cr, uid, data, context):
 	states = {True : 'so', False: 'so_ask_si'}
 	service = netsvc.LocalService('object_proxy')
 	emp_id = data['form']['emp_id']
-	att_id = service.execute(uid, 'hr.attendance', 'search', [('employee_id', '=', emp_id)], limit=1, order='name desc')
-	last_att = service.execute(uid, 'hr.attendance', 'read', att_id)
+	att_id = service.execute(cr.dbname, uid, 'hr.attendance', 'search', [('employee_id', '=', emp_id)], limit=1, order='name desc')
+	last_att = service.execute(cr.dbname, uid, 'hr.attendance', 'read', att_id)
 	if last_att:
 		last_att = last_att[0]
 	cond = last_att and last_att['action'] == 'sign_in'
