@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: hr_timesheet.py 3802 2006-08-11 08:37:58Z pinky $
+# $Id: hr_timesheet.py 4525 2006-11-10 08:59:57Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -36,19 +36,17 @@ class hr_employee(osv.osv):
 	_name = "hr.employee"
 	_inherit = "hr.employee"
 	_columns = {
-		'amount_unit_id': fields.many2one('account.analytic.unittype', 'Cost Unit'),
+		'product_id': fields.many2one('product.product', 'Product'),
+		'journal_id': fields.many2one('account.analytic.journal', 'Analytic Journal')
 	}
 hr_employee()
 
 
 class hr_analytic_timesheet(osv.osv):
 	_name = "hr.analytic.timesheet"
-	
 	_table = 'hr_analytic_timesheet'
 	_inherits = {'account.analytic.line': 'line_id'}
-
 	_columns = {
-		'user_id' : fields.many2one('res.users', 'User', required=True),
 		'line_id' : fields.many2one('account.analytic.line', 'Analytic line', ondelete='cascade'),
 	}
 
@@ -59,14 +57,21 @@ class hr_analytic_timesheet(osv.osv):
 		self.pool.get('account.analytic.line').unlink(cr, uid, toremove.keys(), context)
 		return super(hr_analytic_timesheet, self).unlink(cr, uid, ids, context)
 
-	def on_change_unit_amount(self, cr, uid, id, unit, unit_amount, context={}):
-		return self.pool.get('account.analytic.line').on_change_unit_amount(cr, uid, id, unit, unit_amount, context)
+	def on_change_unit_amount(self, cr, uid, id, prod_id, unit_amount, unit, context={}):
+		return self.pool.get('account.analytic.line').on_change_unit_amount(cr, uid, id, prod_id, unit_amount,unit, context)
+
+	def _getEmployeeProduct(self, cr, uid, context):
+		emp_obj = self.pool.get('hr.employee')
+		emp_id = emp_obj.search(cr, uid, [('user_id', '=', uid)])
+		if emp_id:
+			return emp_obj.browse(cr, uid, emp_id[0], context).product_id.id
+		return False
 
 	def _getEmployeeUnit(self, cr, uid, context):
 		emp_obj = self.pool.get('hr.employee')
 		emp_id = emp_obj.search(cr, uid, [('user_id', '=', uid)])
 		if emp_id:
-			return emp_obj.browse(cr, uid, emp_id[0], context).amount_unit_id.id
+			return emp_obj.browse(cr, uid, emp_id[0], context).product_id.uom_id.id
 		return False
 
 	def _getGeneralAccount(self, cr, uid, context):
@@ -74,8 +79,11 @@ class hr_analytic_timesheet(osv.osv):
 		emp_id = emp_obj.search(cr, uid, [('user_id', '=', uid)])
 		if emp_id:
 			emp = self.pool.get('hr.employee').browse(cr, uid, emp_id[0], context=context)
-			if bool(emp.amount_unit_id):
-				return emp.amount_unit_id.general_account_id.id
+			if bool(emp.product_id):
+				a =  emp.product_id.product_tmpl_id.property_account_income
+				if not a:
+					a = emp.product_id.categ_id.property_account_income_categ
+				return a[0]
 		return False
 
 	def _getAnalyticJournal(self, cr, uid, context):
@@ -83,13 +91,14 @@ class hr_analytic_timesheet(osv.osv):
 		emp_id = emp_obj.search(cr, uid, [('user_id', '=', uid)])
 		if emp_id:
 			emp = self.pool.get('hr.employee').browse(cr, uid, emp_id[0], context=context)
-			if emp.amount_unit_id:
-				return emp.amount_unit_id.journal_id.id
+			if emp.journal_id:
+				return emp.journal_id.id
 		return False
 
 
 	_defaults = {
-		'unit_id' : _getEmployeeUnit,
+		'product_uom_id' : _getEmployeeUnit,
+		'product_id' : _getEmployeeProduct,
 		'general_account_id' : _getGeneralAccount,
 		'journal_id' : _getAnalyticJournal,
 		'user_id' : lambda obj, cr, uid, ctx : uid,
