@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: user_timesheet.py 3857 2006-08-22 07:25:11Z pinky $
+# $Id: user_timesheet.py 4525 2006-11-10 08:59:57Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -28,12 +28,6 @@
 ##############################################################################
 
 import datetime
-import netsvc, tools
-import sql_db
-
-import report.print_xml
-import report.render
-import report.common
 
 from report.interface import report_rml
 from report.interface import toxml 
@@ -44,8 +38,7 @@ def lengthmonth(year, month):
 	return [0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31][month]
 
 class report_custom(report_rml):
-	def create_xml(self, uid, ids, data, context):
-		cr = sql_db.db.cursor()
+	def create_xml(self, cr, uid, ids, data, context):
 
 		# Computing the dates (start of month: som, and end of month: eom)
 		som = datetime.date(data['form']['year'], data['form']['month'], 1)
@@ -59,10 +52,10 @@ class report_custom(report_rml):
 		cr.execute(
 			"select line.date, (unit_amount * unit.factor) as amount, account_id, account.name "\
 			"from account_analytic_line as line, hr_analytic_timesheet as hr, "\
-			"account_analytic_account as account, account_analytic_unittype as unit "\
+			"account_analytic_account as account, product_uom as unit "\
 			"where hr.line_id=line.id and line.account_id=account.id "\
-			"and unit_id = unit.id "\
-			"and hr.user_id=%d and line.date >= %s and line.date < %s "
+			"and product_uom_id = unit.id "\
+			"and line.user_id=%d and line.date >= %s and line.date < %s "
 			"order by line.date",
 			(data['form']['user_id'], som.strftime('%Y-%m-%d'), eom.strftime('%Y-%m-%d')))
 
@@ -88,7 +81,6 @@ class report_custom(report_rml):
 		# Computing the employee
 		cr.execute("select name from res_users where id=%d", (data['form']['user_id'],))
 		emp = cr.fetchone()[0]
-		cr.close()
 
 		# Computing the xml
 		xml = '''<?xml version="1.0" encoding="UTF-8" ?>
