@@ -2,10 +2,11 @@
 	"name" : "Localisation for Quebec",
 	"version" : "1.0",
 	"author" : "Tiny",
-	"category" : "Localisation/North America",
+	"category" : "Localisation/Account charts",
 	"depends" : ["base", "account"],
 	"init_xml" : [],
 	"demo_xml" : ["account_demo.xml"],
 	"update_xml" : ["account_pc_canada.xml"],
-	"active": False
+	"active": False,
+	"installable": True
 }
