@@ -1,11 +1,12 @@
 {
-	"name" : "Localisation sample", # based on belgium files
+	"name" : "Simple account chart",
 	"version" : "1.0",
 	"author" : "Tiny",
 	"category" : "Localisation/Europe",
 	"depends" : ["account"],
 	"init_xml" : [],
-	"demo_xml" : ["account_demo.xml"],
+	"demo_xml" : ["account_demo.xml","account.analytic.line.csv"],
 	"update_xml" : ["account_pcmn_belgium.xml"],
-	"active": True
+	"active": False,
+	"installable": True
 }
