@@ -3,10 +3,12 @@
 	"version" : "1.0",
 	"author" : "Tiny",
 	"website" : "http://tinyerp.com/module_crm_marketing.html",
-	"category" : "Generic Modules/Marketing Operations",
+	"category" : "Generic Modules/Others",
 	"depends" : ["base"],
+	"description": "Marketing management module",
 	"init_xml" : [],
 	"demo_xml" : ["campaign/campaign_demo.xml"],
 	"update_xml" : ["campaign/campaign_view.xml", "campaign/campaign_wizard.xml"],
-	"active": True
+	"active": False,
+	"installable": True
 }
