@@ -128,7 +128,7 @@ class mrp_routing_workcenter(osv.osv):
 		'sequence': fields.integer('Sequence'),
 		'cycle_nbr': fields.float('Number of cycle', required=True),
 		'hour_nbr': fields.float('Number of hours', required=True),
-		'routing_id': fields.many2one('mrp.routing', 'Parent Routing'),
+		'routing_id': fields.many2one('mrp.routing', 'Parent Routing', select=True),
 		'note': fields.text('Description')
 	}
 	_defaults = {
@@ -161,7 +161,7 @@ class mrp_bom(osv.osv):
 		'product_efficiency': fields.float('Product Efficiency', required=True),
 
 		'bom_lines': fields.one2many('mrp.bom', 'bom_id', 'BoM Lines'),
-		'bom_id': fields.many2one('mrp.bom', 'Parent BoM', ondelete='cascade'),
+		'bom_id': fields.many2one('mrp.bom', 'Parent BoM', ondelete='cascade', select=True),
 
 		'routing_id': fields.many2one('mrp.routing', 'Routing', help="The list of operations (list of workcenters) to produce the finnished product. The routing is mainly used to compute workcenter costs during operations and to plan futur loads on workcenters based on production plannification."),
 
@@ -181,6 +181,19 @@ class mrp_bom(osv.osv):
 	_sql_constraints = [
 		('bom_qty_zero', 'CHECK (product_qty>0)',  'All product quantities must be greater than 0 !'),
 	]
+	def _check_recursion(self, cr, uid, ids):
+		level = 500
+		while len(ids):
+			cr.execute('select distinct bom_id from mrp_bom where id in ('+','.join(map(str,ids))+')')
+			ids = filter(None, map(lambda x:x[0], cr.fetchall()))
+			if not level:
+				return False
+			level -= 1
+		return True
+	_constraints = [
+		(_check_recursion, 'Error ! You can not create recursive BoM.', ['parent_id'])
+	]
+
 	
 	def onchange_product_id(self, cr, uid, ids, product_id, name, context={}):
 		if product_id:
@@ -275,7 +288,7 @@ class mrp_bom_revision(osv.osv):
 		'indice': fields.char('Revision', size=16),
 		'last_indice': fields.char('last indice', size=64),
 		'author_id': fields.many2one('res.users', 'Author'),
-		'bom_id': fields.many2one('mrp.bom', 'BoM'),
+		'bom_id': fields.many2one('mrp.bom', 'BoM', select=True),
 	}
 	
 	_defaults = {
@@ -298,7 +311,7 @@ class mrp_production(osv.osv):
 		'origin': fields.char('Origin', size=64),
 		'priority': fields.selection([('0','Not urgent'),('1','Normal'),('2','Urgent'),('3','Very Urgent')], 'Priority'),
 
-		'product_id': fields.many2one('product.product', 'Product', required=True, domain=[('type','=','product')]),
+		'product_id': fields.many2one('product.product', 'Product', required=True, domain=[('type','<>','service')]),
 		'product_qty': fields.float('Product Qty', required=True),
 		'product_uom': fields.many2one('product.uom', 'Product UOM'),
 
@@ -313,9 +326,9 @@ class mrp_production(osv.osv):
 
 		'picking_id': fields.many2one('stock.picking', 'Picking list'),
 		'move_prod_id': fields.many2one('stock.move', 'Move Product'),
-		'move_created_id': fields.many2one('stock.move', 'Move Created'),
-		'move_lines': fields.many2many('stock.move', 'mrp_production_move_ids', 'production_id', 'move_id', 'Moves'),
+		'move_lines': fields.many2many('stock.move', 'mrp_production_move_ids', 'production_id', 'move_id', 'Products Consummed'),
 
+		'move_created_ids': fields.one2many('stock.move', 'production_id', 'Moves Created'),
 		'product_lines': fields.one2many('mrp.production.product.line', 'production_id', 'Material Planned'),
 		'workcenter_lines': fields.one2many('mrp.production.workcenter.line', 'production_id', 'Workcenters Utilisation'),
 
@@ -325,6 +338,7 @@ class mrp_production(osv.osv):
 		'priority': lambda *a: '1',
 		'state': lambda *a: 'draft',
 		'product_qty':  lambda *a: 1.0,
+		'name': lambda x,y,z,c: x.pool.get('ir.sequence').get(y,z,'mrp.production') or '/',
 	}
 	_order = 'date_planned desc, priority desc';
 	def product_id_change(self, cr, uid, ids, product):
@@ -351,10 +365,13 @@ class mrp_production(osv.osv):
 				self.write(cr, uid, [production.id], {'bom_id': bom_id})
 				bom_point = self.pool.get('mrp.bom').browse(cr, uid, [bom_id])[0]
 
+			if not bom_id:
+				raise osv.except_osv('Error', "Couldn't find bill of material for product")
+
 			if bom_point.routing_id and bom_point.routing_id.location_id:
 				self.write(cr, uid, [production.id], {'location_src_id': bom_point.routing_id.location_id.id})
 
-			factor = production.product_qty
+			factor = production.product_qty * production.product_uom.factor / bom_point.product_uom.factor
 			res = self.pool.get('mrp.bom')._bom_explode(cr, uid, bom_point, factor / bom_point.product_qty, properties)
 			results = res[0]
 			results2 = res[1]
@@ -368,8 +385,8 @@ class mrp_production(osv.osv):
 
 	def action_cancel(self, cr, uid, ids):
 		for production in self.browse(cr, uid, ids):
-			if production.move_created_id.id:
-				self.pool.get('stock.move').action_cancel(cr, uid, [production.move_created_id.id])
+			if production.move_created_ids:
+				self.pool.get('stock.move').action_cancel(cr, uid, [x.id for x in production.move_created_ids])
 			self.pool.get('stock.move').action_cancel(cr, uid, [x.id for x in production.move_lines])
 		self.write(cr, uid, ids, {'state':'cancel','move_lines':[(6,0,[])]})
 		return True
@@ -389,12 +406,16 @@ class mrp_production(osv.osv):
 		move_ids = []
 		for production in self.browse(cr, uid, ids):
 			for res in production.move_lines:
-				cr.execute('insert into stock_move_history_ids (parent_id,child_id) values (%d,%d)', (res.id, production.move_created_id.id))
+				for move in production.move_created_ids:
+					cr.execute('insert into stock_move_history_ids (parent_id,child_id) values (%d,%d)', (res.id, move.id))
 				move_ids.append(res.id)
-			if production.move_created_id:
-				vals= {'state':'confirmed', 'product_uom': production.product_uom.id, 'product_id': production.product_id.id, 'product_qty':production.product_qty}
-				self.pool.get('stock.move').write(cr, uid, [production.move_created_id.id], vals)
+			if production.move_created_ids:
+				# There we should handle the residus move creation
+				vals= {'state':'confirmed'}
+				new_moves = [x.id for x in production.move_created_ids]
+				self.pool.get('stock.move').write(cr, uid, new_moves, vals)
 			else:
+				# Why is it there ? Aren't we suppose to already have a created_move ?
 				source = production.product_id.product_tmpl_id.property_stock_production[0]
 				vals = {
 					'name':'PROD:'+production.name,
@@ -407,10 +428,10 @@ class mrp_production(osv.osv):
 					'move_dest_id': production.move_prod_id.id,
 					'state': 'confirmed'
 				}
-				production.move_created_id.id = self.pool.get('stock.move').create(cr, uid, vals)
-				self.write(cr, uid, [production.id], {'move_created_id': production.move_created_id.id})
-			self.pool.get('stock.move').check_assign(cr, uid, [production.move_created_id.id])
-			self.pool.get('stock.move').action_done(cr, uid, [production.move_created_id.id])
+				new_moves = [self.pool.get('stock.move').create(cr, uid, vals)]
+				self.write(cr, uid, [production.id], {'move_created_ids': [(6, 'WTF', new_moves)]})
+			self.pool.get('stock.move').check_assign(cr, uid, new_moves)
+			self.pool.get('stock.move').action_done(cr, uid, new_moves)
 			self._costs_generate(cr, uid, production)
 		self.pool.get('stock.move').action_done(cr, uid, move_ids)
 		self.write(cr,  uid, ids, {'state':'done'})
@@ -472,7 +493,7 @@ class mrp_production(osv.osv):
 				self.action_compute(cr, uid, [production.id])
 				production = self.browse(cr, uid, [production.id])[0]
 			picking_id = self.pool.get('stock.picking').create(cr, uid, {
-				'origin': 'PROD:%d:%s' % (production.id, production.name),
+				'origin': (production.origin or '') +':'+production.name,
 				'type': 'internal',
 				'move_type': 'one',
 				'state': 'auto',
@@ -497,12 +518,12 @@ class mrp_production(osv.osv):
 			}
 			res_final_id = self.pool.get('stock.move').create(cr, uid, data)
 			
-			self.write(cr, uid, [production.id], {'move_created_id':res_final_id})
+			self.write(cr, uid, [production.id], {'move_created_ids': [(6, 'WTF', [res_final_id])]})
 			moves = []
 			for line in production.product_lines:
 				move_id=False
 				newdate = production.date_planned
-				if line.product_id.type=='product':
+				if line.product_id.type in ('product', 'consu'):
 					res_dest_id = self.pool.get('stock.move').create(cr, uid, {
 						'name':'PROD:'+production.name,
 						'date_planned': production.date_planned,
@@ -528,8 +549,8 @@ class mrp_production(osv.osv):
 						'state': 'waiting',
 					})
 				proc_id = self.pool.get('mrp.procurement').create(cr, uid, {
-					'name': 'PROC:'+production.name,
-					'origin': 'PROD:'+str(production.id)+':'+production.name,
+					'name': production.name+':'+ (production.origin or ''),
+					'origin': production.name+':'+ (production.origin or ''),
 					'date_planned': newdate,
 					'product_id': line.product_id.id,
 					'product_qty': line.product_qty,
@@ -553,6 +574,15 @@ class mrp_production(osv.osv):
 
 mrp_production()
 
+class stock_move(osv.osv):
+	_name = 'stock.move'
+	_inherit = 'stock.move'
+
+	_columns = {
+			'production_id': fields.many2one('mrp.production', 'Production', select=True),
+			}
+stock_move()
+
 class mrp_production_workcenter_line(osv.osv):
 	_name = 'mrp.production.workcenter.line'
 	_description = 'Production workcenters used'
@@ -562,7 +592,7 @@ class mrp_production_workcenter_line(osv.osv):
 		'cycle': fields.float('Nbr of cycle'),
 		'hour': fields.float('Nbr of hour'),
 		'sequence': fields.integer('Sequence', required=True),
-		'production_id': fields.many2one('mrp.production', 'Production Order'),
+		'production_id': fields.many2one('mrp.production', 'Production Order', select=True),
 	}
 	_defaults = {
 		'sequence': lambda *a: 1,
@@ -579,7 +609,7 @@ class mrp_production_product_line(osv.osv):
 		'product_id': fields.many2one('product.product', 'Product', required=True),
 		'product_qty': fields.float('Product Qty', required=True),
 		'product_uom': fields.many2one('product.uom', 'Product UOM', required=True),
-		'production_id': fields.many2one('mrp.production', 'Production Order'),
+		'production_id': fields.many2one('mrp.production', 'Production Order', select=True),
 	}
 mrp_production_product_line()
 
@@ -623,7 +653,7 @@ class mrp_procurement(osv.osv):
 	}
 	def check_product(self, cr, uid, ids):
 		for procurement in self.browse(cr, uid, ids):
-			if procurement.product_id.type=='product':
+			if procurement.product_id.type in ('product', 'consu'):
 				return True
 		return False
 
@@ -717,7 +747,7 @@ class mrp_procurement(osv.osv):
 
 	def action_confirm(self, cr, uid, ids):
 		for procurement in self.browse(cr, uid, ids):
-			if procurement.product_id.type=='product':
+			if procurement.product_id.type in ('product', 'consu'):
 				if not procurement.move_id:
 					source = procurement.location_id.id
 					if procurement.procure_method=='make_to_order':
@@ -770,8 +800,8 @@ class mrp_procurement(osv.osv):
 			loc_id = procurement.location_id.id
 			newdate = DateTime.strptime(procurement.date_planned, '%Y-%m-%d') - DateTime.RelativeDateTime(days=procurement.product_id.product_tmpl_id.produce_delay or 0.0)
 			produce_id = self.pool.get('mrp.production').create(cr, uid, {
-				'name': procurement.name,
-				'origin': 'PROC:'+str(procurement.id)+':'+procurement.name,
+				#'name': procurement.name,
+				'origin': procurement.origin,
 				'product_id': procurement.product_id.id,
 				'product_qty': procurement.product_qty,
 				'product_uom': procurement.product_uom.id,
@@ -794,14 +824,21 @@ class mrp_procurement(osv.osv):
 			partner_id = partner.id
 			address_id = self.pool.get('res.partner').address_get(cr, uid, [partner_id], ['delivery'])['delivery']
 			pricelist_id = partner.property_product_pricelist_purchase[0]
-			price = self.pool.get('product.pricelist').price_get(cr, uid, [pricelist_id], procurement.product_id.id, procurement.product_qty, {'uom': procurement.product_uom.id})[pricelist_id]
+
+			uom_id = procurement.product_id.uom_po_id.id
+
+			qty = self.pool.get('product.uom')._compute_qty(cr, uid, procurement.product_uom.id, procurement.product_qty, uom_id)
+			if procurement.product_id.seller_ids[0].qty:
+				qty=max(qty,procurement.product_id.seller_ids[0].qty)
+
+			price = self.pool.get('product.pricelist').price_get(cr, uid, [pricelist_id], procurement.product_id.id, qty, False, {'uom': uom_id})[pricelist_id]
 
 			newdate = DateTime.strptime(procurement.date_planned, '%Y-%m-%d') - DateTime.RelativeDateTime(days=procurement.product_id.product_tmpl_id.seller_delay or 0.0)
 			line = {
 				'name': procurement.product_id.name,
-				'product_qty': procurement.product_qty,
+				'product_qty': qty,
 				'product_id': procurement.product_id.id,
-				'product_uom': procurement.product_uom.id,
+				'product_uom': uom_id,
 				'price_unit': price,
 				'date_planned': newdate.strftime('%Y-%m-%d'),
 				'taxes_id': [(6, 0, [x.id for x in procurement.product_id.product_tmpl_id.taxes_id])],
@@ -809,7 +846,7 @@ class mrp_procurement(osv.osv):
 			}
 
 			purchase_id = self.pool.get('purchase.order').create(cr, uid, {
-				'origin': 'PROC:'+str(procurement.id)+':'+str(procurement.name),
+				'origin': procurement.origin,
 				'partner_id': partner_id,
 				'partner_address_id': address_id,
 				'location_id': procurement.location_id.id,
@@ -866,8 +903,8 @@ class stock_warehouse_orderpoint(osv.osv):
 		'name': fields.char('Name', size=32, required=True),
 		'active': fields.boolean('Active'),
 		'logic': fields.selection([('max','Order to Max'),('price','Best price (not yet active!)')], 'Reordering Mode', required=True),
-		'warehouse_id': fields.many2one('stock.warehouse', 'Warehouse', required=True ),
-		'product_id': fields.many2one('product.product', 'Product', required=True, domain=[('type','=','product')] ),
+		'warehouse_id': fields.many2one('stock.warehouse', 'Warehouse', required=True, relate=True),
+		'product_id': fields.many2one('product.product', 'Product', required=True, domain=[('type','=','product')], relate=True),
 		'product_uom': fields.many2one('product.uom', 'Product UOM', required=True ),
 		'product_min_qty': fields.float('Min Quantity', required=True),
 		'product_max_qty': fields.float('Max Quantity', required=True),
@@ -877,7 +914,8 @@ class stock_warehouse_orderpoint(osv.osv):
 	_defaults = {
 		'active': lambda *a: 1,
 		'logic': lambda *a: 'max',
-		'qty_multiple': lambda *a: 1
+		'qty_multiple': lambda *a: 1,
+		'name': lambda x,y,z,c: x.pool.get('ir.sequence').get(y,z,'mrp.warehouse.orderpoint') or '',
 	}
 	def onchange_product_id(self, cr, uid, ids, product_id, context={}):
 		if product_id:
