@@ -1,8 +1,7 @@
 # -*-encoding: iso8859-1 -*-
 ##############################################################################
 #
-# Copyright (c) 2004 TINY SPRL. (http://tiny.be) All Rights Reserved.
-#                    Fabien Pinckaers <fp@tiny.Be>
+# Copyright (c) 2005-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -27,24 +26,22 @@
 #
 ##############################################################################
 
-import sql_db
 import ir
-from osv.osv import osv_pools
+import pooler
 from report.interface import report_rml
 from report.interface import toxml
 
 
 #FIXME: we should use toxml
 class report_custom(report_rml):
-	def create_xml(self, uid, ids, datas, context={}):
-		cr = sql_db.db.cursor()
+	def create_xml(self, cr, uid, ids, datas, context={}):
 		number = (datas.get('form', False) and datas['form']['number']) or 1
 		
 		def process_bom(bom):
 			xml = '<row>'
 			sum = 0
 			sum_strd = 0
-			prod = osv_pools.get('product.product').browse(cr, uid, bom['product_id'])
+			prod = pooler.get_pool(cr.dbname).get('product.product').browse(cr, uid, bom['product_id'])
 
 			prod_name = bom['name']
 			prod_qtty = bom['product_qty']
@@ -56,8 +53,12 @@ class report_custom(report_rml):
 			main_strd_price = ''
 			if prod.seller_ids and prod.seller_ids[0] :
 				main_sp_name = '<b>' + prod.seller_ids[0].name.name + '</b>\r\n'
-				pricelist_id = ir.ir_get(cr,uid,'meta','product.pricelist.purchase',[('res.partner',prod.seller_ids[0].name.id)])[0][2]
-				price = osv_pools.get('product.pricelist').price_get(cr,uid,[pricelist_id], prod.id, number*prod_qtty or 1.0)[pricelist_id]
+				pricelist = ir.ir_get(cr,uid,'meta','product.pricelist.purchase',[('res.partner',prod.seller_ids[0].name.id)])
+				if pricelist:
+					pricelist_id = pricelist[0][2]
+					price = pooler.get_pool(cr.dbname).get('product.pricelist').price_get(cr,uid,[pricelist_id], prod.id, number*prod_qtty or 1.0)[pricelist_id]
+				else:
+					price = 0
 				main_sp_price = str(price) + '\r\n'
 				sum += prod_qtty*price
 
@@ -68,8 +69,12 @@ class report_custom(report_rml):
 			sellers_price = ''
 			for seller_id in prod.seller_ids:
 				sellers +=  '- <i>'+ seller_id.name.name +'</i>\r\n'
-				pricelist_id = ir.ir_get(cr,uid,'meta','product.pricelist.purchase',[('res.partner',seller_id.name.id)])[0][2]
-				price = osv_pools.get('product.pricelist').price_get(cr,uid,[pricelist_id], prod.id, number*prod_qtty or 1.0)[pricelist_id]
+				pricelist = ir.ir_get(cr,uid,'meta','product.pricelist.purchase',[('res.partner',seller_id.name.id)])
+				if pricelist:
+					pricelist_id = pricelist[0][2]
+					price = pooler.get_pool(cr.dbname).get('product.pricelist').price_get(cr,uid,[pricelist_id], prod.id, number*prod_qtty or 1.0)[pricelist_id]
+				else:
+					price = 0
 				sellers_price += '-' + str(price) + '\r\n'
 
 			xml += "<col para='yes'>" + prod_name + '</col>'
@@ -86,7 +91,7 @@ class report_custom(report_rml):
 		def process_workcenter(wrk):
 			xml = '<row>'
 
-			workcenter = osv_pools.get('mrp.workcenter').browse(cr, uid, wrk['workcenter_id'])
+			workcenter = pooler.get_pool(cr.dbname).get('mrp.workcenter').browse(cr, uid, wrk['workcenter_id'])
 
 			xml += "<col para='yes'>" + wrk['name'] + '</col>'
 			xml += "<col para='yes'>" +  '</col>'
@@ -150,13 +155,13 @@ class report_custom(report_rml):
 
 		first = True
 		for prod_id in ids:
-			bom_ids = osv_pools.get('mrp.bom').search(cr, uid, [('product_id','=',prod_id)])
-			prod = osv_pools.get('product.product').browse(cr, uid, prod_id)
+			bom_ids = pooler.get_pool(cr.dbname).get('mrp.bom').search(cr, uid, [('product_id','=',prod_id)])
+			prod = pooler.get_pool(cr.dbname).get('product.product').browse(cr, uid, prod_id)
 
 			for bom_id in bom_ids:
-				bom = osv_pools.get('mrp.bom').browse(cr, uid, bom_id)
+				bom = pooler.get_pool(cr.dbname).get('mrp.bom').browse(cr, uid, bom_id)
 
-				sub_boms = osv_pools.get('mrp.bom')._bom_explode(cr, uid, bom, number, [])
+				sub_boms = pooler.get_pool(cr.dbname).get('mrp.bom')._bom_explode(cr, uid, bom, number, [])
 				total = 0
 				total_strd = 0
 				parent_bom = {'product_qty': bom.product_qty, 'name': bom.product_id.name, 'product_uom': bom.product_id.uom_id.factor, 'product_id': bom.product_id.id}
@@ -185,6 +190,7 @@ class report_custom(report_rml):
 				first = False
 
 		xml = '<?xml version="1.0" ?><report>' + config_start + '<report-header>Product Cost Structure\n\r' + prod.name  + '</report-header>'+ config_stop +  header + xml + '</report>'
+
 		return xml
 
 report_custom('report.product.price', 'product.product', '', 'addons/mrp/report/price.xsl')
