@@ -41,6 +41,7 @@ parameter_form = '''<?xml version="1.0"?>
 	<separator string="Time (days)" colspan="4"/>
 	<field name="po_lead"/>
 	<field name="security_lead"/>
+	<field name="automatic" />
 	<separator string="Control" colspan="4"/>
 	<field name="user_id"/>
 </form>'''
@@ -48,11 +49,12 @@ parameter_form = '''<?xml version="1.0"?>
 parameter_fields = {
 	'po_lead': {'string':'PO Lead Time', 'type':'float', 'required':True, 'default': lambda *a: 1.0},
 	'security_lead': {'string':'Security Days', 'type':'float', 'required':True, 'default': lambda *a: 5.0},
+	'automatic': {'string': 'Automatic orderpoint', 'type': 'boolean', 'help': 'If the stock of a product is under 0, it will act like an orderpoint', 'default': lambda *a: False},
 	'user_id': {'string':'Send Result To', 'type':'many2one', 'relation':'res.users', 'default': lambda uid,data,state: uid},
 }
 
 def _procure_calculation(self, cr, uid, data, context):
-	threaded_calculation = threading.Thread(target=_procure_orderpoint_confirm, args=(self, uid, data, context))
+	threaded_calculation = threading.Thread(target=_procure_orderpoint_confirm, args=(self, cr.dbname, uid, data, context))
 	threaded_calculation.start()
 	return {}
 
