@@ -4,8 +4,10 @@
 	"author" : "Tiny",
 	"depends" : ["base"],
 	"category" : "Generic Modules/Inventory Control",
+	"description": "Synchronise partners through a LDAP module. Has been used to synchronise partners in Outlook and Tiny ERP.",
 	"init_xml" : [],
 	"demo_xml" : [],
 	"update_xml" : ["wizard.xml"],
-	"active": False
+	"active": False,
+	"installable": False
 }
