@@ -3,9 +3,11 @@
 	"version" : "1.0",
 	"author" : "Tiny",
 	"category" : "Generic Modules/Inventory Control",
-	"depends" : ["base", "account"],
+	"depends" : ["base"],
 	"init_xml" : [],
 	"demo_xml" : ["product_demo.xml"],
+	"description": "Manage products and pricelists",
 	"update_xml" : ["product_data.xml","product_report.xml", "product_wizard.xml","product_view.xml", "pricelist_view.xml"],
-	"active": True
+	"active": False,
+	"installable": True
 }
