@@ -85,7 +85,16 @@ class product_pricelist(osv.osv):
 		'active': lambda *a: 1,
 	}
 
-	def price_get(self, cr, uid, ids, prod_id, qty, context={}):
+	#
+	# IN:
+	#   Context {
+	#      'uom': Unit of Measure (Int)
+	#      'partner': Partner ID (int)
+	#   }
+	#
+	def price_get(self, cr, uid, ids, prod_id, qty, partner=None, context={}):
+		if context and ('partner_id' in context):
+			partner = context['partner_id']
 		result = {}
 		for id in ids:
 			cr.execute('select * from product_pricelist_version where pricelist_id=%d and active=True order by id limit 1', (id,))
@@ -93,6 +102,8 @@ class product_pricelist(osv.osv):
 			# Ajouter le test de la date du jour
 			# 
 			plversion = False
+
+			# Ahahahahaha
 			for plversion in cr.dictfetchall():
 				break
 			
@@ -114,14 +125,14 @@ class product_pricelist(osv.osv):
 				categ_where = '(categ_id is null)'
 
 			cr.execute(
-				'select i.*, pl.currency_id '\
-				'from product_pricelist_item as i, product_pricelist_version as v, product_pricelist as pl '\
-				'where (product_tmpl_id is null or product_tmpl_id=%d) '\
-				'and (product_id is null or product_id=%d) '\
-				'and ('+categ_where+' or (categ_id is null)) '\
-				'and price_version_id=%d '\
-				'and (min_quantity is null or min_quantity<=%d) '\
-				'and i.price_version_id=v.id and v.pricelist_id=pl.id '\
+				'select i.*, pl.currency_id '
+				'from product_pricelist_item as i, product_pricelist_version as v, product_pricelist as pl '
+				'where (product_tmpl_id is null or product_tmpl_id=%d) '
+				'and (product_id is null or product_id=%d) '
+				'and ('+categ_where+' or (categ_id is null)) '
+				'and price_version_id=%d '
+				'and (min_quantity is null or min_quantity<=%f) '
+				'and i.price_version_id=v.id and v.pricelist_id=pl.id '
 				'order by sequence limit 1', (tmpl_id, prod_id, plversion['id'], qty))
 			res = cr.dictfetchone()
 			if res:
@@ -132,6 +143,21 @@ class product_pricelist(osv.osv):
 						price_tmp = self.price_get(cr, uid, [res['base_pricelist_id']], prod_id, qty)[res['base_pricelist_id']]
 						ptype_src = self.pool.get('product.pricelist').browse(cr, uid, res['base_pricelist_id']).currency_id.id
 						price = self.pool.get('res.currency').compute(cr, uid, ptype_src, res['currency_id'], price_tmp)
+				elif res['base'] == -2:
+					where = []
+					if partner:
+						where = [('name', '=', partner) ] 
+					sinfo = self.pool.get('product.supplierinfo').search(cr, uid, [('product_id', '=', prod_id)]+where)
+					if not sinfo:
+						result[id] = 0
+						continue
+					cr.execute('select * from pricelist_partnerinfo where suppinfo_id in (' + ','.join(map(str, sinfo)) + ') and min_quantity<=%f order by min_quantity desc limit 1', (qty,))
+					res = cr.dictfetchone()
+					if res:
+						result[id] = res['price']
+					else:
+						result[id] = 0
+					continue
 				else:
 					price_type_o=self.pool.get('product.price.type').read(cr, uid, [ res['base'] ])[0]
 					price = self.pool.get('res.currency').compute(cr, uid, price_type_o['currency_id'][0], res['currency_id'], self.pool.get('product.product').price_get(cr, uid, [prod_id], price_type_o['field'])[prod_id])
@@ -146,7 +172,9 @@ class product_pricelist(osv.osv):
 				if res['price_max_margin']:
 					price = min(price, price_limit+res['price_max_margin'])
 			else:
-				price = 0
+				# False means no valid line found ! But we may not raise an 
+				# exception here because it breaks the search
+				price = False
 			result[id] = price
 			if 'uom' in context:
 				result[id] = self.pool.get('product.uom')._compute_price(cr, uid, context['uom'], result[id])
@@ -157,7 +185,7 @@ class product_pricelist_version(osv.osv):
 	_name = "product.pricelist.version"
 	_description = "Pricelist Version"
 	_columns = {
-		'pricelist_id': fields.many2one('product.pricelist', 'Price List', required=True),
+		'pricelist_id': fields.many2one('product.pricelist', 'Price List', required=True, select=True),
 		'name': fields.char('Name', size=64, required=True),
 		'active': fields.boolean('Active'),
 		'items_id': fields.one2many('product.pricelist.item', 'price_version_id', 'Price List Items', required=True),
@@ -174,6 +202,7 @@ class product_pricelist_item(osv.osv):
 		cr.execute('select id,name from product_price_type where active')
 		result = cr.fetchall()
 		result.append((-1,'Other Pricelist'))
+		result.append((-2,'Partner section of the product form'))
 		return result
 
 	_name = "product.pricelist.item"
@@ -183,10 +212,11 @@ class product_pricelist_item(osv.osv):
 		'base': lambda *a: -1,
 		'min_quantity': lambda *a: 1,
 		'sequence': lambda *a: 5,
+		'price_discount': lambda *a: 0,
 	}
 	_columns = {
-		'name': fields.char('Name', size=64, required=True),
-		'price_version_id': fields.many2one('product.pricelist.version', 'Price List Version', required=True),
+		'name': fields.char('Name', size=64),
+		'price_version_id': fields.many2one('product.pricelist.version', 'Price List Version', required=True, select=True),
 		'product_tmpl_id': fields.many2one('product.template', 'Product Template'),
 		'product_id': fields.many2one('product.product', 'Product'),
 		'categ_id': fields.many2one('product.category', 'Product Category'),
