@@ -28,6 +28,7 @@
 ##############################################################################
 
 from osv import osv, fields
+import pooler
 
 import math
 from _common import rounding
@@ -55,7 +56,6 @@ class product_uom(osv.osv):
 		'category_id': fields.many2one('product.uom.categ', 'UOM Category', required=True, ondelete='cascade'),
 		'factor': fields.float('Factor', required=True),
 		'rounding': fields.float('Rounding Precision', digits=(16, 3), required=True),
-		'accounting_uos_id': fields.many2one('account.uos', 'Accounting UOS'),
 		'active': fields.boolean('Active'),
 	}
 	
@@ -124,27 +124,24 @@ class product_category(osv.osv):
 	_columns = {
 		'name': fields.char('Name', size=64, required=True),
 		'complete_name': fields.function(_name_get_fnc, method=True, type="char", string='Name'),
-		'parent_id': fields.many2one('product.category','Parent Category'),
+		'parent_id': fields.many2one('product.category','Parent Category', select=True),
 		'child_id': fields.one2many('product.category', 'parent_id', string='Childs Categories'),
-		'property_account_income_categ': fields.property(
-		  'account.account',
-		  type='many2one', 
-		  relation='account.account', 
-		  string="Income Account", 
-		  method=True,
-		  view_load=True,
-		  group_name="Accounting Properties",
-		  help="This account will be used, instead of the default one, to value incoming stock for the current product category"),
-		'property_account_expense_categ': fields.property(
-		  'account.account',
-		  type='many2one', 
-		  relation='account.account', 
-		  string="Expense Account", 
-		  method=True,
-		  view_load=True,
-		  group_name="Accounting Properties",
-		  help="This account will be used, instead of the default one, to value outgoing stock for the current product category"),
+		'sequence': fields.integer('Sequence'),
 	}
+	_order = "sequence"
+	def _check_recursion(self, cr, uid, ids):
+		level = 100
+		while len(ids):
+			cr.execute('select distinct parent_id from product_category where id in ('+','.join(map(str,ids))+')')
+			ids = filter(None, map(lambda x:x[0], cr.fetchall()))
+			if not level:
+				return False
+			level -= 1
+		return True
+
+	_constraints = [
+		(_check_recursion, 'Error ! You can not create recursive categories.', ['parent_id'])
+	]
 	def child_get(self, cr, uid, ids):
 		return [ids]
 
@@ -157,18 +154,26 @@ product_category()
 class product_template(osv.osv):
 	_name = "product.template"
 	_description = "Product Template"
+
+	def _calc_seller_delay(self, cr, uid, ids, name, arg, context={}):
+		result = {}
+		for product in self.browse(cr, uid, ids, context):
+			if product.seller_ids:
+				result[product.id] = product.seller_ids[0].delay
+			else:
+				result[product.id] = 1
+		return result
+
 	_columns = {
-		'name': fields.char('Name', size=64, required=True, translate=True),
+		'name': fields.char('Name', size=64, required=True, translate=True, select=True),
 		'product_manager': fields.many2one('res.users','Product Manager'),
-		'description': fields.text('Description', translate=True),
-		'description_purchase': fields.text('Purchase Description', translate=True),
-		'description_sale': fields.text('Sale Description', translate=True),
-		'name_ids': fields.one2many('product.template.name', 'template_id', 'Names for Partners'),
-		'type': fields.selection([('product','Stockable Product'),('service','Service')], 'Product Type', required=True),
+		'description': fields.text('Description'),
+		'description_purchase': fields.text('Purchase Description'),
+		'description_sale': fields.text('Sale Description'),
+		'type': fields.selection([('product','Stockable Product'),('consu', 'Consumable'),('service','Service')], 'Product Type', required=True),
 		'supply_method': fields.selection([('produce','Produce'),('buy','Buy')], 'Supply method', required=True),
-		'seller_delay': fields.float('Supplier lead time', help="This is the average delay in days between the purchase order confirmation and the reception of goods for this product and for the default supplier. It is used by the sceduler to order requests based on reordering delays."),
 		'sale_delay': fields.float('Procurement lead time', help="This is the average time between the confirmation of the customer order and the delivery of the finnished products. It's the time you promise to your customers."),
-		'produce_delay': fields.float('Production lead time', help="Average time to produce this product. This is only for the production order and, if it is a multi-level bill of material, it's only for the level of this product. Different delays will be summed for all levels and purchase orders."),
+		'produce_delay': fields.float('Manufacturing lead time', help="Average time to produce this product. This is only for the production order and, if it is a multi-level bill of material, it's only for the level of this product. Different delays will be summed for all levels and purchase orders."),
 		'procure_method': fields.selection([('make_to_stock','Make to Stock'),('make_to_order','Make to Order')], 'Procure Method', required=True),
 		'rental': fields.boolean('Rentable product'),
 		'categ_id': fields.many2one('product.category','Category', required=True, change_default=True),
@@ -180,7 +185,6 @@ class product_template(osv.osv):
 		'warranty': fields.float('Warranty (months)'),
 		'sale_ok': fields.boolean('Can be sold', help="Determine if the product can be visible in the list of product within a selection from a sale order line."),
 		'purchase_ok': fields.boolean('Can be Purchased', help="Determine if the product is visible in the list of products within a selection from a purchase order line."),
-		'taxes_id': fields.many2many('account.tax', 'product_taxes_rel', 'prod_id', 'tax_id', 'Product Taxes', domain=[('parent_id','=',False)]),
 		'uom_id': fields.many2one('product.uom', 'Default UOM', required=True),
 		'uom_po_id': fields.many2one('product.uom', 'Purchase UOM', required=True),
 		'state': fields.selection([('draft', 'In Development'),('sellable','In production'),('end','End of lifecycle'),('obsolete','Obsolete')], 'State'),
@@ -189,24 +193,8 @@ class product_template(osv.osv):
 		'intrastat': fields.char('Intrastat number', size=16),
 		'mes_type': fields.selection((('fixed', 'Fixed'), ('variable', 'Variable')), 'Mesure type', required=True),
 		'tracking': fields.boolean('Track lots'),
-		'property_account_income': fields.property(
-		  'account.account',
-		  type='many2one', 
-		  relation='account.account', 
-		  string="Income Account", 
-		  method=True,
-		  view_load=True,
-		  group_name="Accounting Properties",
-		  help="This account will be used, instead of the default one, to value incoming stock for the current product"),
-		'property_account_expense': fields.property(
-		  'account.account',
-		  type='many2one', 
-		  relation='account.account', 
-		  string="Expense Account", 
-		  method=True,
-		  view_load=True,
-		  group_name="Accounting Properties",
-		  help="This account will be used, instead of the default one, to value outgoing stock for the current product"),
+		'seller_delay': fields.function(_calc_seller_delay, method=True, type='integer', string='Supplier lead time', help="This is the average delay in days between the purchase order confirmation and the reception of goods for this product and for the default supplier. It is used by the sceduler to order requests based on reordering delays."),
+		'seller_ids': fields.one2many('product.supplierinfo', 'product_id', 'Partners'),
 	}
 	def _get_uom_id(self, cr, uid, *args):
 		cr.execute('select id from product_uom order by id limit 1')
@@ -222,7 +210,6 @@ class product_template(osv.osv):
 		'sale_ok': lambda *a: 1,
 		'sale_delay': lambda *a: 7,
 		'produce_delay': lambda *a: 1,
-		'seller_delay': lambda *a: 1,
 		'purchase_ok': lambda *a: 1,
 		'procure_method': lambda *a: 'make_to_stock',
 		'uom_id': _get_uom_id,
@@ -232,7 +219,6 @@ class product_template(osv.osv):
 		'uos_coeff' : lambda *a: 1.0,
 		'mes_type' : lambda *a: 'fixed',
 	}
-	# TODO: redefine name_get & name_search for product.template.name
 	def name_get(self, cr, user, ids, context={}):
 		if 'partner_id' in context:
 			pass
@@ -240,17 +226,6 @@ class product_template(osv.osv):
 
 product_template()
 
-class product_template_name(osv.osv):
-	_name = "product.template.name"
-	_description = "Product Template"
-	_columns = {
-		'name': fields.char('Product Name', size=64, required=True),
-		'code': fields.char('Product Code', size=32),
-		'partner_id': fields.many2one('res.partner', 'Partner', ondelete='cascade'),
-		'template_id': fields.many2one('product.template', 'Product Template', ondelete='cascade'),
-	}
-product_template_name()
-
 class product_product(osv.osv):
 	def _product_price(self, cr, uid, ids, name, arg, context={}):
 		res = {}
@@ -264,33 +239,9 @@ class product_product(osv.osv):
 			res.setdefault(id, 0.0)
 		return res
 
-	#
-	# Utiliser browse pour limiter les queries !
-	#
 	def _get_product_available_func(states, what):
 		def _product_available(self, cr, uid, ids, name, arg, context={}):
-			if context.get('shop', False):
-				cr.execute('select warehouse_id from sale_shop where id=%d', (int(context['shop']),))
-				res2 = cr.fetchone()
-				if res2:
-					context['warehouse'] = res2[0]
-
-			if context.get('warehouse', False):
-				cr.execute('select lot_stock_id from stock_warehouse where id=%d', (int(context['warehouse']),))
-				res2 = cr.fetchone()
-				if res2:
-					context['location'] = res2[0]
-
-			if context.get('location', False):
-				location_ids = [context['location']]
-			else:
-				# get the list of ids of the stock location of all warehouses
-				cr.execute("select lot_stock_id from stock_warehouse")
-				location_ids = [id for (id,) in cr.fetchall()]
-				
-			# build the list of ids of children of the location given by id
-			location_ids = self.pool.get('stock.location').search(cr, uid, [('location_id', 'child_of', location_ids)])
-			res = self.pool.get('stock.location')._product_get_multi_location(cr, uid, location_ids, ids, context, states, what)
+			res={}
 			for id in ids:
 				res.setdefault(id, 0.0)
 			return res
@@ -314,9 +265,10 @@ class product_product(osv.osv):
 
 	def _get_partner_code_name(self, cr, uid, ids, product_id, partner_id, context={}):
 		product = self.browse(cr, uid, [product_id], context)[0]
-		for name in product.name_ids:
-			if name.partner_id.id == partner_id:
-				return {'code' : name.code, 'name' : name.name}
+		for supinfo in product.seller_ids:
+			if supinfo.name.id == partner_id:
+				print {'code': supinfo.product_code, 'name': supinfo.product_name}
+				return {'code': supinfo.product_code, 'name': supinfo.product_name}
 		return {'code' : product.default_code, 'name' : product.name}
 
 	def _product_code(self, cr, uid, ids, name, arg, context={}):
@@ -328,7 +280,8 @@ class product_product(osv.osv):
 	def _product_partner_ref(self, cr, uid, ids, name, arg, context={}):
 		res = {}
 		for p in self.browse(cr, uid, ids, context):
-			res[p.id] = self._get_partner_code_name(cr, uid, [], p.id, context.get('partner_id', None), context)['name']
+			data = self._get_partner_code_name(cr, uid, [], p.id, context.get('partner_id', None), context)
+			res[p.id] = (data['code'] and ('['+data['code']+'] ') or '') +data['name']
 		return res
 
 	_defaults = {
@@ -344,7 +297,6 @@ class product_product(osv.osv):
 	_columns = {
 		'qty_available': fields.function(_product_qty_available, method=True, type='float', string='Real Stock'),
 		'virtual_available': fields.function(_product_virtual_available, method=True, type='float', string='Virtual Stock'),
-		'seller_ids': fields.one2many('product.supplierinfo', 'product_id', 'Suppliers'),
 		'incoming_qty': fields.function(_product_incoming_qty, method=True, type='float', string='Incoming'),
 		'outgoing_qty': fields.function(_product_outgoing_qty, method=True, type='float', string='Outgoing'),
 		'price': fields.function(_product_price, method=True, type='float', string='Customer Price'),
@@ -358,11 +310,11 @@ class product_product(osv.osv):
 		'ean13': fields.char('EAN13', size=13),
 		'packaging' : fields.one2many('product.packaging', 'product_id', 'Palettization', help="Gives the different ways to package the same product. This has no impact on the picking order and is mainly used if you use the EDI module."),
 		'price_extra': fields.float('Price Extra'),
-		'price_margin': fields.float('Price Margin')
+		'price_margin': fields.float('Price Margin'),
 	}
 
 	def _check_ean_key(self, cr, uid, ids):
-		for partner_o in osv.osv_pools.get('product.product').read(cr, uid, ids, ['ean13',]):
+		for partner_o in pooler.get_pool(cr.dbname).get('product.product').read(cr, uid, ids, ['ean13',]):
 			thisean=partner_o['ean13']
 			if thisean and thisean!='':
 				if len(thisean)!=13:
@@ -403,7 +355,8 @@ class product_product(osv.osv):
 		if not len(ids):
 			ids = self.search(cr, user, [('ean13','=',name)]+ args, limit=limit)
 		if not len(ids):
-			ids = self.search(cr, user, [('name',operator,name)]+ args, limit=limit)
+			ids = self.search(cr, user, [('default_code',operator,name)]+ args, limit=limit)
+			ids += self.search(cr, user, [('name',operator,name)]+ args, limit=limit)
 		result = self.name_get(cr, user, ids, context)
 		return result
 
@@ -431,7 +384,7 @@ class product_packaging(osv.osv):
 		'ul' : fields.many2one('product.ul', 'Type of UL', required=True),
 		'ul_qty' : fields.integer('UL by row'),
 		'rows' : fields.integer('# of rows', required=True),
-		'product_id' : fields.many2one('product.product', 'Product'),
+		'product_id' : fields.many2one('product.product', 'Product', select=True),
 		'ean' : fields.char('EAN', size=14, help="The EAN code of the transport unit."),
 		'code' : fields.char('Code', size=14, help="The code of the transport unit."),
 		'weight': fields.float('Weight Palette'),
@@ -463,20 +416,40 @@ class product_packaging(osv.osv):
 
 	def on_change_rows(self, cr, uid, ids, weight, ul, row, qty):
 		return {'value' : { 'weight' : weight * ul * row * qty }}
-
 product_packaging()
 
+
 class product_supplierinfo(osv.osv):
 	_name = "product.supplierinfo"
 	_description = "Information about a product supplier"
 	_columns = {
-		'name' : fields.many2one('res.partner', 'Supplier', required=True),
+		'name' : fields.many2one('res.partner', 'Partner', required=True, ondelete='cascade'),
+		'product_name': fields.char('Partner product name', size=128),
+		'product_code': fields.char('Partner product reference', size=64),
 		'sequence' : fields.integer('Sequence'),
 		'qty' : fields.integer('Minimal quantity', required=True),
-		'product_id' : fields.many2one('product.product', 'Product', required=True),
+		'product_id' : fields.many2one('product.template', 'Product', required=True, ondelete='cascade', select=True),
 		'delay' : fields.integer('Delivery delay', required=True),
+		'pricelist_ids': fields.one2many('pricelist.partnerinfo', 'suppinfo_id', 'Pricelist'),
+	}
+	_defaults = {
+		'qty': lambda *a: 0.0,
+		'delay': lambda *a: 1,
 	}
 	_order = 'sequence'
 product_supplierinfo()
 
+
+class pricelist_partnerinfo(osv.osv):
+	_name = 'pricelist.partnerinfo'
+	_columns = {
+		'name': fields.char('Description', size=64),
+		'suppinfo_id': fields.many2one('product.supplierinfo', 'Partner Information', required=True, ondelete='cascade', select=True),
+		'min_quantity': fields.float('Minimal quantity', required=True),
+		'price': fields.float('price', required=True),
+	}
+	_order = 'min_quantity asc'
+pricelist_partnerinfo()
+
+
 # vim:noexpandtab:
