@@ -6,6 +6,8 @@
 	"depends" : ["base", "account", "product", "stock"],
 	"init_xml" : [],
 	"demo_xml" : [],
+	"description": "A module that add manufacturers and attributes on the product form",
 	"update_xml" : ["product_electronic_view.xml"],
-	"active": False
+	"active": False,
+	"installable": True
 }
