@@ -7,5 +7,6 @@
 	"init_xml" : [],
 	"demo_xml" : [],
 	"update_xml" : ["product_extended_view.xml"],
-	"active": False
+	"active": False,
+	"installable": True
 }
