@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: product_extended.py 3839 2006-08-16 16:21:20Z nicoe $
+# $Id: product_extended.py 4304 2006-10-25 09:54:51Z ged $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -30,6 +30,7 @@
 from osv import fields
 from osv import osv
 import ir
+import pooler
 
 class product_supplierinfo(osv.osv):
 	_inherit = 'product.supplierinfo'
@@ -70,21 +71,30 @@ class product_product(osv.osv):
 	_name = 'product.product'
 	_inherit = 'product.product'
 	
-	def _running_po(self, cr, uid, ids, name, arg, context):
+	def _find_op(self, cr, uid, ids, name, arg, context):
 		res = {}
-		for product in self.browse(cr, uid, ids):
-			cr.execute("SELECT po.id, max(po.date_approve) FROM purchase_order as po, purchase_order_line as line \
-						WHERE po.id=line.order_id AND product_id=%d AND state in ('done', 'cancel') GROUP BY po.id", (product.id,))
-			record = cr.fetchone()
-			if record:
-				res[product.id] = record[0]
+		for product_id in ids:
+			cr.execute('SELECT swo.id from stock_warehouse_orderpoint AS swo WHERE product_id=%d', (product_id,))
+			op_id = cr.fetchone()
+			if op_id:
+				res[product_id] = op_id[0]
 			else:
-				res[product.id] = False
+				res[product_id] = False
 		return res
 
+	def _product_dispo(self, cr, uid, ids, name, arg, context={}):
+		res = {}
+		out = self._product_outgoing_qty(cr, uid, ids, name, arg, context)
+		now = self._product_qty_available(cr, uid, ids, name, arg, context)
+		for p_id in ids:
+			res[p_id] = now[p_id] + out[p_id]
+		return res
+
+
 	_columns = {
-		'running_purchase' : fields.function(_running_po, type='many2one', obj='purchase.order', method=True, string='Running order'),
 		'calculate_price': fields.boolean('Compute price'),
+		'orderpoint_ids': fields.one2many('stock.warehouse.orderpoint', 'product_id', 'Orderpoints'),
+		'qty_dispo': fields.function(_product_dispo, method=True, type='float', string='Stock disponible'),
 	}
 
 	_defaults = {
@@ -93,9 +103,9 @@ class product_product(osv.osv):
 
 	def compute_price(self, cr, uid, ids, *args):
 		for prod_id in ids:
-			bom_ids = osv.osv_pools.get('mrp.bom').search(cr, uid, [('product_id', '=', prod_id)])
+			bom_ids = pooler.get_pool(cr.dbname).get('mrp.bom').search(cr, uid, [('product_id', '=', prod_id)])
 			if bom_ids:
-				for bom in osv.osv_pools.get('mrp.bom').browse(cr, uid, bom_ids):
+				for bom in pooler.get_pool(cr.dbname).get('mrp.bom').browse(cr, uid, bom_ids):
 					self._calc_price(cr, uid, bom)
 		return True
 					
@@ -108,14 +118,14 @@ class product_product(osv.osv):
 				for sbom in bom.bom_lines:
 					price += self._calc_price(cr, uid, sbom) * sbom.product_qty
 			else:
-				bom_obj = osv.osv_pools.get('mrp.bom')
+				bom_obj = pooler.get_pool(cr.dbname).get('mrp.bom')
 				no_child_bom = bom_obj.search(cr, uid, [('product_id', '=', bom.product_id.id), ('bom_id', 'is', None)])
 				if no_child_bom:
 					other_bom = bom_obj.browse(cr, uid, no_child_bom)[0]
 					price += bom.product_qty * self._calc_price(cr, uid, other_bom)
 				elif bom.product_id.seller_ids:
 					pricelist_id = bom.product_id.seller_ids[0].name.property_product_pricelist_purchase[0]
-					price += osv.osv_pools.get('product.pricelist').price_get(cr, uid, [pricelist_id], bom.product_id.id, bom.product_qty, 'standard')[pricelist_id]
+					price += pooler.get_pool(cr.dbname).get('product.pricelist').price_get(cr, uid, [pricelist_id], bom.product_id.id, bom.product_qty, 'standard')[pricelist_id]
 				else:
 					price += bom.product_qty * bom.product_id.standard_price
 				
