@@ -4,7 +4,8 @@
 	"depends" : ["base"],
 	"author" : "Tiny",
 	"website" : "",
-	"category" : "Generic Modules/Reporting",
+	"category" : "Generic Modules/Human Resources",
+	"description": "A module that analyse the productivity of Tiny ERP users in terms of creation and modification of objects. It is able to render graphs, compare users, eso.",
 	"init_xml" : [ ],
 	"demo_xml" : [ ],
 	"update_xml" : [
@@ -12,5 +13,6 @@
 		"productivity_analysis_wizard.xml",
 		"productivity_analysis_report.xml",
 	],
-	"active": False
+	"active": False,
+	"installable": True
 }
