@@ -30,17 +30,14 @@
 from sets import Set
 from mx.DateTime import *
 
-import netsvc
 import StringIO
-import tools
-import sql_db
 
 from report.render import render
 from report.interface import report_int
 
 from gantt import GanttCanvas
 from _date_compute import _project_compute, _compute_tasks
-from osv.osv import osv_pools
+import pooler
 
 class external_pdf(render):
 	def __init__(self, pdf):
@@ -52,21 +49,22 @@ class external_pdf(render):
 		return self.pdf
 
 class report_tasks(report_int):
-	def create(self, uid, ids, datas, context={}):
+	def create(self, cr, uid, ids, datas, context={}):
 		io = StringIO.StringIO()
 
 		date_to_int = lambda x: int(x.ticks())
 		int_to_date = lambda x: '/a60{}'+localtime(x).strftime('%d %m %Y')
 		gt = GanttCanvas(io, convertors=(date_to_int, int_to_date))
-		cr = sql_db.db.cursor()
 
-		tasks = osv_pools.get('project.task').browse(cr, uid, ids)
+		tasks = pooler.get_pool(cr.dbname).get('project.task').browse(cr, uid, ids)
 		tasks, last_date = _compute_tasks(cr, uid, tasks, now())
-		cr.close()
 		for user_id in tasks.keys():
 			for t in tasks[user_id]:
 				gt.add(t[3], t[2], [(t[0],t[1])])
-		gt.draw()
+		try:
+			gt.draw()
+		except:
+			pass
 		gt.close()
 		self.obj = external_pdf(io.getvalue())
 		self.obj.render()
@@ -75,14 +73,12 @@ report_tasks('report.project.tasks.gantt')
 
 
 class report_projects(report_int):
-	def create(self, uid, ids, datas, context={}):
+	def create(self, cr, uid, ids, datas, context={}):
 		io = StringIO.StringIO()
 		date_to_int = lambda x: int(x.ticks())
 		int_to_date = lambda x: '/a60{}'+localtime(x).strftime('%d %m %Y')
 		gt = GanttCanvas(io, convertors=(date_to_int, int_to_date))
-		cr = sql_db.db.cursor()
 		tasks, last_date = _project_compute(cr, uid, ids[0])
-		cr.close()
 		for user_id in tasks.keys():
 			for t in tasks[user_id]:
 				gt.add(t[3], t[2], [(t[0],t[1])])
