@@ -8,5 +8,6 @@
 	"init_xml" : [],
 	"demo_xml" : ["purchase_demo.xml"],
 	"update_xml" : ["purchase_workflow.xml", "purchase_sequence.xml", "purchase_data.xml", "purchase_view.xml", "purchase_report.xml", "purchase_wizard.xml"],
-	"active": True
+	"active": False,
+	"installable": True
 }
