@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: wizard_group.py 3857 2006-08-22 07:25:11Z pinky $
+# $Id: wizard_group.py 4522 2006-11-09 16:02:35Z pinky $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -31,7 +31,7 @@ import time
 
 import wizard
 import netsvc
-from osv.osv import osv_pools
+import pooler
 from osv.orm import browse_record
 
 merge_form = """<?xml version="1.0"?>
@@ -53,7 +53,7 @@ ack_form = """<?xml version="1.0"?>
 ack_fields = {}
 
 def _mergeOrders(self, cr, uid, data, context):
-	order_obj = osv_pools.get('purchase.order')
+	order_obj = pooler.get_pool(cr.dbname).get('purchase.order')
 
 	def make_key(br, fields):
 		list_key = []
@@ -76,7 +76,6 @@ def _mergeOrders(self, cr, uid, data, context):
 		order_infos = new_order[0]
 		if not order_infos:
 			order_infos.update({
-				'name': 'Merge: %s' % porder.name,
 				'origin': porder.origin,
 				'date_order': time.strftime('%Y-%m-%d'),
 				'partner_id': porder.partner_id.id,
@@ -88,11 +87,11 @@ def _mergeOrders(self, cr, uid, data, context):
 				'pricelist_id': porder.pricelist_id.id,
 				'state': 'draft',
 				'order_line': {},
-				'notes': '%s\n%s\n\n%s' % (porder.name, '-' * len(porder.name), porder.notes),
+				'notes': '%s' % (porder.notes,),
 			})
 		else:
-			order_infos['name'] += ', %s' % porder.name
-			order_infos['notes'] += '\n\n%s\n%s\n\n%s' % (porder.name, '-' * len(porder.name), porder.notes)
+			#order_infos['name'] += ', %s' % porder.name
+			order_infos['notes'] += ('\n%s' % (porder.notes,))
 
 		for order_line in porder.order_line:
 			line_key = make_key(order_line, ('name', 'date_planned', 'taxes_id', 'price_unit', 'notes', 'product_id', 'move_dest_id'))	
@@ -111,9 +110,11 @@ def _mergeOrders(self, cr, uid, data, context):
 
 	wf_service = netsvc.LocalService("workflow")
 
+	allorders = []
 	for order_key, (order_data, old_ids) in new_orders.iteritems():
 		# skip merges with only one order
 		if len(old_ids) < 2:
+			allorders += (old_ids or [])
 			continue
 
 		# cleanup order line data
@@ -124,13 +125,22 @@ def _mergeOrders(self, cr, uid, data, context):
 		
 		# create the new order
 		neworder_id = order_obj.create(cr, uid, order_data)
+		allorders.append(neworder_id)
 
 		# make triggers pointing to the old orders point to the new order
 		for old_id in old_ids:
 			wf_service.trg_redirect(uid, 'purchase.order', old_id, neworder_id, cr)
 			wf_service.trg_validate(uid, 'purchase.order', old_id, 'purchase_cancel', cr)
 
-	return {}
+	return {
+		'domain': "[('id','in', ["+','.join(map(str,allorders))+"])]",
+		'name': 'Purchase Orders',
+		'view_type': 'form',
+		'view_mode': 'tree,form',
+		'res_model': 'purchase.order',
+		'view_id': False,
+		'type': 'ir.actions.act_window'
+	}
 
 class merge_orders(wizard.interface):
 	states = {
@@ -139,8 +149,8 @@ class merge_orders(wizard.interface):
 			'result' : {'type' : 'form', 'arch' : merge_form, 'fields' : merge_fields, 'state' : [('end', 'Cancel'),('merge', 'Merge orders') ]}
 		},
 		'merge' : {
-			'actions' : [_mergeOrders],
-			'result' : {'type' : 'form', 'arch' : ack_form, 'fields' : ack_fields, 'state' : [('end', 'Done')]}
+			'actions' : [],
+			'result' : {'type':'action', 'action':_mergeOrders, 'state':'end'}
 		},
 	}
 merge_orders("purchase.order.merge")
