@@ -5,8 +5,10 @@
 	"website" : "http://tinyerp.com/module_project.html",
 	"depends" : ["project"],
 	"category" : "Generic Modules/Sales & Purchases",
+	"description": "A module that adds some reports on the sales",
 	"init_xml" : [],
 	"demo_xml" : [],
 	"update_xml" : ["report_project_view.xml"],
-	"active": True
+	"active": False,
+	"installable": True
 }
