@@ -68,7 +68,7 @@ class sale_order(osv.osv):
 
 	def _amount_untaxed(self, cr, uid, ids, field_name, arg, context):
 		id_set = ",".join(map(str, ids))
-		cr.execute("SELECT s.id,COALESCE(SUM(l.price_unit*l.product_uos_qty),0) AS amount FROM sale_order s LEFT OUTER JOIN sale_order_line l ON (s.id=l.order_id) WHERE s.id IN ("+id_set+") GROUP BY s.id ")
+		cr.execute("SELECT s.id,COALESCE(SUM(l.price_unit*l.product_uos_qty*(100-l.discount))/100.0,0)::decimal(16,2) AS amount FROM sale_order s LEFT OUTER JOIN sale_order_line l ON (s.id=l.order_id) WHERE s.id IN ("+id_set+") GROUP BY s.id ")
 		res = dict(cr.fetchall())
 		return res
 
@@ -78,9 +78,9 @@ class sale_order(osv.osv):
 			val = 0.0
 			for line in order.order_line:
 				for tax in line.tax_id:
-					for c in self.pool.get('account.tax').compute(cr, uid, [tax.id], line.price_unit, line.product_uom_qty, order.partner_invoice_id.id):
-						val += c['amount']
-			res[order.id]=val
+					for c in self.pool.get('account.tax').compute(cr, uid, [tax.id], line.price_unit * (1-(line.discount or 0.0)/100.0), line.product_uom_qty, order.partner_invoice_id.id):
+						val += round(c['amount'], 2)
+			res[order.id]=round(val,2)
 		return res
 
 	def _amount_total(self, cr, uid, ids, field_name, arg, context):
@@ -92,10 +92,10 @@ class sale_order(osv.osv):
 		return res
 
 	_columns = {
-		'name': fields.char('Order Description', size=64, required=True),
+		'name': fields.char('Order Description', size=64, required=True, select=True),
 		'shop_id':fields.many2one('sale.shop', 'Shop', required=True, readonly=True, states={'draft':[('readonly',False)]}),
 		'origin': fields.char('Origin', size=64),
-		'client_order_ref': fields.char('Order Reference',size=64),
+		'client_order_ref': fields.char('Partner Ref.',size=64),
 
 		'state': fields.selection([
 			('draft','Quotation'),
@@ -106,11 +106,11 @@ class sale_order(osv.osv):
 			('invoice_except','Invoice Exception'),
 			('done','Done'),
 			('cancel','Cancel')
-		], 'Order State', readonly=True, help="Gives the state of the quotation or sale order. The exception state are automatically setted when a cancel operation occurs in the invoice validation (Invoice Exception) or in picking list process (Shipping Exception). The 'Waiting Schedule' state is set when the invoice is confirmed but waiting the 'Date Order' the schedule."),
+		], 'Order State', readonly=True, help="Gives the state of the quotation or sale order. The exception state are automatically setted when a cancel operation occurs in the invoice validation (Invoice Exception) or in picking list process (Shipping Exception). The 'Waiting Schedule' state is set when the invoice is confirmed but waiting the 'Date Order' the schedule.", select=True),
 		'date_order':fields.date('Date Ordered', required=True, readonly=True, states={'draft':[('readonly',False)]}),
 
-		'user_id':fields.many2one('res.users', 'Salesman', states={'draft':[('readonly',False)]}, relate=True),
-		'partner_id':fields.many2one('res.partner', 'Partner', readonly=True, states={'draft':[('readonly',False)]}, change_default=True, relate=True),
+		'user_id':fields.many2one('res.users', 'Salesman', states={'draft':[('readonly',False)]}, relate=True, select=True),
+		'partner_id':fields.many2one('res.partner', 'Partner', readonly=True, states={'draft':[('readonly',False)]}, change_default=True, relate=True, select=True),
 		'partner_invoice_id':fields.many2one('res.partner.address', 'Invoice Address', readonly=True, required=True, states={'draft':[('readonly',False)]}),
 		'partner_order_id':fields.many2one('res.partner.address', 'Ordering Contact', readonly=True, required=True, states={'draft':[('readonly',False)]}, help="The name and address of the contact that requested the order or quotation."),
 		'partner_shipping_id':fields.many2one('res.partner.address', 'Shipping Address', readonly=True, required=True, states={'draft':[('readonly',False)]}),
@@ -118,18 +118,21 @@ class sale_order(osv.osv):
 		'incoterm': fields.selection(_incoterm_get, 'Incoterm',size=3),
 		'picking_policy': fields.selection([('direct','Direct Delivery'),('one','All at once')], 'Picking Policy', required=True ),
 		'order_policy': fields.selection([
-			('prepaid','Pay before delivery'),
+			('prepaid','Invoice before delivery'),
 			('manual','Shipping & Manual Invoice'),
-			('postpaid','Invoice after delivery'),
+			('postpaid','Automatic Invoice after delivery'),
+			('picking','Invoice from the pickings'),
 		], 'Shipping Policy', required=True, readonly=True, states={'draft':[('readonly',False)]}, help="The Shipping Policy is used to synchronise invoive and delivery operations. The 'Pay before delivery' choice will first generate the invoice and then generate the picking order after the payment of this invoice. The 'Shipping & Manual Invoice' will create the picking order directly and wait the user to manually click on the 'Invoice Button' to generate the draft invoice. The 'Invoice after delivery' choice will generate the draft invoice after the picking list have been finnished"),
 		'pricelist_id':fields.many2one('product.pricelist', 'Pricelist', required=True, readonly=True, states={'draft':[('readonly',False)]}),
-		'project_id':fields.many2one('account.analytic.account', 'Profit/Cost Center', readonly=False, states={'draft':[('done', True)]}),
+		'project_id':fields.many2one('account.analytic.account', 'Profit/Cost Center', readonly=True, states={'draft':[('readonly', False)]}),
 
 		'order_line': fields.one2many('sale.order.line', 'order_id', 'Order Lines', readonly=True, states={'draft':[('readonly',False)]}),
 		'payment_line': fields.one2many('sale.order.payment', 'order_id', 'Order Payments', readonly=True, states={'draft':[('readonly',False)]}),
 
 		'invoice_ids': fields.many2many('account.invoice', 'sale_order_invoice_rel', 'order_id', 'invoice_id', 'Invoice', readonly=True, help="This is the list of invoices that have been generated for this sale order. The same sale order may have been invoiced in several times (by line for example)."),
-		'picking_ids': fields.many2many('stock.picking', 'sale_order_picking_rel', 'order_id','picking_id', 'Picking List', readonly=True, help="This is the list of picking list that have been generated for this invoice"),
+		#'picking_ids': fields.many2many('stock.picking', 'sale_order_picking_rel', 'order_id','picking_id', 'Picking List', readonly=True, help="This is the list of picking list that have been generated for this invoice"),
+
+		'picking_ids': fields.one2many('stock.picking', 'sale_id', 'Picking List', readonly=True, help="This is the list of picking list that have been generated for this invoice"),
 
 		'shipped':fields.boolean('Picked', readonly=True),
 		'invoiced':fields.boolean('Paid', readonly=True),
@@ -139,7 +142,7 @@ class sale_order(osv.osv):
 		'amount_untaxed': fields.function(_amount_untaxed, method=True, string='Untaxed Amount'),
 		'amount_tax': fields.function(_amount_tax, method=True, string='Taxes'),
 		'amount_total': fields.function(_amount_total, method=True, string='Total'),
-		'invoice_quantity': fields.selection([('order','Ordered Quantities'),('procurement','Shipped Quantities')], 'Invoice on', help="The sale order will automatically create the invoice proposition (draft invoice). Ordered and delivered quantities may not be the same. You have to choose if you invoice based on ordered or shipped quantities. If the product is a service, shipped quantities means hours spent on the associated tasks"),
+		'invoice_quantity': fields.selection([('order','Ordered Quantities'),('procurement','Shipped Quantities')], 'Invoice on', help="The sale order will automatically create the invoice proposition (draft invoice). Ordered and delivered quantities may not be the same. You have to choose if you invoice based on ordered or shipped quantities. If the product is a service, shipped quantities means hours spent on the associated tasks."),
 	}
 	_defaults = {
 		'picking_policy': lambda *a: 'direct',
@@ -168,7 +171,7 @@ class sale_order(osv.osv):
 			return False
 		cr.execute('select id from sale_order_line where order_id in ('+','.join(map(str, ids))+')', ('draft',))
 		line_ids = map(lambda x: x[0], cr.fetchall())
-		self.write(cr, uid, ids, {'state':'draft', 'invoice_ids':[(6,0,[])], 'shipped':0, 'invoiced':0, 'picking_ids':[(6,0,[])]})
+		self.write(cr, uid, ids, {'state':'draft', 'invoice_ids':[], 'shipped':0, 'invoiced':0})
 		self.pool.get('sale.order.line').write(cr, uid, line_ids, {'invoiced':False, 'state':'draft', 'invoice_lines':[(6,0,[])]})
 		wf_service = netsvc.LocalService("workflow")
 		for inv_id in ids:
@@ -189,6 +192,9 @@ class sale_order(osv.osv):
 # and not the id of the last invoice created (res). The problem is that we 
 # cannot change it directly since the method is called by the sale order
 # workflow and I suppose it expects a single id...
+	def _inv_get(self, cr, uid, order, context={}):
+		return {}
+
 	def action_invoice_create(self, cr, uid, ids, grouped=False, states=['confirmed','done']):
 		res = False
 		invoices = {}
@@ -196,9 +202,13 @@ class sale_order(osv.osv):
 
 		def make_invoice(order, lines):
 			a = order.partner_id.property_account_receivable[0]
+			if order.partner_id and order.partner_id.property_payment_term:
+				pay_term = order.partner_id.property_payment_term[0]
+			else:
+				pay_term = False
 			inv = {
 				'name': order.name,
-				'origin': 'SO:'+str(order.id)+':'+order.name,
+				'origin': order.name,
 				'type': 'out_invoice',
 				'reference': "P%dSO%d"%(order.partner_id.id,order.id),
 				'account_id': a,
@@ -208,7 +218,10 @@ class sale_order(osv.osv):
 				'project_id': order.project_id.id,
 				'invoice_line': [(6,0,lines)],
 				'currency_id' : order.pricelist_id.currency_id.id,
+				'comment': order.note,
+				'payment_term': pay_term,
 			}
+			inv.update(self._inv_get(cr, uid, order))
 			inv_obj = self.pool.get('account.invoice')
 			inv_id = inv_obj.create(cr, uid, inv)
 			inv_obj.button_compute(cr, uid, [inv_id])
@@ -238,10 +251,26 @@ class sale_order(osv.osv):
 		return res
 
 	def action_cancel(self, cr, uid, ids, context={}):
-		for r in self.read(cr,uid,ids,['picking_ids']):
-			for pick in r['picking_ids']:
-				wf_service = netsvc.LocalService("workflow")
-				wf_service.trg_validate(uid, 'stock.picking', pick, 'button_cancel', cr)
+		ok = True
+		for sale in self.browse(cr, uid, ids):
+			for pick in sale.picking_ids:
+				if pick.state not in ('draft','cancel'):
+					raise osv.except_osv(
+						'Could not cancel sale order !',
+						'You must first cancel all pickings attached to this sale order.')
+			for r in self.read(cr,uid,ids,['picking_ids']):
+				for pick in r['picking_ids']:
+					wf_service = netsvc.LocalService("workflow")
+					wf_service.trg_validate(uid, 'stock.picking', pick, 'button_cancel', cr)
+			for inv in sale.invoice_ids:
+				if inv.state not in ('draft','cancel'):
+					raise osv.except_osv(
+						'Could not cancel this sale order !',
+						'You must first cancel all invoices attached to this sale order.')
+			for r in self.read(cr,uid,ids,['invoice_ids']):
+				for inv in r['invoice_ids']:
+					wf_service = netsvc.LocalService("workflow")
+					wf_service.trg_validate(uid, 'account.invoice', inv, 'invoice_cancel', cr)
 		self.write(cr,uid,ids,{'state':'cancel'})
 		return True
 
@@ -305,18 +334,21 @@ class sale_order(osv.osv):
 				proc_id=False
 				if line.state == 'done':
 					continue
-				if line.product_id and line.product_id.product_tmpl_id.type=='product':
+				if line.product_id and line.product_id.product_tmpl_id.type in ('product', 'consu'):
 					location_id = order.shop_id.warehouse_id.lot_stock_id.id
 					if not picking_id:
 						loc_dest_id = order.partner_id.property_stock_customer[0]
 						picking_id = self.pool.get('stock.picking').create(cr, uid, {
-							'origin': 'SO:%d:%s' % (order.id, order.name),
+							'origin': order.name,
 							'type': 'out',
 							'state': 'auto',
 							'move_type': order.picking_policy,
 							'loc_move_id': loc_dest_id,
 							'sale_id': order.id,
 							'address_id': order.partner_shipping_id.id,
+							'note': order.note,
+							'invoice_state': (order.order_policy=='picking' and '2binvoiced') or 'none',
+
 						})
 
 					move_id = self.pool.get('stock.move').create(cr, uid, {
@@ -335,9 +367,11 @@ class sale_order(osv.osv):
 						'sale_line_id': line.id,
 						'tracking_id': False,
 						'state': 'waiting',
+						'note': line.notes,
 					})
 					proc_id = self.pool.get('mrp.procurement').create(cr, uid, {
-						'name': 'SO:'+order.name,
+						'name': order.name,
+						'origin': order.name,
 						'date_planned': line.date_planned,
 						'product_id': line.product_id.id,
 						'product_qty': line.product_uom_qty,
@@ -352,7 +386,7 @@ class sale_order(osv.osv):
 				elif line.product_id and line.product_id.product_tmpl_id.type=='service':
 					proc_id = self.pool.get('mrp.procurement').create(cr, uid, {
 						'name': line.name,
-						'origin': 'SO:'+order.name,
+						'origin': order.name,
 						'date_planned': line.date_planned,
 						'product_id': line.product_id.id,
 						'product_qty': line.product_uom_qty,
@@ -373,7 +407,7 @@ class sale_order(osv.osv):
 			if picking_id:
 				wf_service = netsvc.LocalService("workflow")
 				wf_service.trg_validate(uid, 'stock.picking', picking_id, 'button_confirm', cr)
-				val = {'picking_ids':[(6,0,[picking_id])]}
+				#val = {'picking_ids':[(6,0,[picking_id])]}
 
 			if order.state=='shipping_except':
 				val['state'] = 'progress'
@@ -405,7 +439,7 @@ class sale_order(osv.osv):
 	def has_stockable_products(self,cr, uid, ids, *args):
 		for order in self.browse(cr, uid, ids):
 			for order_line in order.order_line:
-				if order_line.product_id and order_line.product_id.product_tmpl_id.type=='product':
+				if order_line.product_id and order_line.product_id.product_tmpl_id.type in ('product', 'consu'):
 					return True
 		return False
 sale_order()
@@ -416,13 +450,22 @@ class sale_order_line(osv.osv):
 		default.update( {'invoice_lines':[]})
 		return super(sale_order_line, self).copy(cr, uid, id, default, context)
 
+	def _amount_line_net(self, cr, uid, ids, field_name, arg, context):
+		res = {}
+		for line in self.browse(cr, uid, ids):
+			if line.product_uos.id:
+				res[line.id] = line.price_unit * (1 - (line.discount or 0.0) /100.0)
+			else:
+				res[line.id] = line.price_unit * (1 - (line.discount or 0.0) / 100.0)
+		return res
+
 	def _amount_line(self, cr, uid, ids, field_name, arg, context):
 		res = {}
 		for line in self.browse(cr, uid, ids):
 			if line.product_uos.id:
-				res[line.id] = line.price_unit * line.product_uos_qty
+				res[line.id] = line.price_unit * line.product_uos_qty * (1 - (line.discount or 0.0) /100.0)
 			else:
-				res[line.id] = line.price_unit * line.product_uom_qty
+				res[line.id] = line.price_unit * line.product_uom_qty * (1 - (line.discount or 0.0) / 100.0)
 		return res
 
 	def _number_packages(self, cr, uid, ids, field_name, arg, context):
@@ -441,15 +484,16 @@ class sale_order_line(osv.osv):
 	_name = 'sale.order.line'
 	_description = 'Sale Order line'
 	_columns = {
-		'order_id': fields.many2one('sale.order', 'Order Ref', required=True, ondelete='cascade'),
-		'name': fields.char('Description', size=256, required=True),
+		'order_id': fields.many2one('sale.order', 'Order Ref', required=True, ondelete='cascade', select=True),
+		'name': fields.char('Description', size=256, required=True, select=True),
 		'sequence': fields.integer('Sequence'),
 		'date_planned': fields.date('Date Promised', required=True),
-		'product_id': fields.many2one('product.product', 'Product', domain=[('sale_ok','=',True)], change_default=True),
+		'product_id': fields.many2one('product.product', 'Product', domain=[('sale_ok','=',True)], change_default=True, relate=True),
 		'invoice_lines': fields.many2many('account.invoice.line', 'sale_order_line_invoice_rel', 'order_line_id','invoice_id', 'Invoice Lines', readonly=True),
-		'invoiced': fields.boolean('Paid', readonly=True),
+		'invoiced': fields.boolean('Paid', readonly=True, select=True),
 		'procurement_id': fields.many2one('mrp.procurement', 'Procurement'),
 		'price_unit': fields.float('Unit Price', required=True),
+		'price_net': fields.function(_amount_line_net, method=True, string='Net Price'),
 		'price_subtotal': fields.function(_amount_line, method=True, string='Subtotal'),
 		'tax_id': fields.many2many('account.tax', 'sale_order_tax', 'order_line_id', 'tax_id', 'Taxes'),
 		'type': fields.selection([('make_to_stock','from stock'),('make_to_order','on order')],'Procure Method', required=True),
@@ -462,6 +506,7 @@ class sale_order_line(osv.osv):
 		'product_packaging': fields.many2one('product.packaging', 'Packaging used'),
 		'move_ids': fields.one2many('stock.move', 'sale_line_id', 'Inventory Moves', readonly=True),
 		'property_ids': fields.many2many('mrp.property', 'sale_order_line_property_rel', 'order_id', 'property_id', 'Properties'),
+		'discount': fields.float('Discount (%)', digits=(16,2)),
 		'number_packages': fields.function(_number_packages, method=True, type='integer', string='Number packages'),
 		'notes': fields.text('Notes'),
 		'th_weight' : fields.float('Weight'),
@@ -470,6 +515,7 @@ class sale_order_line(osv.osv):
 	}
 	_order = 'sequence'
 	_defaults = {
+		'discount': lambda *a: 0.0,
 		'date_planned': lambda *a: time.strftime('%Y-%m-%d'),
 		'product_uom_qty': lambda *a: 1,
 		'product_uos_qty': lambda *a: 1,
@@ -489,7 +535,6 @@ class sale_order_line(osv.osv):
 		for line in self.browse(cr, uid, ids, context):
 			if not line.invoiced:
 				if line.product_id:
-					print line.product_id.product_tmpl_id.id
 					a =  line.product_id.product_tmpl_id.property_account_income
 					if not a:
 						a = line.product_id.categ_id.property_account_income_categ[0]
@@ -498,15 +543,17 @@ class sale_order_line(osv.osv):
 				else:
 					a = self.pool.get('ir.property').get(cr, uid, 'property_account_income_categ', 'product.category', context=context)
 				uosqty = _get_line_qty(line)
-				uos_id = line.product_uos and line.product_uos.accounting_uos_id
-				uos_id = (uos_id and uos_id.id) or False
+				uos_id = (line.product_uos and line.product_uos.id) or False
 				inv_id = self.pool.get('account.invoice.line').create(cr, uid, {
 					'name': line.name,
 					'account_id': a,
 					'price_unit': line.price_unit,
 					'quantity': uosqty,
+					'discount': line.discount,
 					'uos_id': uos_id,
-					'invoice_line_tax_id': [(6,0,[x.id for x in line.tax_id])]
+					'product_id': line.product_id.id or False,
+					'invoice_line_tax_id': [(6,0,[x.id for x in line.tax_id])],
+					'note': line.notes,
 				})
 				cr.execute('insert into sale_order_line_invoice_rel (order_line_id,invoice_id) values (%d,%d)', (line.id, inv_id))
 				self.write(cr, uid, [line.id], {'invoiced':True})
@@ -541,17 +588,33 @@ class sale_order_line(osv.osv):
 		default.update({'state':'draft', 'move_ids':[], 'invoiced':False, 'invoice_lines':[]})
 		return super(sale_order_line, self).copy(cr, uid, id, default, context)
 
-	def product_id_change(self, cr, uid, ids, pricelist, product, qty=0, uom=False, qty_uos=0, uos=False, name=''):
+	def product_id_change(self, cr, uid, ids, pricelist, product, qty=0, uom=False, qty_uos=0, uos=False, name='', partner_id=False, lang=False):
+		context = {'lang':lang}
 		if not product:
 			return {'value': {'price_unit': 0.0, 'notes':'', 'weight' : 0}, 'domain':{'product_uom':[]}}
 		if not pricelist:
 			raise osv.except_osv('No Pricelist !', 'You have to select a pricelist in the sale form !\nPlease set one before choosing a product.')
-		price = self.pool.get('product.pricelist').price_get(cr,uid,[pricelist], product, qty or 1.0)[pricelist]
-		res = self.pool.get('product.product').read(cr, uid, [product])[0]
+		price = self.pool.get('product.pricelist').price_get(cr,uid,[pricelist], product, qty or 1.0, partner_id, {'uom': uom})[pricelist]
+		if price is False:
+			raise osv.except_osv('No valid pricelist line found !', "Couldn't find a pricelist line matching this product and quantity.\nYou have to change either the product, the quantity or the pricelist.")
+		res = self.pool.get('product.product').read(cr, uid, [product], context=context)[0]
 		dt = (DateTime.now() + DateTime.RelativeDateTime(days=res['sale_delay'] or 0.0)).strftime('%Y-%m-%d')
-		result = {'price_unit': price, 'tax_id':res['taxes_id'], 'type':res['procure_method'], 'date_planned':dt, 'notes':res['description_sale']}
-		if not name:
-			result['name'] = res['name']
+
+		result = {'price_unit': price, 'type':res['procure_method'], 'date_planned':dt, 'notes':res['description_sale']}
+
+		taxes = self.pool.get('account.tax').browse(cr, uid, res['taxes_id'])
+		taxep = self.pool.get('res.partner').browse(cr, uid, partner_id).property_account_tax
+		if not taxep:
+			result['tax_id'] = res['taxes_id']
+		else:
+			res5 = [taxep[0]]
+			tp = self.pool.get('account.tax').browse(cr, uid, taxep[0])
+			for t in taxes:
+				if not t.tax_group==tp.tax_group:
+					res5.append(t.id)
+			result['tax_id'] = res5
+
+		result['name'] = res['partner_ref']
 		domain = {}
 		if not uom and not uos:
 			result['product_uom'] = res['uom_id'] and res['uom_id'][0]
@@ -579,7 +642,7 @@ class sale_payment_line(osv.osv):
 	_name = 'sale.order.payment'
 	_description = 'Sale Order payment'
 	_columns = {
-		'order_id': fields.many2one('sale.order', 'Order Ref'),
+		'order_id': fields.many2one('sale.order', 'Order Ref', select=True),
 		'name': fields.char('Description', size=64, required=True),
 		'account_id': fields.many2one('account.account', 'Account'),
 		'amount': fields.float('Amount', required=True),
