@@ -29,7 +29,7 @@
 
 import wizard
 import netsvc
-from osv.osv import osv_pools
+import pooler
 
 invoice_form = """<?xml version="1.0"?>
 <form string="Create invoices">
@@ -50,22 +50,51 @@ ack_form = """<?xml version="1.0"?>
 ack_fields = {}
 
 def _makeInvoices(self, cr, uid, data, context):
-	order_obj = osv_pools.get('sale.order')
+	order_obj = pooler.get_pool(cr.dbname).get('sale.order')
+	invoices = {}
+	for o in order_obj.browse(cr, uid, data['ids'], context):
+		for i in o.invoice_ids:
+			invoices[i.id] = False
+
 	order_obj.action_invoice_create(cr, uid, data['ids'], data['form']['grouped'])
 	for id in data['ids']:
 		wf_service = netsvc.LocalService("workflow")
 		wf_service.trg_validate(uid, 'sale.order', id, 'manual_invoice', cr)
+
+	for o in order_obj.browse(cr, uid, data['ids'], context):
+		for i in o.invoice_ids:
+			invoices.setdefault(i.id, True)
+
+	newinv = []
+	for key,val in invoices.items():
+	#	if val:
+		newinv.append(key)
+	return {
+		'domain': "[('id','in', ["+','.join(map(str,newinv))+"])]",
+		'name': 'Invoices',
+		'view_type': 'form',
+		'view_mode': 'tree,form',
+		'res_model': 'account.invoice',
+		'view_id': False,
+		'context': "{'type':'out_refund'}",
+		'type': 'ir.actions.act_window'
+	}
 	return {}
 
 class make_invoice(wizard.interface):
 	states = {
 		'init' : {
 			'actions' : [],
-			'result' : {'type' : 'form', 'arch' : invoice_form, 'fields' : invoice_fields, 'state' : [('end', 'Cancel'),('invoice', 'Create invoices') ]}
+			'result' : {'type' : 'form',
+				    'arch' : invoice_form,
+				    'fields' : invoice_fields,
+				    'state' : [('end', 'Cancel'),('invoice', 'Create invoices') ]}
 		},
 		'invoice' : {
 			'actions' : [_makeInvoices],
-			'result' : {'type' : 'form', 'arch' : ack_form, 'fields' : ack_fields, 'state' : [('end', 'Done')]}
+			'result' : {'type' : 'action',
+				    'action' : _makeInvoices,
+				    'state' : 'end'}
 		},
 	}
 make_invoice("sale.order.make_invoice")
