@@ -30,7 +30,7 @@
 import wizard
 import netsvc
 import ir
-from osv.osv import osv_pools
+import pooler
 
 invoice_form = """<?xml version="1.0"?>
 <form string="Create invoices">
@@ -44,7 +44,7 @@ invoice_fields = {
 }
 
 def _makeInvoices(self, cr, uid, data, context):
-	pool = osv_pools
+	pool = pooler.get_pool(cr.dbname)
 	res = False
 	factures = {}
 
