@@ -8,5 +8,6 @@
 	"init_xml" : [],
 	"demo_xml" : [],
 	"update_xml" : ["sale_crm_wizard.xml"],
-	"active": True
+	"active": False,
+	"installable": True
 }
