@@ -2,9 +2,10 @@
 	"name" : "Sandwich Module",
 	"author" : "Tiny",
 	"version" : "1.0",
+	"category" : "Generic Modules/Others",
 	"depends" : ["base", "product"],
 	"demo_xml" : ["sandwich_demo.xml"],
 	"update_xml" : ["sandwich_view.xml", "sandwich_report.xml", "sandwich_wizard.xml"],
-	"active": False
+	"active": False,
+	"installable": True
 }
-
