@@ -1,6 +1,7 @@
 import time
 
 from osv import osv, fields
+import pooler
 
 #
 # Type of type of products (food, drink, lsd, other...)
@@ -37,7 +38,7 @@ class sandwich_order(osv.osv):
 		'date': fields.date('Order date'),
 		'order_lines': fields.one2many('sandwich.order.line','order_id','Order lines'),
 		'note': fields.text('Notes'),
-		'partner': fields.many2one('res.partner','Partner'),
+		'partner': fields.many2one('res.partner','Partner', required=True),
 	}
 	_defaults = {
 		'date': lambda *a: time.strftime('%Y-%m-%d'),
@@ -89,7 +90,7 @@ class sandwich_order_line(osv.osv):
 	def onchange_product_id(self, cr, uid, id, product_id, context={}):
 		if not product_id:
 			return {}
-		res = osv.osv_pools.get('sandwich.product').read(cr, uid, [ product_id ], ['name','product_type_id'])
+		res = pooler.get_pool(cr.dbname).get('sandwich.product').read(cr, uid, [ product_id ], ['name','product_type_id'])
 		return {'value': res}
 		#return {'value': {'name': name or product_id.name, 'product_type_id': product_id.product_type_id}}
 
