@@ -7,5 +7,6 @@
 	"init_xml" : [],
 	"demo_xml" : ["scrum_demo.xml"],
 	"update_xml": ["scrum_view.xml","scrum_report.xml", "scrum_wizard.xml"],
-	"active": True
+	"active": False,
+	"installable": True
 }
