@@ -78,7 +78,7 @@ class stock_location(osv.osv):
 		'allocation_method': fields.selection([('fifo','FIFO'),('lifo','LIFO'),('nearest','Nearest')], 'Allocation Method', required=True),
 
 		'account_id': fields.many2one('account.account', string='Inventory Account', domain=[('type','=','stock_inventory')]),
-		'location_id': fields.many2one('stock.location', 'Parent Location'),
+		'location_id': fields.many2one('stock.location', 'Parent Location', select=True),
 		'child_ids': fields.one2many('stock.location', 'location_id', 'Contains'),
 
 		'comment': fields.text('Additional Information'),
@@ -113,6 +113,7 @@ class stock_location(osv.osv):
 					result.append({
 						'price': product.list_price,
 						'name': product.name,
+						'code': product.default_code, # used by lot_overview_all report !
 						'variants': product.variants or '',
 						'uom': product.uom_id.name,
 						'amount':qty[prod_id]
@@ -310,9 +311,9 @@ class stock_picking(osv.osv):
 	_name = "stock.picking"
 	_description = "Picking list"
 	_columns = {
-		'name': fields.char('Picking Name', size=64, required=True),
+		'name': fields.char('Picking Name', size=64, required=True, select=True),
 		'origin': fields.char('Origin', size=64),
-		'type': fields.selection([('out','Sending Goods'),('in','Getting Goods'),('internal','Internal')], 'Shipping Type', required=True),
+		'type': fields.selection([('out','Sending Goods'),('in','Getting Goods'),('internal','Internal')], 'Shipping Type', required=True, select=True),
 		'active': fields.boolean('Active'),
 		'note': fields.text('Notes'),
 
@@ -337,7 +338,11 @@ class stock_picking(osv.osv):
 		'loc_move_id': fields.many2one('stock.location', 'Move to Location'),
 		'address_id': fields.many2one('res.partner.address', 'Partner Address'),
 		'lot_id': fields.many2one('stock.lot', 'Consumer Lot Created'),
-		'move_lot_id': fields.many2one('stock.move.lot', 'Moves Created')
+		'move_lot_id': fields.many2one('stock.move.lot', 'Moves Created'),
+		'invoice_state':fields.selection([
+			("invoiced","Invoiced"),
+			("2binvoiced","To be invoiced"),
+			("none","No invoice")], "Invoice state"),
 	}
 	_defaults = {
 		'name': lambda *a: 'Unconfirmed picking',
@@ -346,8 +351,10 @@ class stock_picking(osv.osv):
 		'state': lambda *a: 'draft',
 		'move_type': lambda *a: 'direct',
 		'type': lambda *a: 'in',
+		'invoice_state': lambda *a: 'none',
 		'date': lambda *a: time.strftime('%Y-%m-%d %H:%M:%S'),
 	}
+
 	def action_confirm(self, cr, uid, ids, *args):
 		self.write(cr, uid, ids, {'state': 'confirmed'})
 		todo = []
@@ -408,7 +415,7 @@ class stock_picking(osv.osv):
 		for pick in self.browse(cr, uid, ids):
 			ids2 = [move.id for move in pick.move_lines]
 			self.pool.get('stock.move').action_cancel(cr, uid, ids2, context)
-		self.write(cr,uid, ids, {'state':'cancel'})
+		self.write(cr,uid, ids, {'state':'cancel', 'invoice_state':'none'})
 		return True
 
 	#
@@ -453,19 +460,125 @@ class stock_picking(osv.osv):
 					})
 					self.write(cr, uid, [pick.id], {'move_lot_id':id})
 		return True
+
+	def action_invoice_create(self, cr, uid, ids, journal_id=False, group=False, type='out_invoice', context={}):
+		res={}
+		pgroup = {}
+		get_ids = lambda y: map(lambda x: x.id, y or [])
+		sales = {}
+		for p in self.browse(cr,uid,ids, context):
+			if p.invoice_state<>'2binvoiced':
+				continue
+			a = p.address_id.partner_id.property_account_receivable[0]
+			if p.address_id.partner_id and p.address_id.partner_id.property_payment_term:
+				pay_term = p.address_id.partner_id.property_payment_term[0]
+			else:
+				pay_term = False
+
+			if p.sale_id:
+				pinv_id = p.sale_id.partner_invoice_id.id
+				pcon_id = p.sale_id.partner_order_id.id
+				if p.sale_id.id not in sales:
+					sales[p.sale_id.id] = [x.id for x in p.sale_id.invoice_ids]
+			else:
+				#
+				# ideal: get_address('invoice') on partner
+				#
+				pinv_id = p.address_id.id
+				pcon_id = p.address_id.id
+
+			val = {
+				'name': p.name,
+				'origin': p.name+':'+p.origin,
+				'type': type,
+				'reference': "P%dSO%d"%(p.address_id.partner_id.id,p.id),
+				'account_id': a,
+				'partner_id': p.address_id.partner_id.id,
+				'address_invoice_id': pinv_id,
+				'address_contact_id': pcon_id,
+				'project_id': (p.sale_id and p.sale_id.project_id.id) or False,
+				'comment': (p.note or '') + '\n' + (p.sale_id and p.sale_id.note or ''),
+				'payment_term': pay_term,
+			}
+			if p.sale_id:
+				val['currency_id'] = (p.sale_id and p.sale_id.pricelist_id.currency_id.id) or False
+			if journal_id:
+				val['journal_id'] = journal_id
+
+			if group and p.address_id.partner_id.id in pgroup:
+				invoice_id= pgroup[p.address_id.partner_id.id]
+			else:
+				invoice_id = self.pool.get('account.invoice').create(cr, uid, val ,context= context)
+				pgroup[p.address_id.partner_id.id] = invoice_id
+
+
+			res[p.id]= invoice_id
+
+			for line in p.move_lines:
+				tax_ids = map(lambda x: x.id, line.product_id.taxes_id)
+				a =  line.product_id.product_tmpl_id.property_account_income
+				if not a:
+					a = line.product_id.categ_id.property_account_income_categ
+				account_id =  a[0]
+				punit = line.sale_line_id and line.sale_line_id.price_unit or line.product_id.list_price
+				if type in ('in_invoice','in_refund'):
+					punit = line.product_id.standard_price
+				iline_id = self.pool.get('account.invoice.line').create(cr, uid, {
+					'name': p.name + ' - ' + line.name,
+					'invoice_id': invoice_id,
+					'uos_id': line.product_uos.id,
+					'product_id': line.product_id.id,
+					'account_id': account_id,
+					'price_unit': line.sale_line_id and line.sale_line_id.price_unit or line.product_id.list_price,
+					'quantity': line.product_uos_qty,
+					'invoice_line_tax_id': [(6,0,tax_ids)]
+				})
+				if line.sale_line_id:
+					self.pool.get('sale.order.line').write(cr, uid, [line.sale_line_id.id], {
+						'invoice_line_ids': [(6, 0, [iline_id])]
+					})
+
+			self.pool.get('stock.picking').write(cr, uid, [p.id], {'invoice_state': 'invoiced'})
+			if p.sale_id:
+				sids = sales[p.sale_id.id]
+				if invoice_id not in sids:
+					sales[p.sale_id.id].append(invoice_id)
+					self.pool.get('sale.order').write(cr, uid, [p.sale_id.id], {
+						'invoice_ids': [(6, 0, sales[p.sale_id.id])]
+					})
+
+				self.pool.get('sale.order').write(cr, uid, [p.sale_id.id], {
+					'invoiced': True
+				})
+		return res
 stock_picking()
 
 class stock_production_lot(osv.osv):
+
+	def name_get(self, cr, uid, ids, context={}):
+		if not ids:
+			return []
+		reads = self.read(cr, uid, ids, ['name', 'ref'], context)
+		res=[]
+		for record in reads:
+			name=record['name']
+			if record['ref']:
+				name=name+'/'+record['ref']
+			res.append((record['id'], name))
+		return res
+
 	_name = 'stock.production.lot'
 	_description = 'Production lot'
 
 	_columns = {
-		'name': fields.char('Code', size=15, required=True),
+		'name': fields.char('Code', size=64, required=True),
+		'ref': fields.char('Reference', size=64),
 		'date': fields.datetime('Date create', required=True),
 		'revisions': fields.one2many('stock.production.lot.revision','lot_id','Revisions'),
 	}
 	_defaults = {
 		'date': lambda *a: time.strftime('%Y-%m-%d %H:%M:%S'),
+		'name': lambda x,y,z,c: x.pool.get('ir.sequence').get(y,z,'stock.lot.serial'),
 	}
 stock_production_lot()
 
@@ -478,7 +591,7 @@ class stock_production_lot_revision(osv.osv):
 		'date': fields.date('Revision date'),
 		'indice': fields.char('Revision', size=16),
 		'author_id': fields.many2one('res.users', 'Author'),
-		'lot_id': fields.many2one('stock.production.lot', 'Production lot'),
+		'lot_id': fields.many2one('stock.production.lot', 'Production lot', select=True),
 	}
 
 	_defaults = {
@@ -504,7 +617,7 @@ class stock_move(osv.osv):
 	_description = "Stock Move"
 
 	_columns = {
-		'name': fields.char('Name', size=64, required=True),
+		'name': fields.char('Name', size=64, required=True, select=True),
 		'priority': fields.selection([('0','Not urgent'),('1','Urgent')], 'Priority'),
 
 		'date': fields.datetime('Date Created'),
@@ -523,15 +636,17 @@ class stock_move(osv.osv):
 		'address_id' : fields.many2one('res.partner.address', 'Dest. Address'),
 
 		'prodlot_id' : fields.many2one('stock.production.lot', 'Production lot'),
-		'tracking_id': fields.many2one('stock.tracking', 'Lot Tracking'),
-		'lot_id': fields.many2one('stock.lot', 'Lot'),
+		'tracking_id': fields.many2one('stock.tracking', 'Lot Tracking', select=True),
+		'lot_id': fields.many2one('stock.lot', 'Lot', select=True),
 
 		'move_dest_id': fields.many2one('stock.move', 'Dest. Move'),
 		'move_history_ids': fields.many2many('stock.move', 'stock_move_history_ids', 'parent_id', 'child_id', 'Move History'),
 		'move_history_ids2': fields.many2many('stock.move', 'stock_move_history_ids', 'child_id', 'parent_id', 'Move History'),
-		'picking_id': fields.many2one('stock.picking', 'Picking list'),
+		'picking_id': fields.many2one('stock.picking', 'Picking list', select=True),
 
-		'state': fields.selection([('draft','Draft'),('waiting','Waiting'),('confirmed','Confirmed'),('assigned','Assigned'),('done','Done'),('cancel','cancel')], 'State', readonly=True),
+		'note': fields.text('Notes'),
+
+		'state': fields.selection([('draft','Draft'),('waiting','Waiting'),('confirmed','Confirmed'),('assigned','Assigned'),('done','Done'),('cancel','cancel')], 'State', readonly=True, select=True),
 	}
 	_defaults = {
 		'state': lambda *a: 'draft',
@@ -577,6 +692,9 @@ class stock_move(osv.osv):
 		done = []
 		pickings = {}
 		for move in self.browse(cr, uid, ids):
+			if move.product_id.type == 'consu':
+				done.append(move.id)
+				continue
 			if move.state in ('confirmed','waiting'):
 				res = self.pool.get('stock.location')._product_reserve(cr, uid, [move.location_id.id], move.product_id.id, move.product_qty, {'uom': move.product_uom.id})
 				if res:
@@ -585,13 +703,13 @@ class stock_move(osv.osv):
 					r = res.pop(0)
 					cr.execute('update stock_move set location_id=%d, product_qty=%f where id=%d', (r[1],r[0], move.id))
 
-					while len(res):
+					while res:
 						r = res.pop(0)
 						move_id = self.copy(cr, uid, move.id, {'product_qty':r[0], 'location_id':r[1]})
 						done.append(move_id)
 						#cr.execute('insert into stock_move_history_ids values (%d,%d)', (move.id,move_id))
 
-		if len(done):
+		if done:
 			self.write(cr, uid, done, {'state':'assigned'})
 			for pick_id in pickings:
 				wf_service = netsvc.LocalService("workflow")
@@ -740,7 +858,7 @@ class stock_inventory_line(osv.osv):
 	_name = "stock.inventory.line"
 	_description = "Inventory line"
 	_columns = {
-		'inventory_id': fields.many2one('stock.inventory','Inventory', ondelete='cascade'),
+		'inventory_id': fields.many2one('stock.inventory','Inventory', ondelete='cascade', select=True),
 		'location_id': fields.many2one('stock.location','Location', required=True),
 		'product_id': fields.many2one('product.product', 'Product', required=True ),
 		'product_uom': fields.many2one('product.uom', 'Product UOM', required=True ),
@@ -767,10 +885,56 @@ class stock_warehouse(osv.osv):
 	_columns = {
 		'name': fields.char('Name', size=60, required=True),
 #		'partner_id': fields.many2one('res.partner', 'Owner'),
-#		'partner_address_id': fields.many2one('res.partner.address', 'Owner Address'),
+		'partner_address_id': fields.many2one('res.partner.address', 'Owner Address'),
 		'lot_input_id': fields.many2one('stock.location', 'Location Input', required=True ),
 		'lot_stock_id': fields.many2one('stock.location', 'Location Stock', required=True ),
 		'lot_output_id': fields.many2one('stock.location', 'Location Output', required=True ),
 	}
 stock_warehouse()
 
+
+# Product
+class product_product(osv.osv):
+	_inherit = "product.product"
+	#
+	# Utiliser browse pour limiter les queries !
+	#
+	def _get_product_available_func(states, what):
+		def _product_available(self, cr, uid, ids, name, arg, context={}):
+			if context.get('shop', False):
+				cr.execute('select warehouse_id from sale_shop where id=%d', (int(context['shop']),))
+				res2 = cr.fetchone()
+				if res2:
+					context['warehouse'] = res2[0]
+
+			if context.get('warehouse', False):
+				cr.execute('select lot_stock_id from stock_warehouse where id=%d', (int(context['warehouse']),))
+				res2 = cr.fetchone()
+				if res2:
+					context['location'] = res2[0]
+
+			if context.get('location', False):
+				location_ids = [context['location']]
+			else:
+				# get the list of ids of the stock location of all warehouses
+				cr.execute("select lot_stock_id from stock_warehouse")
+				location_ids = [id for (id,) in cr.fetchall()]
+				
+			# build the list of ids of children of the location given by id
+			location_ids = self.pool.get('stock.location').search(cr, uid, [('location_id', 'child_of', location_ids)])
+			res = self.pool.get('stock.location')._product_get_multi_location(cr, uid, location_ids, ids, context, states, what)
+			for id in ids:
+				res.setdefault(id, 0.0)
+			return res
+		return _product_available
+	_product_qty_available = _get_product_available_func(('done',), ('in', 'out'))
+	_product_virtual_available = _get_product_available_func(('confirmed','waiting','assigned','done'), ('in', 'out'))
+	_product_outgoing_qty = _get_product_available_func(('confirmed','waiting','assigned'), ('out',))
+	_product_incoming_qty = _get_product_available_func(('confirmed','waiting','assigned'), ('in',))
+	_columns = {
+		'qty_available': fields.function(_product_qty_available, method=True, type='float', string='Real Stock'),
+		'virtual_available': fields.function(_product_virtual_available, method=True, type='float', string='Virtual Stock'),
+		'incoming_qty': fields.function(_product_incoming_qty, method=True, type='float', string='Incoming'),
+		'outgoing_qty': fields.function(_product_outgoing_qty, method=True, type='float', string='Outgoing'),
+	}
+product_product()
