@@ -44,6 +44,7 @@ import string
 import netsvc
 
 import psycopg
+import warnings
 
 def _symbol_set(symb):
 	if symb==None or symb==False:
@@ -63,7 +64,7 @@ class _column(object):
 	_symbol_set = (_symbol_c, _symbol_f)
 	_symbol_get = None
 
-	def __init__(self, string='unknown', required=False, readonly=False, domain=[], context='', states={}, priority=0, change_default=False, size=None, ondelete="set null", translate=False, **args):
+	def __init__(self, string='unknown', required=False, readonly=False, domain=[], context='', states={}, priority=0, change_default=False, size=None, ondelete="set null", translate=False, select=False, **args):
 		self.states = states
 		self.string = string
 		self.readonly = readonly
@@ -79,6 +80,7 @@ class _column(object):
 		self._context = context
 		self.group_name = False
 		self.view_load = 0
+		self.select=select
 		for a in args:
 			if args[a]:
 				setattr(self, a, args[a])
@@ -233,6 +235,7 @@ class one2one(_column):
 	_type = 'one2one'
 	
 	def __init__(self, obj, string='unknown', **args):
+		warnings.warn("The one2one field doesn't work anymore", DeprecationWarning)
 		_column.__init__(self, string=string, **args)
 		self._obj = obj
 
@@ -437,6 +440,7 @@ class function(_column):
 		
 	def search(self, cr, uid, obj, name, args):
 		if not self._fnct_search:
+			#CHECKME: should raise an exception
 			return []
 		return self._fnct_search(obj, cr, uid, obj, name, args)
 
