@@ -51,7 +51,7 @@
 from xml import dom
 from xml.parsers import expat
 import string
-import sql_db
+import pooler
 import psycopg
 import netsvc
 import re
@@ -83,13 +83,6 @@ class except_orm(Exception):
 #		p.Parse(datas, 1)
 #		return self.datas
 
-def get_inherit_id(obj_type, obj_id):
-	cr=sql_db.db.cursor()
-	cr.execute('select inst_type, inst_id from inherit where obj_type=%s and obj_id=%d', (obj_type, obj_id))
-	result = cr.dictfetchone()
-	cr.close()
-	return result
-
 #
 # TODO: trigger pour chaque action
 #
@@ -146,6 +139,8 @@ class browse_record(object):
 				col = self._table._columns[name]
 			elif name in self._table._inherit_fields:
 				col = self._table._inherit_fields[name][2]
+			elif hasattr(self._table, name):
+				return getattr(self._table, name)
 			else:
 				print "Programming error: field '%s' does not exist in object '%s' !" % (name, self._table._name)
 				return False
@@ -242,6 +237,8 @@ def get_pg_type(f):
 		f_type = None
 	return f_type
 
+		
+	
 class orm(object):
 	_columns = {}
 	_sql_constraints = []
@@ -256,18 +253,31 @@ class orm(object):
 	_sequence = None
 	_description = None
 	_protected = ['read','write','create','default_get','perm_read','perm_write','unlink','fields_get','fields_view_get','search','name_get','distinct_field_get','name_search','copy','import_data']
-	def _auto_init(self, cr):
-		create = False
-		if not hasattr(self, "_auto") or self._auto:
-			cr.execute("SELECT id FROM ir_model WHERE model='%s'" % self._name)
-			if not cr.rowcount:
-				# reference model in order to have a description of its fonctionnality in custom_report
-				cr.execute("INSERT INTO ir_model (model, name, info) VALUES (%s, %s, %s)", (self._name, self._description, self.__doc__)) 
-			cr.commit()
+	def _field_create(self, cr):
+		cr.execute("SELECT id FROM ir_model WHERE model='%s'" % self._name)
+		if not cr.rowcount:
+			# reference model in order to have a description of its fonctionnality in custom_report
+			cr.execute("INSERT INTO ir_model (model, name, info) VALUES (%s, %s, %s)", (self._name, self._description, self.__doc__)) 
+		cr.commit()
 
+		for k in self._columns:
+			f = self._columns[k]
+			cr.execute("select id from ir_model_fields where model=%s and name=%s", (self._name,k))
+			if not cr.rowcount:
+				cr.execute("select id from ir_model where model='%s'" % self._name)
+				model_id = cr.fetchone()[0]
+				cr.execute("INSERT INTO ir_model_fields (model_id, model, name, field_description, ttype, relate,relation,group_name,view_load) VALUES (%d,%s,%s,%s,%s,%s,%s,%s,%s)", (model_id, self._name, k, f.string.replace("'", " "), f._type, (f.relate and 'True') or 'False', f._obj or 'NULL', f.group_name or '', (f.view_load and 'True') or 'False'))
+		cr.commit()
+
+	def _auto_init(self, cr):
+#		print '*' * 60
+#		print "auto_init", self._name, self._columns
+		create = False
+		self._field_create(cr)
+		if not hasattr(self, "_auto") or self._auto:
 			cr.execute("SELECT relname FROM pg_class WHERE relkind in ('r','v') AND relname='%s'" % self._table)
 			if not cr.rowcount:
-				cr.execute("CREATE TABLE %s(id SERIAL NOT NULL, perm_id INTEGER, PRIMARY KEY(id))" % self._table)
+				cr.execute("CREATE TABLE %s(id SERIAL NOT NULL, perm_id INTEGER, PRIMARY KEY(id)) WITH OIDS" % self._table)
 				create = True
 			cr.commit()
 			if self._log_access:
@@ -308,12 +318,6 @@ class orm(object):
 					#raise 'Can not define a column %s. Reserved keyword !' % (k,)
 				f = self._columns[k]
 
-				cr.execute("select id from ir_model_fields where model=%s and name=%s", (self._name,k))
-				if not cr.rowcount:
-					cr.execute("select id from ir_model where model='%s'" % self._name)
-					model_id = cr.fetchone()[0]
-					cr.execute("INSERT INTO ir_model_fields (model_id, model, name, field_description, ttype, relate,relation,group_name,view_load) VALUES (%d,%s,%s,%s,%s,%s,%s,%s,%s)", (model_id, self._name, k, f.string.replace("'", " "), f._type, (f.relate and 'True') or 'False', f._obj or 'NULL', f.group_name or '', (f.view_load and 'True') or 'False'))
-				
 				if isinstance(f, fields.one2many):
 					cr.execute("SELECT relname FROM pg_class WHERE relkind='r' AND relname='%s'"%f._obj)
 					if cr.fetchone():
@@ -330,7 +334,7 @@ class orm(object):
 							ref = self.pool.get(f._obj)._table
 						except AttributeError:
 							ref = f._obj.replace('.','_')
-						cr.execute("CREATE TABLE %s (%s INTEGER NOT NULL REFERENCES %s ON DELETE CASCADE, %s INTEGER NOT NULL REFERENCES %s ON DELETE CASCADE)"%(f._rel,f._id1,self._table,f._id2,ref))
+						cr.execute("CREATE TABLE %s (%s INTEGER NOT NULL REFERENCES %s ON DELETE CASCADE, %s INTEGER NOT NULL REFERENCES %s ON DELETE CASCADE) WITH OIDS"%(f._rel,f._id1,self._table,f._id2,ref))
 						cr.execute("CREATE INDEX %s_%s_index ON %s (%s)" % (f._rel,f._id1,f._rel,f._id1))
 						cr.execute("CREATE INDEX %s_%s_index ON %s (%s)" % (f._rel,f._id2,f._rel,f._id2))
 						cr.commit()
@@ -360,6 +364,7 @@ class orm(object):
 								except AttributeError:
 									ref = f._obj.replace('.','_')
 								cr.execute("ALTER TABLE %s ADD FOREIGN KEY (%s) REFERENCES %s ON DELETE %s" % (self._table, k, ref, f.ondelete))
+							if f.select:
 								cr.execute("CREATE INDEX %s_%s_index ON %s (%s)" % (self._table, k, self._table, k))
 							if f.required:
 								cr.commit()
@@ -421,6 +426,14 @@ class orm(object):
 							elif not f.required and f_pg_notnull == 1:
 								cr.execute("ALTER TABLE %s ALTER COLUMN %s DROP NOT NULL" % (self._table,k))
 								cr.commit()
+							cr.execute("SELECT indexname FROM pg_indexes WHERE indexname = '%s_%s_index' and tablename = '%s'" % (self._table, k, self._table))
+							res = cr.dictfetchall()
+							if not res and f.select:
+								cr.execute("CREATE INDEX %s_%s_index ON %s (%s)" % (self._table, k, self._table, k))
+								cr.commit()
+							if res and not f.select:
+								cr.execute("DROP INDEX %s_%s_index" % (self._table, k))
+								cr.commit()
 					else:
 						print "ERROR"
 		else:
@@ -439,8 +452,6 @@ class orm(object):
 						cr.execute(line2)
 						cr.commit()
 
-			
-
 	def __init__(self):
 		if not self._table:
 			self._table=self._name.replace('.','_')
@@ -448,19 +459,8 @@ class orm(object):
 			self._description = self._name
 		for (key,_,msg) in self._sql_constraints:
 			self.pool._sql_error[self._table+'_'+key] = msg
-		module = str(self.__class__)[6:]
-		module = module[:len(module)-1]
-		module = module.split('.')[0][2:]
-
-		if hasattr(self,'_auto_init') and ((module in tools.config['update']) or (module in tools.config['init'])):
-			cr=sql_db.db.cursor()
-			if hasattr(self,'init'):
-				self.init(cr)
-			self._auto_init(cr)
-			cr.commit()
-			cr.close()
-			del cr
-
+		
+#		if self.__class__.__name__ != 'fake_class':
 		self._inherits_reload()
 		if not self._sequence:
 			self._sequence = self._table+'_id_seq'
@@ -566,11 +566,13 @@ class orm(object):
 						for key,val in fields_def[field[len(prefix)]]['selection']:
 							if val==line[i]:
 								res = key
+						if line[i] and not res:
+							print 'WARNING, key',line[i],'not found in selection field', field[len(prefix)]
 					elif fields_def[field[len(prefix)]]['type']=='many2one':
 						res = False
 						if line[i]:
 							relation = fields_def[field[len(prefix)]]['relation']
-							res2 = self.pool.get(relation).name_search(cr, uid, line[i], [])
+							res2 = self.pool.get(relation).name_search(cr, uid, line[i], [],operator='=')
 							res = (res2 and res2[0][0]) or False
 							if not res and line[i]:
 								warning += ('Relation not found: '+line[i]+' on '+relation + ' !\n')
@@ -581,7 +583,7 @@ class orm(object):
 						if line[i]:
 							relation = fields_def[field[len(prefix)]]['relation']
 							for word in line[i].split(','):
-								res2 = self.pool.get(relation).name_search(cr, uid, word, [])
+								res2 = self.pool.get(relation).name_search(cr, uid, word, [],operator='=')
 								res3 = (res2 and res2[0][0]) or False
 								if res3:
 									res.append(res3)
@@ -667,7 +669,7 @@ class orm(object):
 		fields_pre = filter(lambda x: x in self._columns and getattr(self._columns[x],'_classic_write'), fields) + self._inherits.values()
 
 		if len(fields_pre):
-			cr.execute('select %s from %s where id in (%s) order by %s' % (','.join(fields_pre + ['id']), self._table, ','.join([str(x) for x in ids]), self._order))
+			cr.execute('select %s from %s where id = any(array[%s]) order by %s' % (','.join(fields_pre + ['id']), self._table, ','.join([str(x) for x in ids]), self._order))
 		
 			if not cr.rowcount:
 				return []
@@ -732,7 +734,6 @@ class orm(object):
 
 	def default_get(self, cr, uid, fields, context={}):
 		value = {}
-		
 		# get the default values for the inherited fields
 		for t in self._inherits.keys():
 			value.update(self.pool.get(t).default_get(cr, uid, fields, context))
@@ -755,7 +756,7 @@ class orm(object):
 		if self._log_access:
 			fields +=', u.create_uid, u.create_date, u.write_uid, u.write_date'
 		ids_str = string.join(map(lambda x:str(x), ids),',')
-		cr.execute('select u.id'+fields+' from perm p right join '+self._table+' u on u.perm_id=p.id where u.id in ('+ids_str+')')
+		cr.execute('select u.id'+fields+' from perm p right join '+self._table+' u on u.perm_id=p.id where u.id=any(array['+ids_str+'])')
 		res = cr.dictfetchall()
 #		for record in res:
 #			for f in ('ox','ux','gx','uid','gid'):
@@ -818,7 +819,7 @@ class orm(object):
 				updend.append(field)
 		if self._log_access:
 			upd0.append('write_uid=%d')
-			upd0.append('write_date=current_timestamp')
+			upd0.append('write_date=current_timestamp(0)')
 			upd1.append(user)
 
 		if len(upd0):
@@ -914,7 +915,7 @@ class orm(object):
 				upd_todo.append(field)
 		if self._log_access:
 			upd0 += ',create_uid,create_date'
-			upd1 += ',%d,current_timestamp'
+			upd1 += ',%d,current_timestamp(0)'
 			upd2.append(user)
 		cr.execute('insert into '+self._table+' (id,perm_id'+upd0+") values ("+str(id_new)+',NULL'+upd1+')', tuple(upd2))
 		upd_todo.sort(lambda x,y: self._columns[x].priority-self._columns[y].priority)
@@ -957,7 +958,7 @@ class orm(object):
 			res.update(self.pool.get(parent).fields_get(cr, user, fields, context))
 		for f in self._columns.keys():
 			res[f] = {'type': self._columns[f]._type}
-			for arg in ('string','readonly','states','size','required','change_default','translate', 'help'):
+			for arg in ('string','readonly','states','size','required','change_default','translate', 'help', 'select'):
 				if getattr(self._columns[f], arg):
 					res[f][arg] = getattr(self._columns[f], arg)
 			for arg in ('digits', 'invisible'):
@@ -1036,9 +1037,10 @@ class orm(object):
 			if result:
 				node.setAttribute('string', result)
 
-		if node.nodeType==node.ELEMENT_NODE:
+		if node.nodeType == node.ELEMENT_NODE:
+			# translate view
 			if ('lang' in context) and node.hasAttribute('string') and node.getAttribute('string') and not result:
-				trans =  tools.translate(cr, user, self._name, 'view', context['lang'], node.getAttribute('string').encode('utf8'))
+				trans = tools.translate(cr, user, self._name, 'view', context['lang'], node.getAttribute('string').encode('utf8'))
 				if trans:
 					node.setAttribute('string', trans.decode('utf8'))
 			#
@@ -1053,16 +1055,16 @@ class orm(object):
 				cr.execute('select id,name,group_name from ir_model_fields where model in ('+','.join(models)+') and view_load order by group_name, id')
 				oldgroup = None
 				res = cr.fetchall()
-				for (id,fname,gname) in res:
-					if oldgroup<>gname:
+				for id, fname, gname in res:
+					if oldgroup != gname:
 						child = doc.createElement('separator')
-						child.setAttribute('string',gname)
-						child.setAttribute('colspan',"4")
-						oldgroup=gname
+						child.setAttribute('string', gname)
+						child.setAttribute('colspan', "4")
+						oldgroup = gname
 						parent.insertBefore(child, node)
 
 					child = doc.createElement('field')
-					child.setAttribute('name',fname)
+					child.setAttribute('name', fname)
 					parent.insertBefore(child, node)
 				parent.removeChild(node)
 
@@ -1083,7 +1085,7 @@ class orm(object):
 	#
 	# if view_id, view_type is not required
 	#
-	def fields_view_get(self, cr, user, view_id=None, view_type='form', context={}):
+	def fields_view_get(self, cr, user, view_id=None, view_type='form', context={}, toolbar=False):
 		def _inherit_apply(src, inherit):
 			def _find(node, node2):
 				if node.nodeType==node.ELEMENT_NODE and node.localName==node2.localName:
@@ -1101,6 +1103,7 @@ class orm(object):
 					res = _find(child, node2)
 					if res: return res
 				return None
+
 			doc_src = dom.minidom.parseString(src)
 			doc_dest = dom.minidom.parseString(inherit)
 			for node2 in doc_dest.childNodes:
@@ -1159,50 +1162,66 @@ class orm(object):
 			view_id = ok or sql_res[3]
 			model = False
 
+		# if a view was found
 		if sql_res:
 			result['type'] = sql_res[4]
 			result['view_id'] = sql_res[3]
 			result['arch'] = sql_res[0]
 
-			cr.execute('select arch from ir_ui_view where inherit_id=%d and model=%s order by priority', (sql_res[3],self._name))
+			# get all views which inherit from (ie modify) this view
+			cr.execute('select arch from ir_ui_view where inherit_id=%d and model=%s order by priority', (sql_res[3], self._name))
 			sql_inherit = cr.fetchall()
 			for (inherit,) in sql_inherit:
 				result['arch'] = _inherit_apply(result['arch'], inherit)
 
 			result['name'] = sql_res[1]
-			#ff = find_fields()
-			#all_fields = ff.parse(result['arch']).keys()
-			#del ff
-			result['field_parent']=sql_res[2] or False
+			result['field_parent'] = sql_res[2] or False
 		else:
-			if view_type=='form':
+			# otherwise, build some kind of default view
+			if view_type == 'form':
 				res = self.fields_get(cr, user, context=context)
-				xml = "<?xml version=\"1.0\"?>\n<form string=\"%s\">\n" % (self._description,)
+				xml = '''<?xml version="1.0"?>\n<form string="%s">\n''' % (self._description,)
 				for x in res:
-					if res[x]['type'] not in ('one2many','many2many'):
-						xml += "\t<field name=\"%s\"/>\n" % (x,)
-						if res[x]['type']=='text':
+					if res[x]['type'] not in ('one2many', 'many2many'):
+						xml += '\t<field name="%s"/>\n' % (x,)
+						if res[x]['type'] == 'text':
 							xml += "<newline/>"
 				xml += "</form>"
-			elif view_type=='tree':
-				res = self.fields_get(cr, user, [self._rec_name], context)
+			elif view_type == 'tree':
 				xml = '''<?xml version="1.0"?>\n<tree string="%s">\n\t<field name="%s"/>\n</tree>''' % (self._description,self._rec_name)
 			else:
 				xml = ''
 			result['arch'] = xml
 			result['name'] = 'default'
-			result['field_parent']=False
+			result['field_parent'] = False
 			result['view_id'] = 0
 
 		doc = dom.minidom.parseString(result['arch'])
-		xarch,xfields  = self.__view_look_dom_arch(cr, user, doc, context=context)
+		xarch, xfields = self.__view_look_dom_arch(cr, user, doc, context=context)
 		result['arch'] = xarch
 		result['fields'] = xfields
-
-		#for f in fields:
-		#	if len(fields[f]):
-		#		for typ in fields[f].split(','):
-		#			result['fields'][f]['view_data_'+str(typ)] = self.pool.get(result['fields'][f]['relation']).fields_view_get(cr, user, None, str(typ))
+		if toolbar:
+			resprint = self.pool.get('ir.values').get(cr, user, 'action', 'client_print_multi', [(self._name, False)], False, context)
+			resaction = self.pool.get('ir.values').get(cr, user, 'action', 'client_action_multi', [(self._name, False)], False, context)
+			resprint = map(lambda x:x[2], resprint)
+			resaction = map(lambda x:x[2], resaction)
+			resaction = filter(lambda x: not x.get('multi',False), resaction)
+			for x in resprint+resaction:
+				x['string'] = x['name']
+			ids = self.pool.get('ir.model.fields').search(cr, user, [('relation','=',self._name),('relate','=',1)])
+			resrelate = self.pool.get('ir.model.fields').read(cr, user, ids, ['name','model_id'], context)
+			models = self.pool.get('ir.model').read(cr, user, map(lambda x: x['model_id'][0], resrelate), ['name'], context)
+			dmodels = {}
+			for m in models:
+				dmodels[m['id']] = m['name']
+			for x in resrelate:
+				x['string'] = dmodels[x['model_id'][0]]
+			
+			result['toolbar'] = {
+				'print': resprint,
+				'action': resaction,
+				'relate': resrelate
+			}
 
 		return result
 
@@ -1210,26 +1229,27 @@ class orm(object):
 	def _where_calc(self, args):
 		qu1, qu2 = [], []
 		for x in args:
-			if isinstance(x, WhereClause):
-				qu, val = x.to_query()
-				qu1.append(qu)
-				if val is not None:
-					qu2.append(val)
-				continue
+			table=self
+			if len(x) > 3:
+				table=x[3]
 			if x[1] != 'in':
 #FIXME: this replace all (..., '=', False) values with 'is null' and this is 
 # not what we want for real boolean fields. The problem is, we can't change it
 # easily because we use False everywhere instead of None
 # NOTE FAB: we can't use None because it is not accepted by XML-RPC, that's why
 # boolean (0-1), None -> False
+# Ged> boolean fields are not always = 0 or 1
 				if (x[2] is False) and (x[1]=='='):
 					qu1.append(x[0]+' is null')
 				elif (x[2] is False) and (x[1]=='<>' or x[1]=='!='):
 					qu1.append(x[0]+' is not null')
 				else:
 					if x[0]=='id':
-						qu1.append('(%s.%s %s %%s)' % (self._table, x[0], x[1]))
-						qu2.append(x[2])
+						if x[1]=='join':
+							qu1.append('(%s.%s = %s)' % (table._table, x[0], x[2]))
+						else:
+							qu1.append('(%s.%s %s %%s)' % (table._table, x[0], x[1]))
+							qu2.append(x[2])
 					else:
 						if x[1] in ('like', 'ilike'):
 							if isinstance(x[2], str):
@@ -1240,12 +1260,12 @@ class orm(object):
 								str_utf8 = str(x[2])
 							qu2.append('%%%s%%' % str_utf8)
 						else:
-							qu2.append(self._columns[x[0]]._symbol_set[1](x[2]))
+							qu2.append(table._columns[x[0]]._symbol_set[1](x[2]))
 						if x[1]=='=like':
 							x1 = 'like'
 						else:
 							x1 = x[1]
-						qu1.append('(%s.%s %s %s)' % (self._table, x[0], x1, self._columns[x[0]]._symbol_set[0]))
+						qu1.append('(%s.%s %s %s)' % (table._table, x[0], x1, table._columns[x[0]]._symbol_set[0]))
 			elif x[1]=='in':
 				if len(x[2])>0:
 					todel = False
@@ -1254,9 +1274,9 @@ class orm(object):
 							todel = xitem
 							del x[2][xitem]
 					if x[0]=='id':
-						qu1.append('(id in (%s))' % (','.join(['%d'] * len(x[2])),))
+						qu1.append('(id=any(array[%s]))' % (','.join(['%d'] * len(x[2])),))
 					else:
-						qu1.append('(%s.%s in (%s))' % (self._table, x[0], ','.join([self._columns[x[0]]._symbol_set[0]]*len(x[2]))))
+						qu1.append('(%s.%s in (%s))' % (table._table, x[0], ','.join([table._columns[x[0]]._symbol_set[0]]*len(x[2]))))
 					if todel:
 						qu1[-1] = '('+qu1[-1]+' or '+x[0]+' is null)'
 					qu2+=x[2]
@@ -1284,22 +1304,17 @@ class orm(object):
 				compids.append(False)
 				args.append(('company_id','in',compids))
 
-		# build the list of arguments which use inherited fields and remove those from args
-		args2 = {}
-		i=0
-		while i < len(args):
-			(field,op,value) = args[i]
-			if field in self._inherit_fields:
-				if not self._inherit_fields[field][0] in args2:
-					args2[self._inherit_fields[field][0]] = []
-				args2[self._inherit_fields[field][0]].append( (field, op, value) )
-				del args[i]
-			else:
-				i+=1
-
 		i = 0
+		tables=[self._table]
+		joins=[]
 		while i<len(args):
-			field = self._columns.get(args[i][0],False)
+			table=self
+			if args[i][0] in self._inherit_fields:
+				table=self.pool.get(self._inherit_fields[args[i][0]][0])
+				if (table._table not in tables):
+					tables.append(table._table)
+					joins.append(('id', 'join', '%s.%s' % (self._table, self._inherits[table._name]), table))
+			field = table._columns.get(args[i][0],False)
 			if not field:
 				i+=1
 				continue
@@ -1311,7 +1326,7 @@ class orm(object):
 				if not ids2:
 					args[i] = ('id','=','0')
 				else:
-					cr.execute('select '+field._fields_id+' from '+field_obj._table+' where id in ('+','.join(map(str,ids2))+')')
+					cr.execute('select '+field._fields_id+' from '+field_obj._table+' where id = any(array['+','.join(map(str,ids2))+'])')
 					ids3 = [x[0] for x in cr.fetchall()]
 
 					args[i] = ('id', 'in', ids3)
@@ -1346,18 +1361,22 @@ class orm(object):
 						ids2 = [x[0] for x in self.pool.get(field._obj).name_search(cr, user, args[i][2], [], 'like')]
 					else:
 						ids2 = args[i][2]
-					def _rec_get(ids):
-						if not len(ids): return []
-						ids2 = self.search(cr, user, [(args[i][0],'in',ids)])
-						# This was a bugfix
-						#cr.execute('select id from '+self.pool.get(field._obj)._table+' where '+args[i][0]+' in ('+','.join(map(str, ids))+')')
-						#ids = [x[0] for x in cr.fetchall()]
-						return ids + _rec_get(ids2)
-					args[i] = ('id','in',ids2+_rec_get(ids2))
+					def _rec_get(ids, table):
+						if not len(ids):
+							return []
+						if 'active' in table._columns:
+							ids2 = table.search(cr, user, [(args[i][0],'in',ids),('active','=',0)])
+							ids2 += table.search(cr, user, [(args[i][0],'in',ids),('active','=',1)])
+						else:
+							ids2 = table.search(cr, user, [(args[i][0], 'in', ids)])
+						return ids + _rec_get(ids2, table)
+					args[i] = ('id','in',ids2+_rec_get(ids2, table), table)
 				else:
 					if isinstance(args[i][2], basestring):
 						res_ids = self.pool.get(field._obj).name_search(cr, user, args[i][2], [], args[i][1])
-						args[i] = (args[i][0],'in',map(lambda x: x[0], res_ids))
+						args[i] = (args[i][0],'in',map(lambda x: x[0], res_ids), table)
+					else:
+						args[i] += (table,)
 				i+=1
 			elif field._properties:
 				arg = [args.pop(i)]
@@ -1370,15 +1389,10 @@ class orm(object):
 				if field._fnct_search:
 					args.extend(field.search(cr, user, self, arg[0][0], arg))
 			else:
+				args[i] += (table,)
 				i+=1
+		args.extend(joins)
 
-		tables = [self._table]
-		for table in args2:
-			other = self.pool.get(table)
-			args.extend([WhereClause(other, 'id', '=', '%s.%s' % (self._table, self._inherits[table]))])
-			args.extend([WhereClause(other, col, op, comp) for col, op, comp in args2[table]])
-			tables.append('%s' % other._table)
-			
 		# compute the where, order by, limit and offset clauses
 		(qu1,qu2) = self._where_calc(args)
 		if len(qu1):
@@ -1391,7 +1405,7 @@ class orm(object):
 		offset_str = offset and ' offset %d' % offset or ''
 		
 		# execute the "main" query to fetch the ids we were searching for
- 		cr.execute('select %s.id from ' % self._table + ','.join(tables) +qu1+' order by '+order_by+limit_str+offset_str, qu2)
+		cr.execute('select %s.id from ' % self._table + ','.join(tables) +qu1+' order by '+order_by+limit_str+offset_str, qu2)
 		res = cr.fetchall()
 		return [x[0] for x in res]
 
@@ -1451,33 +1465,4 @@ class orm(object):
 			del data[self._inherits[v]]
 		return self.create(cr, uid, data)
 
-class WhereClause(object):
-
-	def __init__(self, table, column, operator, condition):
-		self.table = table
-		self.column = column
-		self.operator = operator
-		self.condition = condition
-
-	def clause(self):
-		if not self.column in self.table._columns:
-			val = self.condition
-		else:
-			val = self.table._columns[self.column]._symbol_set[0]
-		return '(%s.%s %s %s)' % (self.table._table, self.column, self.operator, val)
-
-	def value(self):
-		if not self.column in self.table._columns:
-			val = None
-		else:
-			val = self.table._columns[self.column]._symbol_set[1](self.condition)
-			if self.operator in ('like', 'ilike'):
-				val = '%%%s%%' % val
-		return val
-
-	def to_query(self):
-		return self.clause(), self.value()
-
-	def __str__(self):
-		return self.condition() % self.value()
 # vim:noexpandtab:ts=4
