@@ -32,11 +32,15 @@
 
 import orm
 import netsvc
-import sql_db
+import pooler
 import copy
 
 import psycopg
 
+module_list = []
+module_class_list = {}
+class_pool = {}
+
 class except_osv(Exception):
 	def __init__(self, name, value, exc_type='warning'):
 		self.name = name
@@ -46,6 +50,8 @@ class except_osv(Exception):
 
 class osv_pool(netsvc.Service):
 	obj_pool = {}
+	module_object_list = {}
+
 	def __init__(self):
 		self.created = []
 		self._sql_error = {}
@@ -84,13 +90,13 @@ class osv_pool(netsvc.Service):
 			self.abortResponse(1, inst.name, inst.exc_type, inst.value)
 		except psycopg.IntegrityError, inst:
 			for key in self._sql_error.keys():
-				if '<<'+key+'>>' in inst[0]:
+				if key in inst[0]:
 					self.abortResponse(1, 'Constraint Error', 'warning', self._sql_error[key])
 			self.abortResponse(1, 'Integrity Error', 'warning', inst[0])
 
 
-	def execute(self, uid, obj, method, *args, **kw):
-		cr = sql_db.db.cursor()
+	def execute(self, db, uid, obj, method, *args, **kw):
+		cr = pooler.get_db(db).cursor()
 		try:
 			try:
 				res = self.execute_cr(cr, uid, obj, method, *args, **kw)
@@ -107,8 +113,8 @@ class osv_pool(netsvc.Service):
 		wf_service.trg_validate(uid, obj, args[0], method, cr)
 		return True
 
-	def exec_workflow(self, uid, obj, method, *args):
-		cr = sql_db.db.cursor()
+	def exec_workflow(self, db, uid, obj, method, *args):
+		cr = pooler.get_db(db).cursor()
 		try:
 			try:
 				res = self.exec_workflow_cr(cr, uid, obj, method, *args)
@@ -130,35 +136,107 @@ class osv_pool(netsvc.Service):
 			del self.obj_pool[name]
 		self.obj_pool[name] = obj_inst
 
+		module = str(obj_inst.__class__)[6:]
+		module = module[:len(module)-1]
+		module = module.split('.')[0][2:]
+		self.module_object_list.setdefault(module, []).append(obj_inst)
+
 	def get(self, name):
-		return self.obj_pool.get(name, None)
+		obj = self.obj_pool.get(name, None)
+# We cannot uncomment this line because it breaks initialisation since objects do not initialize
+# in the correct order and the ORM doesnt support correctly when some objets do not exist yet
+#		assert obj, "object %s does not exist !" % name
+		return obj
 
-osv_pools = osv_pool()
+	#TODO: pass a list of modules to load
+	def instanciate(self, module):
+#		print "module list:", module_list
+#		for module in module_list:
+		res = []
+		class_list = module_class_list.get(module, [])
+#			if module not in self.module_object_list:
+#		print "%s class_list:" % module, class_list
+		for klass in class_list:
+			res.append(klass.createInstance(self, module))
+		return res
+#			else:
+#				print "skipping module", module
 
+#pooler.get_pool(cr.dbname) = osv_pool()
+
+#
+# See if we can use the pool var instead of the class_pool one
+#
 class inheritor(type):
 	def __new__(cls, name, bases, d):
 		parent_name = d.get('_inherit', None)
 		if parent_name:
-			parent_obj = osv_pools.get(parent_name)
-			assert parent_obj, "parent object %s does not exist !" % parent_name
-			for s in ('_columns', '_defaults'):
-				new_dict = copy.copy(getattr(parent_obj.__class__, s))
+			parent_class = class_pool.get(parent_name)
+			assert parent_class, "parent class %s does not exist !" % parent_name
+			for s in ('_columns', '_defaults', '_inherits'):
+				new_dict = copy.copy(getattr(parent_class, s))
 				new_dict.update(d.get(s, {}))
 				d[s] = new_dict
-			bases = (parent_obj.__class__,)
+			bases = (parent_class,)
 		res = type.__new__(cls, name, bases, d)
 		#
 		# update _inherits of others objects
 		#
 		return res
 
-class osv(orm.orm):
-	__metaclass__ = inheritor
 
-	def __init__(self):
-		osv_pools.add(self._name, self)
-		self.pool = osv_pools
+
+class osv(orm.orm):
+	#__metaclass__ = inheritor
+
+	def __new__(cls):
+		if not hasattr(cls, '_module'):
+			module = str(cls)[6:]
+			module = module[:len(module)-1]
+			module = module.split('.')[0][2:]
+			cls._module = module
+		module_class_list.setdefault(cls._module, []).append(cls)
+		class_pool[cls._name] = cls
+		if module not in module_list:
+			module_list.append(cls._module)
+		return None
+		
+	#
+	# Goal: try to apply inheritancy at the instanciation level and
+	#       put objects in the pool var
+	#
+	def createInstance(cls, pool, module):
+#		obj = cls()
+		parent_name = hasattr(cls, '_inherit') and cls._inherit
+		if parent_name:
+			parent_class = pool.get(parent_name).__class__
+			assert parent_class, "parent class %s does not exist !" % parent_name
+			ndict = {}
+			for s in ('_columns', '_defaults', '_inherits'):
+				new_dict = copy.copy(getattr(pool.get(parent_name), s))
+				new_dict.update(cls.__dict__.get(s, {}))
+				ndict[s] = new_dict
+			#bases = (parent_class,)
+			#obj.__class__ += (parent_class,)
+			#res = type.__new__(cls, name, bases, d)
+			name = hasattr(cls,'_name') and cls._name or cls._inherit
+			name = str(cls)
+			cls = type(name, (cls, parent_class), ndict)
+
+		obj = object.__new__(cls)
+		obj.__init__(pool)
+		return obj
+#		return object.__new__(cls, pool)
+	createInstance = classmethod(createInstance)
+
+	def __init__(self, pool):
+#		print "__init__", self._name, pool
+		pool.add(self._name, self)
+		self.pool = pool
 		orm.orm.__init__(self)
+		
+#		pooler.get_pool(cr.dbname).add(self._name, self)
+#		print self._name, module
 
 class Cacheable(object):
 
@@ -260,3 +338,24 @@ class cacheable_osv(osv, Cacheable):
 #cacheable_osv = osv
 
 # vim:noexpandtab:
+
+#class FakePool(object):
+#	def __init__(self, module):
+#		self.preferred_module = module
+	
+#	def get(self, name):
+#		localpool = module_objects_dict.get(self.preferred_module, {'dict': {}})['dict']
+#		if name in localpool:
+#			obj = localpool[name]
+#		else:
+#			obj = pooler.get_pool(cr.dbname).get(name)
+#		return obj
+
+#		fake_pool = self
+#		class fake_class(obj.__class__):
+#			def __init__(self):
+#				super(fake_class, self).__init__()
+#				self.pool = fake_pool
+				
+#		return fake_class()
+
