@@ -35,10 +35,9 @@ import print_xml
 import render
 from interface import report_int
 import common
-from osv.osv import osv_pools
 from osv.orm import browse_null
 from osv.orm import browse_record_list
-import sql_db
+import pooler
 from xml.dom import minidom
 import libxml2
 import libxslt
@@ -133,24 +132,24 @@ class report_custom(report_int):
 		return result 
 
 
-	def create(self, uid, ids, datas, context={}):
-		cr = sql_db.db.cursor()
-		report = osv_pools.get('ir.report.custom').browse(cr, uid, [datas['report_id']])[0]
+	def create(self, cr, uid, ids, datas, context={}):
+		self.pool = pooler.get_pool(cr.dbname)
+		report = self.pool.get('ir.report.custom').browse(cr, uid, [datas['report_id']])[0]
 		datas['model'] = report.model_id.model
 		if report.menu_id:
-			ids = osv_pools.get(report.model_id.model).search(cr, uid, [])
+			ids = self.pool.get(report.model_id.model).search(cr, uid, [])
 			datas['ids'] = ids
 
 		service = netsvc.LocalService("object_proxy")
 		report_id = datas['report_id']
-		report = service.execute(uid, 'ir.report.custom', 'read', [report_id], context=context)[0]
-		fields = service.execute(uid, 'ir.report.custom.fields', 'read', report['fields_child0'], context=context)
+		report = service.execute(cr.dbname, uid, 'ir.report.custom', 'read', [report_id], context=context)[0]
+		fields = service.execute(cr.dbname, uid, 'ir.report.custom.fields', 'read', report['fields_child0'], context=context)
 
 		fields.sort(lambda x,y : x['sequence'] - y['sequence'])
 
 		if report['field_parent']:
-			parent_field = service.execute(uid, 'ir.model.fields', 'read', [report['field_parent'][0]],['model'])
-		model_name = service.execute(uid, 'ir.model', 'read', [report['model_id'][0]], ['model'],context=context)[0]['model']
+			parent_field = service.execute(cr.dbname, uid, 'ir.model.fields', 'read', [report['field_parent'][0]],['model'])
+		model_name = service.execute(cr.dbname, uid, 'ir.model', 'read', [report['model_id'][0]], ['model'],context=context)[0]['model']
 
 		fct = {}
 		fct['id'] = lambda x : x
@@ -175,7 +174,7 @@ class report_custom(report_int):
 						cond.append(None)
 			new_fields.append(row)
 			new_cond.append(cond)
-		objs = osv_pools.get(model_name).browse(cr, uid, ids)
+		objs = self.pool.get(model_name).browse(cr, uid, ids)
 
 		# Group by
 		groupby = None
@@ -204,8 +203,6 @@ class report_custom(report_int):
 				results += build_tree(obj, level, 0)
 		else:
 			results = self._row_get(cr, uid,objs, new_fields, new_cond, group_by=groupby)
-		cr.close()
-
 
 		fct = {
 			'calc_sum': lambda l: reduce(lambda x,y: float(x)+float(y), filter(None, l), 0),
@@ -276,11 +273,11 @@ class report_custom(report_int):
 							row.append(r[j])
 				results2.append(row)
 			if report['type']=='pie':
-				res = self._create_pie(uid, ids, report, fields, results2, context)
+				res = self._create_pie(cr,uid, ids, report, fields, results2, context)
 			elif report['type']=='bar':
-				res = self._create_bars(uid, ids, report, fields, results2, context)
+				res = self._create_bars(cr,uid, ids, report, fields, results2, context)
 			elif report['type']=='line':
-				res = self._create_lines(uid, ids, report, fields, results2, context)
+				res = self._create_lines(cr,uid, ids, report, fields, results2, context)
 		return (self.obj.get(), 'pdf')
 
 	def _create_tree(self, uid, ids, report, fields, level, results, context):
@@ -363,7 +360,7 @@ class report_custom(report_int):
 		return True
 
 
-	def _create_lines(self, uid, ids, report, fields, results, context):
+	def _create_lines(self, cr, uid, ids, report, fields, results, context):
 		service = netsvc.LocalService("object_proxy")
 		pdf_string = StringIO.StringIO()
 		can = canvas.init(fname=pdf_string, format='pdf')
@@ -394,7 +391,7 @@ class report_custom(report_int):
 		for f in fields:
 			field_id = (f['field_child3'] and f['field_child3'][0]) or (f['field_child2'] and f['field_child2'][0]) or (f['field_child1'] and f['field_child1'][0]) or (f['field_child0'] and f['field_child0'][0])
 			if field_id:
-				type = service.execute(uid, 'ir.model.fields', 'read', [field_id],['ttype'])
+				type = service.execute(cr.dbname, uid, 'ir.model.fields', 'read', [field_id],['ttype'])
 				if type[0]['ttype'] == 'date':
 					date_idx = idx
 					fct[idx] = process_date[report['frequency']] 
@@ -466,7 +463,7 @@ class report_custom(report_int):
 
 
 
-	def _create_bars(self, uid, ids, report, fields, results, context):
+	def _create_bars(self, cr, uid, ids, report, fields, results, context):
 		service = netsvc.LocalService("object_proxy")
 		pdf_string = StringIO.StringIO()
 		can = canvas.init(fname=pdf_string, format='pdf')
@@ -493,7 +490,7 @@ class report_custom(report_int):
 		for f in fields:
 			field_id = (f['field_child3'] and f['field_child3'][0]) or (f['field_child2'] and f['field_child2'][0]) or (f['field_child1'] and f['field_child1'][0]) or (f['field_child0'] and f['field_child0'][0])
 			if field_id:
-				type = service.execute(uid, 'ir.model.fields', 'read', [field_id],['ttype'])
+				type = service.execute(cr.dbname, uid, 'ir.model.fields', 'read', [field_id],['ttype'])
 				if type[0]['ttype'] == 'date':
 					date_idx = idx
 					fct[idx] = process_date[report['frequency']] 
@@ -564,7 +561,7 @@ class report_custom(report_int):
 		pdf_string.close()
 		return True
 
-	def _create_pie(self, uid, ids, report, fields, results, context):
+	def _create_pie(self, cr, uid, ids, report, fields, results, context):
 		pdf_string = StringIO.StringIO()
 		can = canvas.init(fname=pdf_string, format='pdf')
 		ar = area.T(size=(350,350), legend=legend.T(),
