@@ -34,7 +34,7 @@ import libxml2
 import libxslt
 
 import netsvc
-import sql_db
+import pooler
 
 import tools
 import print_xml
@@ -63,7 +63,7 @@ class report_int(netsvc.Service):
 		self.joinGroup('report')
 		self.exportMethod(self.create)
 
-	def create(self, uid, ids, datas, context={}):
+	def create(self, cr, uid, ids, datas, context={}):
 		return False
 
 """
@@ -81,27 +81,27 @@ class report_rml(report_int):
 		self.bin_datas = {}
 		self.generators = {'pdf': self.create_pdf, 'html': self.create_html, 'raw': self.create_raw}
 
-	def create(self, uid, ids, datas, context):
-		xml = self.create_xml(uid, ids, datas, context)
+	def create(self, cr, uid, ids, datas, context):
+		xml = self.create_xml(cr, uid, ids, datas, context)
 #		file('/tmp/terp.xml','wb+').write(xml)
 		if datas.get('report_type', 'pdf') == 'raw':
 			return xml
-		rml = self.create_rml(xml, uid, context)
+		rml = self.create_rml(cr, xml, uid, context)
 #		file('/tmp/terp.rml','wb+').write(rml)
 		report_type = datas.get('report_type', 'pdf')
 		create_doc = self.generators[report_type]
 		pdf = create_doc(rml)
 		return (pdf, report_type)
 	
-	def create_xml(self, uid, ids, datas, context={}):
-		doc = print_xml.document(uid, datas, {})
+	def create_xml(self, cr, uid, ids, datas, context={}):
+		doc = print_xml.document(cr, uid, datas, {})
 		self.bin_datas = doc.bin_datas
 		doc.parse(self.tmpl, ids, self.table, context)
 		xml = doc.xml_get()
 		doc.close()
-		return self.post_process_xml_data(uid, xml, context)
+		return self.post_process_xml_data(cr, uid, xml, context)
 
-	def post_process_xml_data(self, uid, xml, context={}):
+	def post_process_xml_data(self, cr, uid, xml, context={}):
 		# find the position of the 3rd tag 
 		# (skip the <?xml ...?> and the "root" tag)
 		iter = re.finditer('<[^>]*>', xml)
@@ -109,7 +109,7 @@ class report_rml(report_int):
 		i = iter.next()
 		pos_xml = i.end()
 
-		doc = print_xml.document(uid, {}, {})
+		doc = print_xml.document(cr, uid, {}, {})
 		tmpl_path = os.path.join(tools.config['root_path'], 'addons/custom/corporate_defaults.xml')
 		doc.parse(tmpl_path, [uid], 'res.users', context)
 		corporate_header = doc.xml_get()
@@ -125,7 +125,7 @@ class report_rml(report_int):
 	#
 	# TODO: The translation doesn't work for "<tag t="1">textext<tag> tex</tag>text</tag>"
 	#
-	def create_rml(self, xml, uid, context={}):
+	def create_rml(self, cr, xml, uid, context={}):
 		service = netsvc.LocalService("object_proxy")
 
 		# In some case we might not use xsl ...
@@ -144,7 +144,8 @@ class report_rml(report_int):
 		def look_down(child, lang):
 			while child is not None:
 				if (child.type == "element") and child.hasProp('t'):
-					res = service.execute(uid, 'ir.translation', '_get_source', self.name2, 'xsl', lang, child.content)
+					#FIXME: use cursor
+					res = service.execute(cr.dbname, uid, 'ir.translation', '_get_source', self.name2, 'xsl', lang, child.content)
 					if res:
 						child.setContent(res)
 				look_down(child.children, lang)
@@ -179,9 +180,10 @@ class report_rml(report_int):
 
 from report_sxw import report_sxw
 
-def register_all():
-	opj=os.path.join
-	cr=sql_db.db.cursor()
+def register_all(db):
+	opj = os.path.join
+	#FIXME: multi-db, quoique... ca init le code donc ok. Enfin, du moins si les modules sont les memes.
+	cr = db.cursor()
 	cr.execute("SELECT * FROM ir_act_report_xml WHERE auto ORDER BY id")
 	result = cr.dictfetchall()
 	cr.close()
