@@ -28,11 +28,12 @@
 
 import xml.dom.minidom
 import os, time
-import ir, netsvc, sql_db
+import ir, netsvc
 import osv
 from interface import  report_rml
 import re
 import tools
+import pooler
 
 import copy
 
@@ -84,36 +85,45 @@ class browse_record_list(list):
 		return None
 
 class rml_parse(object):
-	def __init__(self, cr, uid, context):
+	def __init__(self, cr, uid, name, context={}):
 		self.cr = cr
 		self.uid = uid
-		self.pool = osv.osv.osv_pools
+		self.pool = pooler.get_pool(cr.dbname)
 		user = self.pool.get('res.users').browse(cr, uid, uid)
 		self.localcontext = {
 			'user': user,
 			'company': user.company_id,
 			'repeatIn': self.repeatIn,
+			'setLang': self.setLang,
 			'setTag': self.setTag,
+			'removeParentNode': self.removeParentNode,
 		}
 		self.localcontext.update(context)
+		self.name = name
 		self._regex = re.compile('\[\[(.+?)\]\]')
+		self._transl_regex = re.compile('(\[\[.+?\]\])')
 		self._node = None
-
+#		self.already = {}
+	
 	def setTag(self, oldtag, newtag):
 		node = self._find_parent(self._node, [oldtag])
 		if node:
 			node.tagName = newtag
 		return None
 
-	def repeatIn(self, lst, name):
-		node = self._node
-		node.data = ''
-		while True:
-			if not node.parentNode:
-				break
-			node = node.parentNode
-			if node.nodeType == node.ELEMENT_NODE and node.localName in parents:
-				break
+	def removeParentNode(self, tag):
+		node = self._find_parent(self._node, [tag])
+		if node:
+			parentNode = node.parentNode
+			parentNode.removeChild(node)
+			self._node = parentNode
+
+	def setLang(self, lang):
+		self.localcontext['lang'] = lang
+
+	def repeatIn(self, lst, name, nodes_parent=False):
+		self._node.data = ''
+		node = self._find_parent(self._node, nodes_parent or parents)
 
 		pp = node.parentNode
 		ns = node.nextSibling
@@ -129,9 +139,9 @@ class rml_parse(object):
 				pp.insertBefore(newnode, ns)
 			else:
 				pp.appendChild(newnode)
-			nodes.append((i,newnode))
-		for i,node in nodes:
-			self.node_context[node] = {name:lst[i]}
+			nodes.append((i, newnode))
+		for i, node in nodes:
+			self.node_context[node] = {name: lst[i]}
 		return None
 
 	def _eval(self, expr):
@@ -161,23 +171,45 @@ class rml_parse(object):
 		for key in res:
 			newtext = self._eval(key)
 			for i in range(len(level)):
-				if isinstance(newtext,browse_record_list) or (type(newtext)==type([])):
+				if isinstance(newtext, list):
 					newtext = newtext[level[i]]
-			if isinstance(newtext,browse_record_list) or (type(newtext)==type([])):
+			if isinstance(newtext, list):
 				todo.append((key, newtext))
 			else:
-				if type(newtext) not in (type(''), type(u'')):
+				if not isinstance(newtext, basestring):
 					newtext = str(newtext)
+				# if there are two [[]] blocks the same, it will replace both
+				# but it's ok because it should evaluate to the same thing 
+				# anyway
 				text = text.replace('[['+key+']]', newtext.decode('utf8'))
+		# translate the text
+		# the "split [[]] if not match [[]]" is not very nice, but I 
+		# don't see how I could do it better...
+		# what I'd like to do is a re.sub(NOT pattern, func, string)
+		# but I don't know how to do that...
+		# translate the RML file
+		if 'lang' in self.localcontext:
+			lang = self.localcontext['lang']
+			if lang not in (False, 'en') and text and not text.isspace():
+				transl_obj = self.pool.get('ir.translation')
+				piece_list = self._transl_regex.split(text)
+				for pn in range(len(piece_list)):
+					if not self._transl_regex.match(piece_list[pn]):
+						source_string = piece_list[pn].replace('\n', ' ').strip()
+						if len(source_string):
+							translated_string = transl_obj._get_source(self.cr, self.uid, self.name, 'rml', lang, source_string)
+							if translated_string:
+								piece_list[pn] = piece_list[pn].replace(source_string, translated_string.decode('utf8'))
+				text = ''.join(piece_list)
 		self._node.data = text
 		if len(todo):
 			for key, newtext in todo:
 				parent_node = self._find_parent(self._node, parents)
-				assert parents.get(parent_node.localName,False), 'No parent node found !'
+				assert parents.get(parent_node.localName, False), 'No parent node found !'
 				nodes = [parent_node]
-				for i in range(len(newtext)-1):
+				for i in range(len(newtext) - 1):
 					newnode = parent_node.cloneNode(1)
-					if parents.get(parent_node.localName,False):
+					if parents.get(parent_node.localName, False):
 						n = parent_node.parentNode
 						parent_node.parentNode.insertAfter(newnode, parent_node)
 						nodes.append(newnode)
@@ -199,8 +231,14 @@ class rml_parse(object):
 				self._node = self._node.nextSibling
 			if self._node in self.node_context:
 				self.localcontext.update(self.node_context[self._node])
-			if (self._node.nodeType == self._node.CDATA_SECTION_NODE) or (self._node.nodeType == self._node.TEXT_NODE):
-				self._parse_text(self._node.data,level)
+			if self._node.nodeType in (self._node.CDATA_SECTION_NODE, self._node.TEXT_NODE):
+#				if self._node in self.already:
+#					self.already[self._node] += 1 
+#					print "second pass!", self.already[self._node], '---%s---' % self._node.data
+#				else:
+#					self.already[self._node] = 0
+				self._parse_text(self._node.data, level)
+				
 		return True
 
 	def _find_node(self, node, localname):
@@ -236,66 +274,33 @@ class rml_parse(object):
 		self.dom = rml_dom
 		self._node = self.dom.documentElement
 		self._add_header(self._node)
-
 		self._parse_node()
 		res = self.dom.documentElement.toxml('utf-8')
 		return res
 
-#
-# Not thread independant !!!
-# Bad concurrency, to recode !
-#
 class report_sxw(report_rml):
 	def __init__(self, name, table, rml, parser=rml_parse):
 		report_rml.__init__(self, name, table, rml, '')
-#		self.bin_datas = {}
 		self.name = name
 		self.parser = parser
 
 	def getObjects(self, cr, uid, ids, context):
-		table_obj = osv.osv.osv_pools.get(self.table)
+		table_obj = pooler.get_pool(cr.dbname).get(self.table)
 		return table_obj.browse(cr, uid, ids, list_class=browse_record_list, context=context)
 
-	def create(self, uid, ids, data, context={}):
+	def create(self, cr, uid, ids, data, context={}):
 		rml = file(os.path.join(tools.config['root_path'], self.tmpl)).read()
-		cr = sql_db.db.cursor()
 
-		rml_parser = self.parser(cr, uid, context)
+		rml_parser = self.parser(cr, uid, self.name2, context)
 		objs = self.getObjects(cr, uid, ids, context)
 		rml_parser.preprocess(objs, data, ids)
 		
 		rml_dom = xml.dom.minidom.parseString(rml)
 		
-		service = netsvc.LocalService("object_proxy")
-
-		# translate a node and its children
-		def translate(de, lang):
-			for n in [i for i in de.childNodes if (i.nodeType == i.ELEMENT_NODE)]:
-				for m in [j for j in n.childNodes if (j.nodeType == j.TEXT_NODE)]:
-					# the "split [[]] if not match [[]]" is not very nice, but I 
-					# don't see how I could do it better...
-					# what I'd like to do is a re.sub(NOT pattern, func, string)
-					# but I don't know how to do that...
-					piece_list = re.split('(\[\[.+?\]\])', m.data)
-					for pn in range(len(piece_list)):
-						if not re.match('(\[\[.+?\]\])', piece_list[pn]):
-							source_string = piece_list[pn].replace('\n', ' ').strip()
-							if len(source_string):
-								translated_string = service.execute(uid, 'ir.translation', '_get_source', self.name2, 'rml', lang, source_string)
-								if translated_string:
-									piece_list[pn] = piece_list[pn].replace(source_string, translated_string.decode('utf8'))
-					m.data = ''.join(piece_list)
-				translate(n, lang)
-				
-		# translate the RML file
-		if context.get('lang', False):
-			translate(rml_dom.documentElement, context['lang'])
-
 		rml2 = rml_parser._parse(rml_dom, objs, data)
 		#f = file("/tmp/debug.rml", "w")
 		#f.write(rml2)
 		#f.close()
-		cr.close()
 		report_type= data.get('report_type','pdf')
 		create_doc = self.generators[report_type]
 		pdf = create_doc(rml2)
