@@ -32,7 +32,7 @@ from tools.translate import translate
 from xml import dom
 
 import ir
-import sql_db
+import pooler
 
 class except_wizard(Exception):
 	def __init__(self, name, value):
@@ -90,13 +90,20 @@ class interface(netsvc.Service):
 				for val in fields.keys():
 					if 'default' in fields[val]:
 						# execute default method for this field
-						fields[val]['value'] = fields[val]['default'](uid, data, state)
+						if callable(fields[val]['default']):
+							fields[val]['value'] = fields[val]['default'](uid, data, state)
+						else:
+							fields[val]['value'] = fields[val]['default']
 						del fields[val]['default']
 					else:
 						# if user has set a default value for the field, use it
 						if val in default_values:
 							fields[val]['value'] = default_values[val]
-							
+					if 'selection' in fields[val]:
+						if not isinstance(fields[val]['selection'], (tuple, list)):
+							fields[val] = copy.copy(fields[val])
+							fields[val]['selection'] = fields[val]['selection'](self, cr, uid, context)
+
 				if isinstance(arch, UpdateableStr):
 					arch = arch.string
 					
@@ -115,10 +122,13 @@ class interface(netsvc.Service):
 
 					# translate buttons
 					button_list = list(button_list)
-					for i, (button_name, button_label) in enumerate(button_list):
+					for i, aa  in enumerate(button_list):
+						button_name = aa[0]
 						trans = translate(cr, uid, self.wiz_name+','+state+','+button_name, 'wizard_button', lang)
 						if trans:
-							button_list[i] = (button_name, trans)
+							aa = list(aa)
+							aa[1] = trans
+							button_list[i] = aa
 					
 				res['fields'] = fields
 				res['arch'] = arch
@@ -129,8 +139,8 @@ class interface(netsvc.Service):
 			
 		return res
 
-	def execute(self, uid, data, state='init', context={}):
-		cr = sql_db.db.cursor()
+	def execute(self, db, uid, data, state='init', context={}):
+		cr = pooler.get_db(db).cursor()
 		try:
 			try:
 				res = self.execute_cr(cr, uid, data, state, context)
